
module Make

# 5 "src/parser/grammar.mly"
           ( C : Parser_config.ParseFile )
# 7 "src/parser/grammar.ml"

= struct
  
  module MenhirBasics = struct
    
    exception Error of int
    
    let _eRR =
      fun _s ->
        raise (Error _s)
    
    type token = Elpi_lexer_config.Tokens.token
    
  end
  
  include MenhirBasics
  
# 7 "src/parser/grammar.mly"
  
open Elpi_util
open Elpi_lexer_config

open Lexer_config
open Parser_config
open Ast
open Term


let loc (startpos, endpos) = {
  Util.Loc.source_name = startpos.Lexing.pos_fname;
  source_start = startpos.Lexing.pos_cnum;
  source_stop = endpos.Lexing.pos_cnum;
  line = startpos.Lexing.pos_lnum;
  line_starts_at = startpos.Lexing.pos_bol;
}

let desugar_multi_binder loc = function
  | App(Const hd as binder,args)
    when Func.equal hd Func.pif || Func.equal hd Func.sigmaf && List.length args > 1 ->
      let last, rev_rest = let l = List.rev args in List.hd l, List.tl l in
      let names = List.map (function
        | Const x -> Func.show x
        | (App _ | Lam _ | CData _ | Quoted _) ->
            raise (ParseError(loc,"Only names are allowed after 'pi' or 'sigma'"))) rev_rest in
      let body = mkApp loc [binder;last] in
      List.fold_left (fun bo name -> mkApp loc [binder;mkLam name bo]) body names
  | (App _ | Const _ | Lam _ | CData _ | Quoted _) as t -> t
;;

let desugar_macro loc lhs rhs =
  match lhs, rhs with
  | Const name, body ->
      if ((Func.show name).[0] != '@') then
        raise (ParseError(loc,"Macro name must begin with '@'"));
      name, body
  | App(Const name,args), body ->
      if ((Func.show name).[0] != '@') then
        raise (ParseError(loc,"Macro name must begin with '@'"));
      let names = List.map (function
        | Const x -> Func.show x
        | (App _ | Lam _ | CData _ | Quoted _) ->
              raise (ParseError(loc,"Macro parameters must be names"))) args in
      name, List.fold_right mkLam names body
  | _ ->
        raise (ParseError(loc,"Illformed macro left hand side"))
;;

let mkApp loc = function
  | Const c :: a :: App (Const c1, args) :: [] when Func.(equal c andf && equal c1 andf) ->
      mkAppF loc c (a :: args)
  | l -> mkApp loc l

let binder l = function
  | None -> l
  | Some (loc,b) ->
      match List.rev l with
      | Const name :: rest ->
          List.rev rest @ [mkLam (Func.show name) b]
      | _ -> raise (ParseError(loc,"bind '\\' operator must follow a name"))
;;

let underscore () = Const Func.dummyname

let decode_sequent t =
  match t with
  | App(Const c,[hyps;bo]) when c == Func.sequentf -> hyps, bo
  | _ -> underscore (), t

let prop = Func.from_string "prop"

let fix_church x = if Func.show x = "o" then prop else x

let mode_of_IO io =
  if io = 'i' then true
  else if io = 'o' then false
  else assert false


# 106 "src/parser/grammar.ml"
  
  type ('s, 'r) _menhir_state = 
    | MenhirState000 : ('s, _menhir_box_goal) _menhir_state
      (** State 000.
        Stack shape : .
        Start symbol: goal. *)

    | MenhirState007 : (('s, 'r) _menhir_cell1_LPAREN, 'r) _menhir_state
      (** State 007.
        Stack shape : LPAREN.
        Start symbol: <undetermined>. *)

    | MenhirState017 : (('s, 'r) _menhir_cell1_LCURLY, 'r) _menhir_state
      (** State 017.
        Stack shape : LCURLY.
        Start symbol: <undetermined>. *)

    | MenhirState018 : (('s, 'r) _menhir_cell1_LBRACKET, 'r) _menhir_state
      (** State 018.
        Stack shape : LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState020 : (('s, 'r) _menhir_cell1_PIPE, 'r) _menhir_state
      (** State 020.
        Stack shape : PIPE.
        Start symbol: <undetermined>. *)

    | MenhirState027 : (('s, 'r) _menhir_cell1_FAMILY_TILDE, 'r) _menhir_state
      (** State 027.
        Stack shape : FAMILY_TILDE.
        Start symbol: <undetermined>. *)

    | MenhirState035 : (('s, 'r) _menhir_cell1_head_term, 'r) _menhir_state
      (** State 035.
        Stack shape : head_term.
        Start symbol: <undetermined>. *)

    | MenhirState036 : ((('s, 'r) _menhir_cell1_head_term, 'r) _menhir_cell1_nonempty_list_closed_term_, 'r) _menhir_state
      (** State 036.
        Stack shape : head_term nonempty_list(closed_term).
        Start symbol: <undetermined>. *)

    | MenhirState037 : (('s, 'r) _menhir_cell1_BIND, 'r) _menhir_state
      (** State 037.
        Stack shape : BIND.
        Start symbol: <undetermined>. *)

    | MenhirState038 : (('s, 'r) _menhir_cell1_FAMILY_TILDE, 'r) _menhir_state
      (** State 038.
        Stack shape : FAMILY_TILDE.
        Start symbol: <undetermined>. *)

    | MenhirState042 : (('s, 'r) _menhir_cell1_head_term, 'r) _menhir_state
      (** State 042.
        Stack shape : head_term.
        Start symbol: <undetermined>. *)

    | MenhirState043 : ((('s, 'r) _menhir_cell1_head_term, 'r) _menhir_cell1_nonempty_list_closed_term_, 'r) _menhir_state
      (** State 043.
        Stack shape : head_term nonempty_list(closed_term).
        Start symbol: <undetermined>. *)

    | MenhirState048 : (('s, 'r) _menhir_cell1_closed_term, 'r) _menhir_state
      (** State 048.
        Stack shape : closed_term.
        Start symbol: <undetermined>. *)

    | MenhirState050 : (('s, 'r) _menhir_cell1_constant, 'r) _menhir_state
      (** State 050.
        Stack shape : constant.
        Start symbol: <undetermined>. *)

    | MenhirState055 : (('s, 'r) _menhir_cell1_term _menhir_cell0_VDASH, 'r) _menhir_state
      (** State 055.
        Stack shape : term VDASH.
        Start symbol: <undetermined>. *)

    | MenhirState057 : (('s, 'r) _menhir_cell1_term _menhir_cell0_SLASH, 'r) _menhir_state
      (** State 057.
        Stack shape : term SLASH.
        Start symbol: <undetermined>. *)

    | MenhirState059 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_SHARP, 'r) _menhir_state
      (** State 059.
        Stack shape : term FAMILY_SHARP.
        Start symbol: <undetermined>. *)

    | MenhirState061 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_OR, 'r) _menhir_state
      (** State 061.
        Stack shape : term FAMILY_OR.
        Start symbol: <undetermined>. *)

    | MenhirState063 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_AND, 'r) _menhir_state
      (** State 063.
        Stack shape : term FAMILY_AND.
        Start symbol: <undetermined>. *)

    | MenhirState065 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_MINUS, 'r) _menhir_state
      (** State 065.
        Stack shape : term FAMILY_MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState067 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_EQ, 'r) _menhir_state
      (** State 067.
        Stack shape : term FAMILY_EQ.
        Start symbol: <undetermined>. *)

    | MenhirState069 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_BTICK, 'r) _menhir_state
      (** State 069.
        Stack shape : term FAMILY_BTICK.
        Start symbol: <undetermined>. *)

    | MenhirState071 : (('s, 'r) _menhir_cell1_term _menhir_cell0_OR, 'r) _menhir_state
      (** State 071.
        Stack shape : term OR.
        Start symbol: <undetermined>. *)

    | MenhirState073 : (('s, 'r) _menhir_cell1_term _menhir_cell0_MOD, 'r) _menhir_state
      (** State 073.
        Stack shape : term MOD.
        Start symbol: <undetermined>. *)

    | MenhirState075 : (('s, 'r) _menhir_cell1_term _menhir_cell0_MINUSs, 'r) _menhir_state
      (** State 075.
        Stack shape : term MINUSs.
        Start symbol: <undetermined>. *)

    | MenhirState077 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_TIMES, 'r) _menhir_state
      (** State 077.
        Stack shape : term FAMILY_TIMES.
        Start symbol: <undetermined>. *)

    | MenhirState079 : (('s, 'r) _menhir_cell1_term _menhir_cell0_DIV, 'r) _menhir_state
      (** State 079.
        Stack shape : term DIV.
        Start symbol: <undetermined>. *)

    | MenhirState081 : (('s, 'r) _menhir_cell1_term _menhir_cell0_MINUSr, 'r) _menhir_state
      (** State 081.
        Stack shape : term MINUSr.
        Start symbol: <undetermined>. *)

    | MenhirState083 : (('s, 'r) _menhir_cell1_term _menhir_cell0_MINUSi, 'r) _menhir_state
      (** State 083.
        Stack shape : term MINUSi.
        Start symbol: <undetermined>. *)

    | MenhirState085 : (('s, 'r) _menhir_cell1_term _menhir_cell0_MINUS, 'r) _menhir_state
      (** State 085.
        Stack shape : term MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState087 : (('s, 'r) _menhir_cell1_term _menhir_cell0_IS, 'r) _menhir_state
      (** State 087.
        Stack shape : term IS.
        Start symbol: <undetermined>. *)

    | MenhirState089 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_TICK, 'r) _menhir_state
      (** State 089.
        Stack shape : term FAMILY_TICK.
        Start symbol: <undetermined>. *)

    | MenhirState091 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_PLUS, 'r) _menhir_state
      (** State 091.
        Stack shape : term FAMILY_PLUS.
        Start symbol: <undetermined>. *)

    | MenhirState093 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_EXP, 'r) _menhir_state
      (** State 093.
        Stack shape : term FAMILY_EXP.
        Start symbol: <undetermined>. *)

    | MenhirState095 : (('s, 'r) _menhir_cell1_term _menhir_cell0_CONS, 'r) _menhir_state
      (** State 095.
        Stack shape : term CONS.
        Start symbol: <undetermined>. *)

    | MenhirState097 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_LT, 'r) _menhir_state
      (** State 097.
        Stack shape : term FAMILY_LT.
        Start symbol: <undetermined>. *)

    | MenhirState099 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_GT, 'r) _menhir_state
      (** State 099.
        Stack shape : term FAMILY_GT.
        Start symbol: <undetermined>. *)

    | MenhirState101 : (('s, 'r) _menhir_cell1_term _menhir_cell0_EQ2, 'r) _menhir_state
      (** State 101.
        Stack shape : term EQ2.
        Start symbol: <undetermined>. *)

    | MenhirState103 : (('s, 'r) _menhir_cell1_term _menhir_cell0_EQ, 'r) _menhir_state
      (** State 103.
        Stack shape : term EQ.
        Start symbol: <undetermined>. *)

    | MenhirState105 : (('s, 'r) _menhir_cell1_term _menhir_cell0_DARROW, 'r) _menhir_state
      (** State 105.
        Stack shape : term DARROW.
        Start symbol: <undetermined>. *)

    | MenhirState107 : (('s, 'r) _menhir_cell1_term _menhir_cell0_CONJ2, 'r) _menhir_state
      (** State 107.
        Stack shape : term CONJ2.
        Start symbol: <undetermined>. *)

    | MenhirState109 : (('s, 'r) _menhir_cell1_term _menhir_cell0_CONJ, 'r) _menhir_state
      (** State 109.
        Stack shape : term CONJ.
        Start symbol: <undetermined>. *)

    | MenhirState111 : (('s, 'r) _menhir_cell1_term _menhir_cell0_ARROW, 'r) _menhir_state
      (** State 111.
        Stack shape : term ARROW.
        Start symbol: <undetermined>. *)

    | MenhirState113 : (('s, 'r) _menhir_cell1_term _menhir_cell0_QDASH, 'r) _menhir_state
      (** State 113.
        Stack shape : term QDASH.
        Start symbol: <undetermined>. *)

    | MenhirState117 : (('s, 'r) _menhir_cell1_constant _menhir_cell0_BIND, 'r) _menhir_state
      (** State 117.
        Stack shape : constant BIND.
        Start symbol: <undetermined>. *)

    | MenhirState122 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_VDASH, 'r) _menhir_state
      (** State 122.
        Stack shape : term_noconj VDASH.
        Start symbol: <undetermined>. *)

    | MenhirState124 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_SLASH, 'r) _menhir_state
      (** State 124.
        Stack shape : term_noconj SLASH.
        Start symbol: <undetermined>. *)

    | MenhirState126 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_SHARP, 'r) _menhir_state
      (** State 126.
        Stack shape : term_noconj FAMILY_SHARP.
        Start symbol: <undetermined>. *)

    | MenhirState128 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_OR, 'r) _menhir_state
      (** State 128.
        Stack shape : term_noconj FAMILY_OR.
        Start symbol: <undetermined>. *)

    | MenhirState130 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_AND, 'r) _menhir_state
      (** State 130.
        Stack shape : term_noconj FAMILY_AND.
        Start symbol: <undetermined>. *)

    | MenhirState132 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_MINUS, 'r) _menhir_state
      (** State 132.
        Stack shape : term_noconj FAMILY_MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState134 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EQ, 'r) _menhir_state
      (** State 134.
        Stack shape : term_noconj FAMILY_EQ.
        Start symbol: <undetermined>. *)

    | MenhirState136 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_BTICK, 'r) _menhir_state
      (** State 136.
        Stack shape : term_noconj FAMILY_BTICK.
        Start symbol: <undetermined>. *)

    | MenhirState138 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_OR, 'r) _menhir_state
      (** State 138.
        Stack shape : term_noconj OR.
        Start symbol: <undetermined>. *)

    | MenhirState140 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_MOD, 'r) _menhir_state
      (** State 140.
        Stack shape : term_noconj MOD.
        Start symbol: <undetermined>. *)

    | MenhirState142 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_MINUSs, 'r) _menhir_state
      (** State 142.
        Stack shape : term_noconj MINUSs.
        Start symbol: <undetermined>. *)

    | MenhirState144 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TIMES, 'r) _menhir_state
      (** State 144.
        Stack shape : term_noconj FAMILY_TIMES.
        Start symbol: <undetermined>. *)

    | MenhirState146 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_DIV, 'r) _menhir_state
      (** State 146.
        Stack shape : term_noconj DIV.
        Start symbol: <undetermined>. *)

    | MenhirState148 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_MINUSr, 'r) _menhir_state
      (** State 148.
        Stack shape : term_noconj MINUSr.
        Start symbol: <undetermined>. *)

    | MenhirState150 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_MINUSi, 'r) _menhir_state
      (** State 150.
        Stack shape : term_noconj MINUSi.
        Start symbol: <undetermined>. *)

    | MenhirState152 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_MINUS, 'r) _menhir_state
      (** State 152.
        Stack shape : term_noconj MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState154 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_IS, 'r) _menhir_state
      (** State 154.
        Stack shape : term_noconj IS.
        Start symbol: <undetermined>. *)

    | MenhirState156 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TICK, 'r) _menhir_state
      (** State 156.
        Stack shape : term_noconj FAMILY_TICK.
        Start symbol: <undetermined>. *)

    | MenhirState158 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_PLUS, 'r) _menhir_state
      (** State 158.
        Stack shape : term_noconj FAMILY_PLUS.
        Start symbol: <undetermined>. *)

    | MenhirState160 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EXP, 'r) _menhir_state
      (** State 160.
        Stack shape : term_noconj FAMILY_EXP.
        Start symbol: <undetermined>. *)

    | MenhirState162 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_CONS, 'r) _menhir_state
      (** State 162.
        Stack shape : term_noconj CONS.
        Start symbol: <undetermined>. *)

    | MenhirState164 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_LT, 'r) _menhir_state
      (** State 164.
        Stack shape : term_noconj FAMILY_LT.
        Start symbol: <undetermined>. *)

    | MenhirState166 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_GT, 'r) _menhir_state
      (** State 166.
        Stack shape : term_noconj FAMILY_GT.
        Start symbol: <undetermined>. *)

    | MenhirState168 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_EQ2, 'r) _menhir_state
      (** State 168.
        Stack shape : term_noconj EQ2.
        Start symbol: <undetermined>. *)

    | MenhirState170 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_EQ, 'r) _menhir_state
      (** State 170.
        Stack shape : term_noconj EQ.
        Start symbol: <undetermined>. *)

    | MenhirState172 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_DARROW, 'r) _menhir_state
      (** State 172.
        Stack shape : term_noconj DARROW.
        Start symbol: <undetermined>. *)

    | MenhirState174 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_CONJ2, 'r) _menhir_state
      (** State 174.
        Stack shape : term_noconj CONJ2.
        Start symbol: <undetermined>. *)

    | MenhirState176 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_ARROW, 'r) _menhir_state
      (** State 176.
        Stack shape : term_noconj ARROW.
        Start symbol: <undetermined>. *)

    | MenhirState179 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_QDASH, 'r) _menhir_state
      (** State 179.
        Stack shape : term_noconj QDASH.
        Start symbol: <undetermined>. *)

    | MenhirState183 : (('s, 'r) _menhir_cell1_term_noconj, 'r) _menhir_state
      (** State 183.
        Stack shape : term_noconj.
        Start symbol: <undetermined>. *)

    | MenhirState186 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_CONJ, 'r) _menhir_state
      (** State 186.
        Stack shape : term_noconj CONJ.
        Start symbol: <undetermined>. *)

    | MenhirState195 : ((('s, 'r) _menhir_cell1_LPAREN, 'r) _menhir_cell1_FAMILY_TILDE, 'r) _menhir_state
      (** State 195.
        Stack shape : LPAREN FAMILY_TILDE.
        Start symbol: <undetermined>. *)

    | MenhirState220 : ((('s, 'r) _menhir_cell1_LPAREN, 'r) _menhir_cell1_term, 'r) _menhir_state
      (** State 220.
        Stack shape : LPAREN term.
        Start symbol: <undetermined>. *)

    | MenhirState267 : ('s, _menhir_box_program) _menhir_state
      (** State 267.
        Stack shape : .
        Start symbol: program. *)

    | MenhirState269 : (('s, _menhir_box_program) _menhir_cell1_USEONLY, _menhir_box_program) _menhir_state
      (** State 269.
        Stack shape : USEONLY.
        Start symbol: program. *)

    | MenhirState270 : (('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 270.
        Stack shape : LPAREN.
        Start symbol: program. *)

    | MenhirState272 : ((('s, _menhir_box_program) _menhir_cell1_USEONLY, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_, _menhir_box_program) _menhir_state
      (** State 272.
        Stack shape : USEONLY separated_nonempty_list(CONJ,constant).
        Start symbol: program. *)

    | MenhirState273 : (('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 273.
        Stack shape : LPAREN.
        Start symbol: program. *)

    | MenhirState276 : (('s, _menhir_box_program) _menhir_cell1_type_term _menhir_cell0_ARROW, _menhir_box_program) _menhir_state
      (** State 276.
        Stack shape : type_term ARROW.
        Start symbol: program. *)

    | MenhirState278 : (('s, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 278.
        Stack shape : constant.
        Start symbol: program. *)

    | MenhirState280 : (('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 280.
        Stack shape : LPAREN.
        Start symbol: program. *)

    | MenhirState285 : (('s, _menhir_box_program) _menhir_cell1_atype_term, _menhir_box_program) _menhir_state
      (** State 285.
        Stack shape : atype_term.
        Start symbol: program. *)

    | MenhirState289 : (('s, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_CONJ, _menhir_box_program) _menhir_state
      (** State 289.
        Stack shape : constant CONJ.
        Start symbol: program. *)

    | MenhirState291 : (('s, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_state
      (** State 291.
        Stack shape : TYPEABBREV.
        Start symbol: program. *)

    | MenhirState292 : ((('s, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 292.
        Stack shape : TYPEABBREV LPAREN.
        Start symbol: program. *)

    | MenhirState293 : (((('s, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 293.
        Stack shape : TYPEABBREV LPAREN constant.
        Start symbol: program. *)

    | MenhirState296 : ((('s, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 296.
        Stack shape : constant constant.
        Start symbol: program. *)

    | MenhirState299 : ((('s, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_abbrevform, _menhir_box_program) _menhir_state
      (** State 299.
        Stack shape : TYPEABBREV abbrevform.
        Start symbol: program. *)

    | MenhirState301 : (('s, _menhir_box_program) _menhir_cell1_SIG, _menhir_box_program) _menhir_state
      (** State 301.
        Stack shape : SIG.
        Start symbol: program. *)

    | MenhirState303 : (('s, _menhir_box_program) _menhir_cell1_SHORTEN, _menhir_box_program) _menhir_state
      (** State 303.
        Stack shape : SHORTEN.
        Start symbol: program. *)

    | MenhirState309 : ((('s, _menhir_box_program) _menhir_cell1_SHORTEN, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_FULLSTOP _menhir_cell0_LCURLY, _menhir_box_program) _menhir_state
      (** State 309.
        Stack shape : SHORTEN constant FULLSTOP LCURLY.
        Start symbol: program. *)

    | MenhirState311 : (('s, _menhir_box_program) _menhir_cell1_subtrie _menhir_cell0_CONJ, _menhir_box_program) _menhir_state
      (** State 311.
        Stack shape : subtrie CONJ.
        Start symbol: program. *)

    | MenhirState315 : (('s, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_FULLSTOP _menhir_cell0_LCURLY, _menhir_box_program) _menhir_state
      (** State 315.
        Stack shape : constant FULLSTOP LCURLY.
        Start symbol: program. *)

    | MenhirState321 : (('s, _menhir_box_program) _menhir_cell1_NAMESPACE, _menhir_box_program) _menhir_state
      (** State 321.
        Stack shape : NAMESPACE.
        Start symbol: program. *)

    | MenhirState324 : (('s, _menhir_box_program) _menhir_cell1_MODULE, _menhir_box_program) _menhir_state
      (** State 324.
        Stack shape : MODULE.
        Start symbol: program. *)

    | MenhirState327 : (('s, _menhir_box_program) _menhir_cell1_MODE _menhir_cell0_LPAREN, _menhir_box_program) _menhir_state
      (** State 327.
        Stack shape : MODE LPAREN.
        Start symbol: program. *)

    | MenhirState328 : ((('s, _menhir_box_program) _menhir_cell1_MODE _menhir_cell0_LPAREN, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 328.
        Stack shape : MODE LPAREN constant.
        Start symbol: program. *)

    | MenhirState332 : (('s, _menhir_box_program) _menhir_cell1_i_o, _menhir_box_program) _menhir_state
      (** State 332.
        Stack shape : i_o.
        Start symbol: program. *)

    | MenhirState334 : (('s, _menhir_box_program) _menhir_cell1_MACRO, _menhir_box_program) _menhir_state
      (** State 334.
        Stack shape : MACRO.
        Start symbol: program. *)

    | MenhirState336 : ((('s, _menhir_box_program) _menhir_cell1_MACRO, _menhir_box_program) _menhir_cell1_term _menhir_cell0_VDASH, _menhir_box_program) _menhir_state
      (** State 336.
        Stack shape : MACRO term VDASH.
        Start symbol: program. *)

    | MenhirState338 : (('s, _menhir_box_program) _menhir_cell1_LOCALKIND, _menhir_box_program) _menhir_state
      (** State 338.
        Stack shape : LOCALKIND.
        Start symbol: program. *)

    | MenhirState340 : (('s, _menhir_box_program) _menhir_cell1_LOCAL, _menhir_box_program) _menhir_state
      (** State 340.
        Stack shape : LOCAL.
        Start symbol: program. *)

    | MenhirState341 : ((('s, _menhir_box_program) _menhir_cell1_LOCAL, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_, _menhir_box_program) _menhir_state
      (** State 341.
        Stack shape : LOCAL separated_nonempty_list(CONJ,constant).
        Start symbol: program. *)

    | MenhirState346 : (('s, _menhir_box_program) _menhir_cell1_KIND, _menhir_box_program) _menhir_state
      (** State 346.
        Stack shape : KIND.
        Start symbol: program. *)

    | MenhirState347 : ((('s, _menhir_box_program) _menhir_cell1_KIND, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_, _menhir_box_program) _menhir_state
      (** State 347.
        Stack shape : KIND separated_nonempty_list(CONJ,constant).
        Start symbol: program. *)

    | MenhirState349 : (('s, _menhir_box_program) _menhir_cell1_TYPE _menhir_cell0_ARROW, _menhir_box_program) _menhir_state
      (** State 349.
        Stack shape : TYPE ARROW.
        Start symbol: program. *)

    | MenhirState353 : (('s, _menhir_box_program) _menhir_cell1_FIXITY, _menhir_box_program) _menhir_state
      (** State 353.
        Stack shape : FIXITY.
        Start symbol: program. *)

    | MenhirState359 : (('s, _menhir_box_program) _menhir_cell1_EXPORTDEF, _menhir_box_program) _menhir_state
      (** State 359.
        Stack shape : EXPORTDEF.
        Start symbol: program. *)

    | MenhirState360 : ((('s, _menhir_box_program) _menhir_cell1_EXPORTDEF, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_, _menhir_box_program) _menhir_state
      (** State 360.
        Stack shape : EXPORTDEF separated_nonempty_list(CONJ,constant).
        Start symbol: program. *)

    | MenhirState363 : (('s, _menhir_box_program) _menhir_cell1_CONSTRAINT, _menhir_box_program) _menhir_state
      (** State 363.
        Stack shape : CONSTRAINT.
        Start symbol: program. *)

    | MenhirState366 : (('s, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 366.
        Stack shape : constant.
        Start symbol: program. *)

    | MenhirState368 : (('s, _menhir_box_program) _menhir_cell1_COLON, _menhir_box_program) _menhir_state
      (** State 368.
        Stack shape : COLON.
        Start symbol: program. *)

    | MenhirState372 : (('s, _menhir_box_program) _menhir_cell1_INDEX _menhir_cell0_LPAREN, _menhir_box_program) _menhir_state
      (** State 372.
        Stack shape : INDEX LPAREN.
        Start symbol: program. *)

    | MenhirState377 : (('s, _menhir_box_program) _menhir_cell1_indexing, _menhir_box_program) _menhir_state
      (** State 377.
        Stack shape : indexing.
        Start symbol: program. *)

    | MenhirState388 : (('s, _menhir_box_program) _menhir_cell1_attribute _menhir_cell0_COLON, _menhir_box_program) _menhir_state
      (** State 388.
        Stack shape : attribute COLON.
        Start symbol: program. *)

    | MenhirState390 : (('s, _menhir_box_program) _menhir_cell1_CLOSED, _menhir_box_program) _menhir_state
      (** State 390.
        Stack shape : CLOSED.
        Start symbol: program. *)

    | MenhirState411 : (('s, _menhir_box_program) _menhir_cell1_decl, _menhir_box_program) _menhir_state
      (** State 411.
        Stack shape : decl.
        Start symbol: program. *)

    | MenhirState417 : (('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_state
      (** State 417.
        Stack shape : attributes.
        Start symbol: program. *)

    | MenhirState418 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_TYPE, _menhir_box_program) _menhir_state
      (** State 418.
        Stack shape : attributes TYPE.
        Start symbol: program. *)

    | MenhirState419 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_TYPE, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_, _menhir_box_program) _menhir_state
      (** State 419.
        Stack shape : attributes TYPE separated_nonempty_list(CONJ,constant).
        Start symbol: program. *)

    | MenhirState421 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_state
      (** State 421.
        Stack shape : attributes RULE.
        Start symbol: program. *)

    | MenhirState422 : (('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 422.
        Stack shape : LPAREN.
        Start symbol: program. *)

    | MenhirState423 : ((('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 423.
        Stack shape : LPAREN constant.
        Start symbol: program. *)

    | MenhirState424 : (((('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_cell1_COLON, _menhir_box_program) _menhir_state
      (** State 424.
        Stack shape : LPAREN constant COLON.
        Start symbol: program. *)

    | MenhirState427 : (('s, _menhir_box_program) _menhir_cell1_sequent, _menhir_box_program) _menhir_state
      (** State 427.
        Stack shape : sequent.
        Start symbol: program. *)

    | MenhirState431 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_BIND, _menhir_box_program) _menhir_state
      (** State 431.
        Stack shape : attributes RULE list(sequent) BIND.
        Start symbol: program. *)

    | MenhirState432 : (('s, _menhir_box_program) _menhir_cell1_sequent, _menhir_box_program) _menhir_state
      (** State 432.
        Stack shape : sequent.
        Start symbol: program. *)

    | MenhirState436 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___, _menhir_box_program) _menhir_state
      (** State 436.
        Stack shape : attributes RULE list(sequent) option(preceded(BIND,nonempty_list(sequent))).
        Start symbol: program. *)

    | MenhirState439 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ _menhir_cell0_option_preceded_PIPE_term__, _menhir_box_program) _menhir_state
      (** State 439.
        Stack shape : attributes RULE list(sequent) option(preceded(BIND,nonempty_list(sequent))) option(preceded(PIPE,term)).
        Start symbol: program. *)

    | MenhirState442 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_PRED, _menhir_box_program) _menhir_state
      (** State 442.
        Stack shape : attributes PRED.
        Start symbol: program. *)

    | MenhirState443 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_PRED, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 443.
        Stack shape : attributes PRED constant.
        Start symbol: program. *)

    | MenhirState444 : (('s, _menhir_box_program) _menhir_cell1_IO_COLON, _menhir_box_program) _menhir_state
      (** State 444.
        Stack shape : IO_COLON.
        Start symbol: program. *)

    | MenhirState449 : (('s, _menhir_box_program) _menhir_cell1_pred_item _menhir_cell0_option_CONJ_, _menhir_box_program) _menhir_state
      (** State 449.
        Stack shape : pred_item option(CONJ).
        Start symbol: program. *)

    | MenhirState452 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 452.
        Stack shape : attributes LPAREN.
        Start symbol: program. *)

    | MenhirState455 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_FAMILY_TILDE, _menhir_box_program) _menhir_state
      (** State 455.
        Stack shape : attributes FAMILY_TILDE.
        Start symbol: program. *)

    | MenhirState457 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term, _menhir_box_program) _menhir_state
      (** State 457.
        Stack shape : attributes head_term.
        Start symbol: program. *)

    | MenhirState458 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term, _menhir_box_program) _menhir_cell1_nonempty_list_closed_term_, _menhir_box_program) _menhir_state
      (** State 458.
        Stack shape : attributes head_term nonempty_list(closed_term).
        Start symbol: program. *)

    | MenhirState462 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_VDASH, _menhir_box_program) _menhir_state
      (** State 462.
        Stack shape : attributes clause_hd_term VDASH.
        Start symbol: program. *)

    | MenhirState464 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_SLASH, _menhir_box_program) _menhir_state
      (** State 464.
        Stack shape : attributes clause_hd_term SLASH.
        Start symbol: program. *)

    | MenhirState466 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_QDASH, _menhir_box_program) _menhir_state
      (** State 466.
        Stack shape : attributes clause_hd_term QDASH.
        Start symbol: program. *)

    | MenhirState468 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_OR, _menhir_box_program) _menhir_state
      (** State 468.
        Stack shape : attributes clause_hd_term OR.
        Start symbol: program. *)

    | MenhirState470 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MOD, _menhir_box_program) _menhir_state
      (** State 470.
        Stack shape : attributes clause_hd_term MOD.
        Start symbol: program. *)

    | MenhirState472 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSs, _menhir_box_program) _menhir_state
      (** State 472.
        Stack shape : attributes clause_hd_term MINUSs.
        Start symbol: program. *)

    | MenhirState474 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSr, _menhir_box_program) _menhir_state
      (** State 474.
        Stack shape : attributes clause_hd_term MINUSr.
        Start symbol: program. *)

    | MenhirState476 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSi, _menhir_box_program) _menhir_state
      (** State 476.
        Stack shape : attributes clause_hd_term MINUSi.
        Start symbol: program. *)

    | MenhirState478 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUS, _menhir_box_program) _menhir_state
      (** State 478.
        Stack shape : attributes clause_hd_term MINUS.
        Start symbol: program. *)

    | MenhirState480 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_IS, _menhir_box_program) _menhir_state
      (** State 480.
        Stack shape : attributes clause_hd_term IS.
        Start symbol: program. *)

    | MenhirState482 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TIMES, _menhir_box_program) _menhir_state
      (** State 482.
        Stack shape : attributes clause_hd_term FAMILY_TIMES.
        Start symbol: program. *)

    | MenhirState484 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TICK, _menhir_box_program) _menhir_state
      (** State 484.
        Stack shape : attributes clause_hd_term FAMILY_TICK.
        Start symbol: program. *)

    | MenhirState486 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_SHARP, _menhir_box_program) _menhir_state
      (** State 486.
        Stack shape : attributes clause_hd_term FAMILY_SHARP.
        Start symbol: program. *)

    | MenhirState489 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_PLUS, _menhir_box_program) _menhir_state
      (** State 489.
        Stack shape : attributes clause_hd_term FAMILY_PLUS.
        Start symbol: program. *)

    | MenhirState491 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_OR, _menhir_box_program) _menhir_state
      (** State 491.
        Stack shape : attributes clause_hd_term FAMILY_OR.
        Start symbol: program. *)

    | MenhirState493 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_MINUS, _menhir_box_program) _menhir_state
      (** State 493.
        Stack shape : attributes clause_hd_term FAMILY_MINUS.
        Start symbol: program. *)

    | MenhirState495 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_LT, _menhir_box_program) _menhir_state
      (** State 495.
        Stack shape : attributes clause_hd_term FAMILY_LT.
        Start symbol: program. *)

    | MenhirState497 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_GT, _menhir_box_program) _menhir_state
      (** State 497.
        Stack shape : attributes clause_hd_term FAMILY_GT.
        Start symbol: program. *)

    | MenhirState499 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EXP, _menhir_box_program) _menhir_state
      (** State 499.
        Stack shape : attributes clause_hd_term FAMILY_EXP.
        Start symbol: program. *)

    | MenhirState501 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EQ, _menhir_box_program) _menhir_state
      (** State 501.
        Stack shape : attributes clause_hd_term FAMILY_EQ.
        Start symbol: program. *)

    | MenhirState503 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_BTICK, _menhir_box_program) _menhir_state
      (** State 503.
        Stack shape : attributes clause_hd_term FAMILY_BTICK.
        Start symbol: program. *)

    | MenhirState505 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_AND, _menhir_box_program) _menhir_state
      (** State 505.
        Stack shape : attributes clause_hd_term FAMILY_AND.
        Start symbol: program. *)

    | MenhirState507 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ2, _menhir_box_program) _menhir_state
      (** State 507.
        Stack shape : attributes clause_hd_term EQ2.
        Start symbol: program. *)

    | MenhirState509 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ, _menhir_box_program) _menhir_state
      (** State 509.
        Stack shape : attributes clause_hd_term EQ.
        Start symbol: program. *)

    | MenhirState511 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DIV, _menhir_box_program) _menhir_state
      (** State 511.
        Stack shape : attributes clause_hd_term DIV.
        Start symbol: program. *)

    | MenhirState513 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DARROW, _menhir_box_program) _menhir_state
      (** State 513.
        Stack shape : attributes clause_hd_term DARROW.
        Start symbol: program. *)

    | MenhirState515 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONS, _menhir_box_program) _menhir_state
      (** State 515.
        Stack shape : attributes clause_hd_term CONS.
        Start symbol: program. *)

    | MenhirState517 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ2, _menhir_box_program) _menhir_state
      (** State 517.
        Stack shape : attributes clause_hd_term CONJ2.
        Start symbol: program. *)

    | MenhirState519 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ, _menhir_box_program) _menhir_state
      (** State 519.
        Stack shape : attributes clause_hd_term CONJ.
        Start symbol: program. *)

    | MenhirState521 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_ARROW, _menhir_box_program) _menhir_state
      (** State 521.
        Stack shape : attributes clause_hd_term ARROW.
        Start symbol: program. *)

    | MenhirState525 : (('s, _menhir_box_program) _menhir_cell1_accumulate, _menhir_box_program) _menhir_state
      (** State 525.
        Stack shape : accumulate.
        Start symbol: program. *)

    | MenhirState530 : (('s, _menhir_box_program) _menhir_cell1_filename _menhir_cell0_CONJ, _menhir_box_program) _menhir_state
      (** State 530.
        Stack shape : filename CONJ.
        Start symbol: program. *)

  
  and ('s, 'r) _menhir_cell1_abbrevform = 
    | MenhirCell1_abbrevform of 's * ('s, 'r) _menhir_state * (Ast.Func.t * Ast.Func.t list)
  
  and ('s, 'r) _menhir_cell1_accumulate = 
    | MenhirCell1_accumulate of 's * ('s, 'r) _menhir_state * (string) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_attribute = 
    | MenhirCell1_attribute of 's * ('s, 'r) _menhir_state * (Ast.raw_attribute) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_attributes = 
    | MenhirCell1_attributes of 's * ('s, 'r) _menhir_state * (Ast.raw_attribute list) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_atype_term = 
    | MenhirCell1_atype_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_clause_hd_term = 
    | MenhirCell1_clause_hd_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_closed_term = 
    | MenhirCell1_closed_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_constant = 
    | MenhirCell1_constant of 's * ('s, 'r) _menhir_state * (Ast.Func.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_decl = 
    | MenhirCell1_decl of 's * ('s, 'r) _menhir_state * (Ast.Program.decl)
  
  and ('s, 'r) _menhir_cell1_filename = 
    | MenhirCell1_filename of 's * ('s, 'r) _menhir_state * (string)
  
  and ('s, 'r) _menhir_cell1_head_term = 
    | MenhirCell1_head_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_i_o = 
    | MenhirCell1_i_o of 's * ('s, 'r) _menhir_state * (bool)
  
  and ('s, 'r) _menhir_cell1_indexing = 
    | MenhirCell1_indexing of 's * ('s, 'r) _menhir_state * (int)
  
  and ('s, 'r) _menhir_cell1_list_sequent_ = 
    | MenhirCell1_list_sequent_ of 's * ('s, 'r) _menhir_state * (Ast.Chr.sequent list)
  
  and ('s, 'r) _menhir_cell1_nonempty_list_closed_term_ = 
    | MenhirCell1_nonempty_list_closed_term_ of 's * ('s, 'r) _menhir_state * (Ast.Term.t list)
  
  and 's _menhir_cell0_option_CONJ_ = 
    | MenhirCell0_option_CONJ_ of 's * (unit option)
  
  and 's _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ = 
    | MenhirCell0_option_preceded_BIND_nonempty_list_sequent___ of 's * (Ast.Chr.sequent list option)
  
  and 's _menhir_cell0_option_preceded_PIPE_term__ = 
    | MenhirCell0_option_preceded_PIPE_term__ of 's * (Ast.Term.t option)
  
  and ('s, 'r) _menhir_cell1_pred_item = 
    | MenhirCell1_pred_item of 's * ('s, 'r) _menhir_state * (bool * Ast.Term.t) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_separated_nonempty_list_CONJ_constant_ = 
    | MenhirCell1_separated_nonempty_list_CONJ_constant_ of 's * ('s, 'r) _menhir_state * (Ast.Func.t list) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_sequent = 
    | MenhirCell1_sequent of 's * ('s, 'r) _menhir_state * (Ast.Chr.sequent) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_subtrie = 
    | MenhirCell1_subtrie of 's * ('s, 'r) _menhir_state * ((string * string) list)
  
  and ('s, 'r) _menhir_cell1_term = 
    | MenhirCell1_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_term_noconj = 
    | MenhirCell1_term_noconj of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_type_term = 
    | MenhirCell1_type_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_ARROW = 
    | MenhirCell0_ARROW of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BIND = 
    | MenhirCell1_BIND of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_BIND = 
    | MenhirCell0_BIND of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_CLOSED = 
    | MenhirCell1_CLOSED of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_COLON = 
    | MenhirCell1_COLON of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_COLON = 
    | MenhirCell0_COLON of 's * Lexing.position
  
  and 's _menhir_cell0_CONJ = 
    | MenhirCell0_CONJ of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_CONJ2 = 
    | MenhirCell0_CONJ2 of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_CONS = 
    | MenhirCell0_CONS of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_CONSTRAINT = 
    | MenhirCell1_CONSTRAINT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_DARROW = 
    | MenhirCell0_DARROW of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_DIV = 
    | MenhirCell0_DIV of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_EQ = 
    | MenhirCell0_EQ of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_EQ2 = 
    | MenhirCell0_EQ2 of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_EXPORTDEF = 
    | MenhirCell1_EXPORTDEF of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_FAMILY_AND = 
    | MenhirCell0_FAMILY_AND of 's * (
# 84 "src/parser/tokens.mly"
       (string)
# 1104 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_BTICK = 
    | MenhirCell0_FAMILY_BTICK of 's * (
# 80 "src/parser/tokens.mly"
       (string)
# 1111 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_EQ = 
    | MenhirCell0_FAMILY_EQ of 's * (
# 78 "src/parser/tokens.mly"
       (string)
# 1118 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_EXP = 
    | MenhirCell0_FAMILY_EXP of 's * (
# 75 "src/parser/tokens.mly"
       (string)
# 1125 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_GT = 
    | MenhirCell0_FAMILY_GT of 's * (
# 77 "src/parser/tokens.mly"
       (string)
# 1132 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_LT = 
    | MenhirCell0_FAMILY_LT of 's * (
# 76 "src/parser/tokens.mly"
       (string)
# 1139 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_MINUS = 
    | MenhirCell0_FAMILY_MINUS of 's * (
# 74 "src/parser/tokens.mly"
       (string)
# 1146 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_OR = 
    | MenhirCell0_FAMILY_OR of 's * (
# 85 "src/parser/tokens.mly"
       (string)
# 1153 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_PLUS = 
    | MenhirCell0_FAMILY_PLUS of 's * (
# 72 "src/parser/tokens.mly"
       (string)
# 1160 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_SHARP = 
    | MenhirCell0_FAMILY_SHARP of 's * (
# 82 "src/parser/tokens.mly"
       (string)
# 1167 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_TICK = 
    | MenhirCell0_FAMILY_TICK of 's * (
# 81 "src/parser/tokens.mly"
       (string)
# 1174 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_FAMILY_TILDE = 
    | MenhirCell1_FAMILY_TILDE of 's * ('s, 'r) _menhir_state * (
# 83 "src/parser/tokens.mly"
       (string)
# 1181 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_TIMES = 
    | MenhirCell0_FAMILY_TIMES of 's * (
# 73 "src/parser/tokens.mly"
       (string)
# 1188 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_FIXITY = 
    | MenhirCell1_FIXITY of 's * ('s, 'r) _menhir_state * (
# 54 "src/parser/tokens.mly"
       (string)
# 1195 "src/parser/grammar.ml"
  ) * Lexing.position
  
  and 's _menhir_cell0_FULLSTOP = 
    | MenhirCell0_FULLSTOP of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_INDEX = 
    | MenhirCell1_INDEX of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IO_COLON = 
    | MenhirCell1_IO_COLON of 's * ('s, 'r) _menhir_state * (
# 21 "src/parser/tokens.mly"
       (char)
# 1208 "src/parser/grammar.ml"
  )
  
  and 's _menhir_cell0_IS = 
    | MenhirCell0_IS of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_KIND = 
    | MenhirCell1_KIND of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LBRACKET = 
    | MenhirCell1_LBRACKET of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LCURLY = 
    | MenhirCell1_LCURLY of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_LCURLY = 
    | MenhirCell0_LCURLY of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LOCAL = 
    | MenhirCell1_LOCAL of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_LOCALKIND = 
    | MenhirCell1_LOCALKIND of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LPAREN = 
    | MenhirCell1_LPAREN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_LPAREN = 
    | MenhirCell0_LPAREN of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_MACRO = 
    | MenhirCell1_MACRO of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_MINUS = 
    | MenhirCell0_MINUS of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_MINUSi = 
    | MenhirCell0_MINUSi of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_MINUSr = 
    | MenhirCell0_MINUSr of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_MINUSs = 
    | MenhirCell0_MINUSs of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_MOD = 
    | MenhirCell0_MOD of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_MODE = 
    | MenhirCell1_MODE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_MODULE = 
    | MenhirCell1_MODULE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_NAMESPACE = 
    | MenhirCell1_NAMESPACE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_OR = 
    | MenhirCell0_OR of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_PIPE = 
    | MenhirCell1_PIPE of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_PRED = 
    | MenhirCell1_PRED of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_QDASH = 
    | MenhirCell0_QDASH of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RULE = 
    | MenhirCell1_RULE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_SHORTEN = 
    | MenhirCell1_SHORTEN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_SIG = 
    | MenhirCell1_SIG of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_SLASH = 
    | MenhirCell0_SLASH of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_TYPE = 
    | MenhirCell1_TYPE of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_TYPEABBREV = 
    | MenhirCell1_TYPEABBREV of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_USEONLY = 
    | MenhirCell1_USEONLY of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_VDASH = 
    | MenhirCell0_VDASH of 's * Lexing.position * Lexing.position
  
  and _menhir_box_program = 
    | MenhirBox_program of (Ast.Program.t) [@@unboxed]
  
  and _menhir_box_prefix_SYMB = 
    | MenhirBox_prefix_SYMB of (Ast.Func.t) [@@unboxed]
  
  and _menhir_box_postfix_SYMB = 
    | MenhirBox_postfix_SYMB of (Ast.Func.t) [@@unboxed]
  
  and _menhir_box_infix_SYMB = 
    | MenhirBox_infix_SYMB of (Ast.Func.t) [@@unboxed]
  
  and _menhir_box_goal = 
    | MenhirBox_goal of (Ast.Goal.t) [@@unboxed]
  
  let _menhir_action_005 =
    fun c ->
      (
# 225 "src/parser/grammar.mly"
               ( c, [] )
# 1321 "src/parser/grammar.ml"
       : (Ast.Func.t * Ast.Func.t list))
  
  let _menhir_action_006 =
    fun args hd ->
      (
# 226 "src/parser/grammar.mly"
                                                                ( hd, args  )
# 1329 "src/parser/grammar.ml"
       : (Ast.Func.t * Ast.Func.t list))
  
  let _menhir_action_007 =
    fun () ->
      (
# 143 "src/parser/grammar.mly"
             ( ".elpi" )
# 1337 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_008 =
    fun () ->
      (
# 144 "src/parser/grammar.mly"
         ( ".mod" )
# 1345 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_009 =
    fun () ->
      (
# 145 "src/parser/grammar.mly"
            ( ".sig" )
# 1353 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_010 =
    fun () ->
      (
# 146 "src/parser/grammar.mly"
          ( ".sig" )
# 1361 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_011 =
    fun s ->
      (
# 293 "src/parser/grammar.mly"
                 ( If s )
# 1369 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_012 =
    fun s ->
      (
# 294 "src/parser/grammar.mly"
                    ( Name s )
# 1377 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_013 =
    fun s ->
      (
# 295 "src/parser/grammar.mly"
                    ( After s )
# 1385 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_014 =
    fun s ->
      (
# 296 "src/parser/grammar.mly"
                     ( Before s )
# 1393 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_015 =
    fun () ->
      (
# 297 "src/parser/grammar.mly"
           ( External )
# 1401 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_016 =
    fun l ->
      (
# 298 "src/parser/grammar.mly"
                                                      ( Index l )
# 1409 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_017 =
    fun () ->
      (
# 288 "src/parser/grammar.mly"
  ( [] )
# 1417 "src/parser/grammar.ml"
       : (Ast.raw_attribute list))
  
  let _menhir_action_018 =
    fun () ->
      (
# 289 "src/parser/grammar.mly"
           ( [ External ] )
# 1425 "src/parser/grammar.ml"
       : (Ast.raw_attribute list))
  
  let _menhir_action_019 =
    fun l ->
      (
# 290 "src/parser/grammar.mly"
                                                       ( l )
# 1433 "src/parser/grammar.ml"
       : (Ast.raw_attribute list))
  
  let _menhir_action_020 =
    fun c ->
      (
# 186 "src/parser/grammar.mly"
             ( mkC (cstring.Util.CData.cin c) )
# 1441 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_021 =
    fun c ->
      (
# 187 "src/parser/grammar.mly"
               ( Const (fix_church c) )
# 1449 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_022 =
    fun t ->
      (
# 188 "src/parser/grammar.mly"
                                ( t )
# 1457 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_023 =
    fun _endpos_bind_ _startpos_bind_ b bind ->
      let _loc_bind_ = (_startpos_bind_, _endpos_bind_) in
      (
# 343 "src/parser/grammar.mly"
                        ( (loc _loc_bind_, b) )
# 1466 "src/parser/grammar.ml"
       : (Ast.Loc.t * Ast.Term.t))
  
  let _menhir_action_024 =
    fun b t ->
      (
# 340 "src/parser/grammar.mly"
                                ( mkLam (Func.show t) (snd b) )
# 1474 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_025 =
    fun b t ->
      (
# 346 "src/parser/grammar.mly"
                               ( mkLam (Func.show t) b )
# 1482 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_026 =
    fun _endpos_attributes_ _endpos_new_goal_ _startpos__2_ _startpos_attributes_ attributes guard new_goal to_match to_remove ->
      let _endpos = _endpos_new_goal_ in
      let _symbolstartpos = if _startpos_attributes_ != _endpos_attributes_ then
        _startpos_attributes_
      else
        _startpos__2_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 157 "src/parser/grammar.mly"
                                    (
    { Chr.to_match; to_remove = Util.option_default [] to_remove; guard; new_goal; attributes; loc=(loc _sloc) }
  )
# 1498 "src/parser/grammar.ml"
       : (Ast.raw_attribute list Ast.Chr.t))
  
  let _menhir_action_027 =
    fun _endpos_attributes_ _endpos_body_ _startpos_attributes_ _startpos_body_ attributes body ->
      let _endpos = _endpos_body_ in
      let _symbolstartpos = if _startpos_attributes_ != _endpos_attributes_ then
        _startpos_attributes_
      else
        _startpos_body_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 274 "src/parser/grammar.mly"
                                                  (
    { Clause.loc = loc _sloc;
      attributes;
      body;
    }
  )
# 1517 "src/parser/grammar.ml"
       : ((Ast.Term.t, Ast.raw_attribute list) Ast.Clause.t))
  
  let _menhir_action_028 =
    fun _endpos_attributes_ _endpos_r_ _startpos_attributes_ _startpos_l_ attributes l r ->
      let _endpos = _endpos_r_ in
      let _symbolstartpos = if _startpos_attributes_ != _endpos_attributes_ then
        _startpos_attributes_
      else
        _startpos_l_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 280 "src/parser/grammar.mly"
                                                               ( 
    { Clause.loc = loc _sloc;
      attributes;
      body = App(Const Func.rimplf,[l;r])
    }
)
# 1536 "src/parser/grammar.ml"
       : ((Ast.Term.t, Ast.raw_attribute list) Ast.Clause.t))
  
  let _menhir_action_029 =
    fun t ->
      (
# 374 "src/parser/grammar.mly"
               ( Const t )
# 1544 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_030 =
    fun t ->
      (
# 375 "src/parser/grammar.mly"
                           ( t )
# 1552 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_031 =
    fun _endpos_hd_ _startpos_hd_ args b hd ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 378 "src/parser/grammar.mly"
                                                                             (
    let args = binder args b in
    let t = mkApp (loc _loc_hd_) (hd :: args) in
    desugar_multi_binder (loc _loc_hd_) t
)
# 1565 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_032 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 439 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1574 "src/parser/grammar.ml"
         in
        
# 435 "src/parser/grammar.mly"
                       ( x )
# 1579 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1588 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_033 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 440 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1597 "src/parser/grammar.ml"
         in
        
# 435 "src/parser/grammar.mly"
                       ( x )
# 1602 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1611 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_034 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 441 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1620 "src/parser/grammar.ml"
         in
        
# 435 "src/parser/grammar.mly"
                       ( x )
# 1625 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1634 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_035 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 442 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1643 "src/parser/grammar.ml"
         in
        
# 435 "src/parser/grammar.mly"
                       ( x )
# 1648 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1657 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_036 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 443 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1666 "src/parser/grammar.ml"
         in
        
# 435 "src/parser/grammar.mly"
                       ( x )
# 1671 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1680 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_037 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 444 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1689 "src/parser/grammar.ml"
         in
        
# 435 "src/parser/grammar.mly"
                       ( x )
# 1694 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1703 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_038 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 445 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1712 "src/parser/grammar.ml"
         in
        
# 435 "src/parser/grammar.mly"
                       ( x )
# 1717 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1726 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_039 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 446 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1735 "src/parser/grammar.ml"
         in
        
# 435 "src/parser/grammar.mly"
                       ( x )
# 1740 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1749 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_040 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 447 "src/parser/grammar.mly"
                  ( Func.from_string s )
# 1758 "src/parser/grammar.ml"
         in
        
# 435 "src/parser/grammar.mly"
                       ( x )
# 1763 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1772 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_041 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 448 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1781 "src/parser/grammar.ml"
         in
        
# 435 "src/parser/grammar.mly"
                       ( x )
# 1786 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1795 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_042 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 449 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1804 "src/parser/grammar.ml"
         in
        
# 435 "src/parser/grammar.mly"
                       ( x )
# 1809 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1818 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_043 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 450 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1827 "src/parser/grammar.ml"
         in
        
# 435 "src/parser/grammar.mly"
                       ( x )
# 1832 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1841 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_044 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 453 "src/parser/grammar.mly"
         ( Func.consf )
# 1851 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 1856 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 1862 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1871 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_045 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 454 "src/parser/grammar.mly"
         ( Func.eqf )
# 1881 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 1886 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 1892 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1901 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_046 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 455 "src/parser/grammar.mly"
         ( Func.from_string "-" )
# 1911 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 1916 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 1922 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1931 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_047 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 456 "src/parser/grammar.mly"
         ( Func.from_string "r-" )
# 1941 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 1946 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 1952 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1961 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_048 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 457 "src/parser/grammar.mly"
         ( Func.from_string "i-" )
# 1971 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 1976 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 1982 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1991 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_049 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 458 "src/parser/grammar.mly"
         ( Func.from_string "s-" )
# 2001 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 2006 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 2012 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2021 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_050 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 459 "src/parser/grammar.mly"
         ( Func.from_string "==" )
# 2031 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 2036 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 2042 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2051 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_051 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 460 "src/parser/grammar.mly"
         ( Func.orf )
# 2061 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 2066 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 2072 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2081 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_052 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 461 "src/parser/grammar.mly"
         ( Func.isf )
# 2091 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 2096 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 2102 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2111 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_053 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 462 "src/parser/grammar.mly"
         ( Func.from_string "mod" )
# 2121 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 2126 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 2132 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2141 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_054 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 463 "src/parser/grammar.mly"
         ( Func.from_string "div" )
# 2151 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 2156 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 2162 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2171 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_055 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 464 "src/parser/grammar.mly"
         ( Func.arrowf )
# 2181 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 2186 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 2192 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2201 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_056 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 465 "src/parser/grammar.mly"
         ( Func.implf )
# 2211 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 2216 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 2222 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2231 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_057 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 466 "src/parser/grammar.mly"
         ( Func.sequentf )
# 2241 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 2246 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 2252 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2261 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_058 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 467 "src/parser/grammar.mly"
         ( Func.from_string "/" )
# 2271 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 2276 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 2282 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2291 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_059 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 468 "src/parser/grammar.mly"
         ( Func.andf )
# 2301 "src/parser/grammar.ml"
           in
          
# 471 "src/parser/grammar.mly"
                                          ( x )
# 2306 "src/parser/grammar.ml"
          
        in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 2312 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2321 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_060 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x = 
# 472 "src/parser/grammar.mly"
         ( Func.andf )
# 2330 "src/parser/grammar.ml"
         in
        
# 436 "src/parser/grammar.mly"
                                   ( x )
# 2335 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 383 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2344 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_061 =
    fun r s ->
      let s =
        let x = 
# 483 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 2353 "src/parser/grammar.ml"
         in
        
# 421 "src/parser/grammar.mly"
                        ( x )
# 2358 "src/parser/grammar.ml"
        
      in
      (
# 384 "src/parser/grammar.mly"
                       ( App(Const s,[r]) )
# 2364 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_062 =
    fun l s ->
      let s =
        let x = 
# 486 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 2373 "src/parser/grammar.ml"
         in
        
# 424 "src/parser/grammar.mly"
                         ( x )
# 2378 "src/parser/grammar.ml"
        
      in
      (
# 385 "src/parser/grammar.mly"
                                   ( App(Const s,[l]) )
# 2384 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_063 =
    fun t ->
      (
# 370 "src/parser/grammar.mly"
                          ( t )
# 2392 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_064 =
    fun t ->
      (
# 371 "src/parser/grammar.mly"
                            ( t )
# 2400 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_065 =
    fun x ->
      (
# 315 "src/parser/grammar.mly"
              ( mkC (cint.Util.CData.cin x))
# 2408 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_066 =
    fun x ->
      (
# 316 "src/parser/grammar.mly"
            ( mkC (cfloat.Util.CData.cin x))
# 2416 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_067 =
    fun x ->
      (
# 317 "src/parser/grammar.mly"
             ( mkC (cstring.Util.CData.cin x))
# 2424 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_068 =
    fun _endpos_x_ _startpos_x_ x ->
      let _endpos = _endpos_x_ in
      let _startpos = _startpos_x_ in
      let _loc = (_startpos, _endpos) in
      (
# 318 "src/parser/grammar.mly"
             ( mkQuoted (loc _loc) x )
# 2435 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_069 =
    fun c t ->
      (
# 319 "src/parser/grammar.mly"
                                         ( App(mkCon "as",[t;c]) )
# 2443 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_070 =
    fun l ->
      (
# 320 "src/parser/grammar.mly"
                           ( mkSeq l )
# 2451 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_071 =
    fun l ->
      (
# 321 "src/parser/grammar.mly"
                                  (  mkSeq l )
# 2459 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_072 =
    fun t ->
      (
# 322 "src/parser/grammar.mly"
                           ( App (Const Func.spillf,[t]) )
# 2467 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_073 =
    fun t ->
      (
# 323 "src/parser/grammar.mly"
                ( t )
# 2475 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_074 =
    fun c ->
      (
# 388 "src/parser/grammar.mly"
               (
    if c = "nil" then Func.nilf
    else if c = "cons" then Func.consf
    else Func.from_string c )
# 2486 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_075 =
    fun () ->
      (
# 392 "src/parser/grammar.mly"
     ( Func.from_string "if" )
# 2494 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_076 =
    fun () ->
      (
# 393 "src/parser/grammar.mly"
       ( Func.from_string "name" )
# 2502 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_077 =
    fun () ->
      (
# 394 "src/parser/grammar.mly"
         ( Func.from_string "before" )
# 2510 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_078 =
    fun () ->
      (
# 395 "src/parser/grammar.mly"
        ( Func.from_string "after" )
# 2518 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_079 =
    fun () ->
      (
# 396 "src/parser/grammar.mly"
        ( Func.from_string "index" )
# 2526 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_080 =
    fun c ->
      (
# 397 "src/parser/grammar.mly"
         ( Func.from_string @@ String.make 1 c )
# 2534 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_081 =
    fun () ->
      (
# 398 "src/parser/grammar.mly"
      ( Func.cutf )
# 2542 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_082 =
    fun () ->
      (
# 399 "src/parser/grammar.mly"
     ( Func.pif )
# 2550 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_083 =
    fun () ->
      (
# 400 "src/parser/grammar.mly"
        ( Func.sigmaf )
# 2558 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_084 =
    fun () ->
      (
# 401 "src/parser/grammar.mly"
          ( Func.dummyname )
# 2566 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_085 =
    fun s ->
      (
# 402 "src/parser/grammar.mly"
                                  ( s )
# 2574 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_086 =
    fun () ->
      (
# 403 "src/parser/grammar.mly"
                      ( Func.from_string "as" )
# 2582 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_087 =
    fun () ->
      (
# 404 "src/parser/grammar.mly"
      ( Func.nilf )
# 2590 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_088 =
    fun c ->
      (
# 118 "src/parser/grammar.mly"
                       ( Program.Clause c )
# 2598 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_089 =
    fun r ->
      (
# 119 "src/parser/grammar.mly"
                         ( Program.Chr r )
# 2606 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_090 =
    fun p ->
      (
# 120 "src/parser/grammar.mly"
                     ( Program.Pred (snd p, fst p) )
# 2614 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_091 =
    fun t ->
      (
# 121 "src/parser/grammar.mly"
                      ( Program.Type t )
# 2622 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_092 =
    fun t ->
      (
# 122 "src/parser/grammar.mly"
                     ( Program.Type t )
# 2630 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_093 =
    fun m ->
      (
# 123 "src/parser/grammar.mly"
                     ( Program.Mode [m] )
# 2638 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_094 =
    fun m ->
      (
# 124 "src/parser/grammar.mly"
                      ( Program.Macro m )
# 2646 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_095 =
    fun _endpos__3_ _startpos__1_ cl ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 125 "src/parser/grammar.mly"
                                          ( Program.Constraint(loc _sloc, cl) )
# 2657 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_096 =
    fun _endpos__3_ _startpos__1_ c ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 126 "src/parser/grammar.mly"
                                  ( Program.Namespace(loc _sloc, c ))
# 2668 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_097 =
    fun _endpos__3_ _startpos__1_ s ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 127 "src/parser/grammar.mly"
                                 ( Program.Shorten(loc _sloc, s) )
# 2679 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_098 =
    fun a ->
      (
# 128 "src/parser/grammar.mly"
                           ( Program.TypeAbbreviation a )
# 2687 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_099 =
    fun _endpos__1_ _startpos__1_ ->
      let _endpos = _endpos__1_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 129 "src/parser/grammar.mly"
         ( Program.Begin (loc _sloc) )
# 2698 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_100 =
    fun _endpos__1_ _startpos__1_ ->
      let _endpos = _endpos__1_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 130 "src/parser/grammar.mly"
         ( Program.End (loc _sloc) )
# 2709 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_101 =
    fun _endpos__3_ _startpos_ext_ ext l ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos_ext_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 131 "src/parser/grammar.mly"
                                                                         (
    Program.Accumulated(loc _sloc,List.(concat (map (fun x ->
      let cwd = Filename.dirname (loc _sloc).source_name in
      C.parse_file ~cwd (x ^ ext)) l)))
  )
# 2724 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_102 =
    fun l ->
      (
# 136 "src/parser/grammar.mly"
                                                                                 (
    Program.Local l
  )
# 2734 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_103 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 139 "src/parser/grammar.mly"
                    ( Program.Ignored (loc _sloc) )
# 2745 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_104 =
    fun _endpos__2_ _startpos_f_ f ->
      let _endpos = _endpos__2_ in
      let _startpos = _startpos_f_ in
      let _loc = (_startpos, _endpos) in
      (
# 140 "src/parser/grammar.mly"
                       ( error_mixfix (loc _loc) )
# 2756 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_105 =
    fun c ->
      (
# 149 "src/parser/grammar.mly"
               ( Func.show c )
# 2764 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_106 =
    fun s ->
      (
# 150 "src/parser/grammar.mly"
             ( s )
# 2772 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_107 =
    fun _endpos_c_ _startpos_c_ c f i ->
      let _loc_c_ = (_startpos_c_, _endpos_c_) in
      (
# 241 "src/parser/grammar.mly"
                                        ( (fixity_of_string f,c,i,loc _loc_c_) )
# 2781 "src/parser/grammar.ml"
       : (Elpi_lexer_config.Lexer_config.fixity * Ast.Func.t * int * Ast.Loc.t))
  
  let _menhir_action_108 =
    fun _endpos_c_ _startpos_c_ c f i ->
      let _loc_c_ = (_startpos_c_, _endpos_c_) in
      (
# 242 "src/parser/grammar.mly"
                                           ( (fixity_of_string f,c,i,loc _loc_c_) )
# 2790 "src/parser/grammar.ml"
       : (Elpi_lexer_config.Lexer_config.fixity * Ast.Func.t * int * Ast.Loc.t))
  
  let _menhir_action_109 =
    fun _endpos__2_ _startpos_g_ g ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos_g_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 270 "src/parser/grammar.mly"
                ( ( loc _sloc , g ) )
# 2801 "src/parser/grammar.ml"
       : (Ast.Goal.t))
  
  let _menhir_action_110 =
    fun _endpos__2_ _startpos_g_ g ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos_g_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 271 "src/parser/grammar.mly"
                     ( ( loc _sloc , g ) )
# 2812 "src/parser/grammar.ml"
       : (Ast.Goal.t))
  
  let _menhir_action_111 =
    fun t ->
      (
# 326 "src/parser/grammar.mly"
               ( Const t )
# 2820 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_112 =
    fun t ->
      (
# 327 "src/parser/grammar.mly"
                           ( t )
# 2828 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_113 =
    fun io ->
      (
# 204 "src/parser/grammar.mly"
          ( mode_of_IO io )
# 2836 "src/parser/grammar.ml"
       : (bool))
  
  let _menhir_action_114 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2847 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_115 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2858 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_116 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2869 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_117 =
    fun _endpos__3_ _startpos__1_ ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2880 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_118 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2891 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_119 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2902 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_120 =
    fun _endpos__3_ _startpos__1_ ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2913 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_121 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2924 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_122 =
    fun () ->
      (
# 301 "src/parser/grammar.mly"
          ( 0 )
# 2932 "src/parser/grammar.ml"
       : (int))
  
  let _menhir_action_123 =
    fun i ->
      (
# 302 "src/parser/grammar.mly"
              ( i )
# 2940 "src/parser/grammar.ml"
       : (int))
  
  let _menhir_action_124 =
    fun s ->
      let x =
        let x = 
# 439 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 2949 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 2954 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 2960 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_125 =
    fun s ->
      let x =
        let x = 
# 440 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 2969 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 2974 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 2980 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_126 =
    fun s ->
      let x =
        let x = 
# 441 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 2989 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 2994 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3000 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_127 =
    fun s ->
      let x =
        let x = 
# 442 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3009 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 3014 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3020 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_128 =
    fun s ->
      let x =
        let x = 
# 443 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3029 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 3034 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3040 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_129 =
    fun s ->
      let x =
        let x = 
# 444 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3049 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 3054 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3060 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_130 =
    fun s ->
      let x =
        let x = 
# 445 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3069 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 3074 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3080 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_131 =
    fun s ->
      let x =
        let x = 
# 446 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3089 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 3094 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3100 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_132 =
    fun s ->
      let x =
        let x = 
# 447 "src/parser/grammar.mly"
                  ( Func.from_string s )
# 3109 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 3114 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3120 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_133 =
    fun s ->
      let x =
        let x = 
# 448 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3129 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 3134 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3140 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_134 =
    fun s ->
      let x =
        let x = 
# 449 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3149 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 3154 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3160 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_135 =
    fun s ->
      let x =
        let x = 
# 450 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3169 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 3174 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3180 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_136 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 453 "src/parser/grammar.mly"
         ( Func.consf )
# 3191 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3196 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3202 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3208 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3214 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_137 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 454 "src/parser/grammar.mly"
         ( Func.eqf )
# 3225 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3230 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3236 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3242 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3248 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_138 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 455 "src/parser/grammar.mly"
         ( Func.from_string "-" )
# 3259 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3264 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3270 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3276 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3282 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_139 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 456 "src/parser/grammar.mly"
         ( Func.from_string "r-" )
# 3293 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3298 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3304 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3310 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3316 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_140 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 457 "src/parser/grammar.mly"
         ( Func.from_string "i-" )
# 3327 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3332 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3338 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3344 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3350 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_141 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 458 "src/parser/grammar.mly"
         ( Func.from_string "s-" )
# 3361 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3366 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3372 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3378 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3384 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_142 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 459 "src/parser/grammar.mly"
         ( Func.from_string "==" )
# 3395 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3400 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3406 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3412 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3418 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_143 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 460 "src/parser/grammar.mly"
         ( Func.orf )
# 3429 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3434 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3440 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3446 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3452 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_144 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 461 "src/parser/grammar.mly"
         ( Func.isf )
# 3463 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3468 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3474 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3480 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3486 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_145 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 462 "src/parser/grammar.mly"
         ( Func.from_string "mod" )
# 3497 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3502 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3508 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3514 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3520 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_146 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 463 "src/parser/grammar.mly"
         ( Func.from_string "div" )
# 3531 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3536 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3542 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3548 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3554 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_147 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 464 "src/parser/grammar.mly"
         ( Func.arrowf )
# 3565 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3570 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3576 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3582 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3588 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_148 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 465 "src/parser/grammar.mly"
         ( Func.implf )
# 3599 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3604 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3610 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3616 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3622 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_149 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 466 "src/parser/grammar.mly"
         ( Func.sequentf )
# 3633 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3638 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3644 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3650 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3656 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_150 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 467 "src/parser/grammar.mly"
         ( Func.from_string "/" )
# 3667 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3672 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3678 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3684 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3690 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_151 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 468 "src/parser/grammar.mly"
         ( Func.andf )
# 3701 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 3706 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3712 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3718 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3724 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_152 =
    fun () ->
      let x =
        let x =
          let x = 
# 472 "src/parser/grammar.mly"
         ( Func.andf )
# 3734 "src/parser/grammar.ml"
           in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 3739 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3745 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3751 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_153 =
    fun () ->
      let x =
        let x = 
# 480 "src/parser/grammar.mly"
         ( Func.rimplf )
# 3760 "src/parser/grammar.ml"
         in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 3765 "src/parser/grammar.ml"
        
      in
      (
# 412 "src/parser/grammar.mly"
            ( x )
# 3771 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_154 =
    fun _endpos_k_ _startpos__1_ k names ->
      let _endpos = _endpos_k_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 174 "src/parser/grammar.mly"
                                                                      (
    names |> List.map (fun n->
     { Type.loc=loc _sloc; attributes=[]; name =  n; ty = k })
  )
# 3785 "src/parser/grammar.ml"
       : (Ast.raw_attribute list Ast.Type.t list))
  
  let _menhir_action_155 =
    fun () ->
      (
# 196 "src/parser/grammar.mly"
       ( mkCon "type" )
# 3793 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_156 =
    fun _endpos_hd_ _startpos_hd_ hd t ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 197 "src/parser/grammar.mly"
                                  ( mkApp (loc _loc_hd_) [mkCon "->"; mkCon "type"; t] )
# 3802 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_157 =
    fun () ->
      (
# 208 "<standard.mly>"
    ( [] )
# 3810 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_158 =
    fun x xs ->
      (
# 210 "<standard.mly>"
    ( x :: xs )
# 3818 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_159 =
    fun () ->
      (
# 208 "<standard.mly>"
    ( [] )
# 3826 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list))
  
  let _menhir_action_160 =
    fun x xs ->
      (
# 210 "<standard.mly>"
    ( x :: xs )
# 3834 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list))
  
  let _menhir_action_161 =
    fun () ->
      (
# 330 "src/parser/grammar.mly"
           ( [mkNil] )
# 3842 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_162 =
    fun x ->
      (
# 331 "src/parser/grammar.mly"
                            ( [x;mkNil] )
# 3850 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_163 =
    fun x xs ->
      (
# 332 "src/parser/grammar.mly"
                                         ( x :: xs )
# 3858 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_164 =
    fun x ->
      (
# 335 "src/parser/grammar.mly"
                                  ( [x] )
# 3866 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_165 =
    fun x xs ->
      (
# 336 "src/parser/grammar.mly"
                                                    ( [x;xs] )
# 3874 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_166 =
    fun x xs ->
      (
# 337 "src/parser/grammar.mly"
                                              ( x :: xs )
# 3882 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_167 =
    fun () ->
      (
# 139 "<standard.mly>"
    ( [] )
# 3890 "src/parser/grammar.ml"
       : ((bool * Ast.Term.t) list))
  
  let _menhir_action_168 =
    fun x ->
      (
# 141 "<standard.mly>"
    ( x )
# 3898 "src/parser/grammar.ml"
       : ((bool * Ast.Term.t) list))
  
  let _menhir_action_169 =
    fun _endpos_b_ _startpos__1_ b m ->
      let _endpos = _endpos_b_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 207 "src/parser/grammar.mly"
                                   (
  let name, body = desugar_macro (loc _sloc) m b in
  { Macro.loc = loc _sloc; name; body }
)
# 3912 "src/parser/grammar.ml"
       : ((Ast.Func.t, Ast.Term.t) Ast.Macro.t))
  
  let _menhir_action_170 =
    fun s ->
      let x =
        let x = 
# 439 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3921 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 3926 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 3932 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_171 =
    fun s ->
      let x =
        let x = 
# 440 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3941 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 3946 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 3952 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_172 =
    fun s ->
      let x =
        let x = 
# 441 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3961 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 3966 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 3972 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_173 =
    fun s ->
      let x =
        let x = 
# 442 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3981 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 3986 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 3992 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_174 =
    fun s ->
      let x =
        let x = 
# 443 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4001 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 4006 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4012 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_175 =
    fun s ->
      let x =
        let x = 
# 444 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4021 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 4026 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4032 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_176 =
    fun s ->
      let x =
        let x = 
# 445 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4041 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 4046 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4052 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_177 =
    fun s ->
      let x =
        let x = 
# 446 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4061 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 4066 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4072 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_178 =
    fun s ->
      let x =
        let x = 
# 447 "src/parser/grammar.mly"
                  ( Func.from_string s )
# 4081 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 4086 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4092 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_179 =
    fun s ->
      let x =
        let x = 
# 448 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4101 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 4106 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4112 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_180 =
    fun s ->
      let x =
        let x = 
# 449 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4121 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 4126 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4132 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_181 =
    fun s ->
      let x =
        let x = 
# 450 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4141 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 4146 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4152 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_182 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 453 "src/parser/grammar.mly"
         ( Func.consf )
# 4163 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4168 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4174 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4180 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4186 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_183 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 454 "src/parser/grammar.mly"
         ( Func.eqf )
# 4197 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4202 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4208 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4214 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4220 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_184 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 455 "src/parser/grammar.mly"
         ( Func.from_string "-" )
# 4231 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4236 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4242 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4248 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4254 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_185 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 456 "src/parser/grammar.mly"
         ( Func.from_string "r-" )
# 4265 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4270 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4276 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4282 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4288 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_186 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 457 "src/parser/grammar.mly"
         ( Func.from_string "i-" )
# 4299 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4304 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4310 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4316 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4322 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_187 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 458 "src/parser/grammar.mly"
         ( Func.from_string "s-" )
# 4333 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4338 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4344 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4350 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4356 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_188 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 459 "src/parser/grammar.mly"
         ( Func.from_string "==" )
# 4367 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4372 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4378 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4384 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4390 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_189 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 460 "src/parser/grammar.mly"
         ( Func.orf )
# 4401 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4406 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4412 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4418 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4424 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_190 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 461 "src/parser/grammar.mly"
         ( Func.isf )
# 4435 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4440 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4446 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4452 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4458 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_191 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 462 "src/parser/grammar.mly"
         ( Func.from_string "mod" )
# 4469 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4474 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4480 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4486 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4492 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_192 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 463 "src/parser/grammar.mly"
         ( Func.from_string "div" )
# 4503 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4508 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4514 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4520 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4526 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_193 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 464 "src/parser/grammar.mly"
         ( Func.arrowf )
# 4537 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4542 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4548 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4554 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4560 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_194 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 465 "src/parser/grammar.mly"
         ( Func.implf )
# 4571 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4576 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4582 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4588 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4594 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_195 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 466 "src/parser/grammar.mly"
         ( Func.sequentf )
# 4605 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4610 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4616 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4622 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4628 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_196 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 467 "src/parser/grammar.mly"
         ( Func.from_string "/" )
# 4639 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4644 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4650 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4656 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4662 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_197 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 468 "src/parser/grammar.mly"
         ( Func.andf )
# 4673 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 4678 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4684 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4690 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4696 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_198 =
    fun () ->
      let x =
        let x =
          let x = 
# 472 "src/parser/grammar.mly"
         ( Func.andf )
# 4706 "src/parser/grammar.ml"
           in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 4711 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4717 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4723 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_199 =
    fun () ->
      let x =
        let x = 
# 480 "src/parser/grammar.mly"
         ( Func.rimplf )
# 4732 "src/parser/grammar.ml"
         in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 4737 "src/parser/grammar.ml"
        
      in
      (
# 407 "src/parser/grammar.mly"
            ( x )
# 4743 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_200 =
    fun s ->
      let x =
        let x = 
# 483 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4752 "src/parser/grammar.ml"
         in
        
# 421 "src/parser/grammar.mly"
                        ( x )
# 4757 "src/parser/grammar.ml"
        
      in
      (
# 408 "src/parser/grammar.mly"
             ( x )
# 4763 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_201 =
    fun s ->
      let x =
        let x = 
# 486 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4772 "src/parser/grammar.ml"
         in
        
# 424 "src/parser/grammar.mly"
                         ( x )
# 4777 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
              ( x )
# 4783 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_202 =
    fun _endpos__5_ _startpos__1_ c l ->
      let _endpos = _endpos__5_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 200 "src/parser/grammar.mly"
                                                             (
    { Mode.name = c; args = l; loc = loc _sloc } 
)
# 4796 "src/parser/grammar.ml"
       : (Ast.Func.t Ast.Mode.t))
  
  let _menhir_action_203 =
    fun x ->
      (
# 218 "<standard.mly>"
    ( [ x ] )
# 4804 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_204 =
    fun x xs ->
      (
# 220 "<standard.mly>"
    ( x :: xs )
# 4812 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_205 =
    fun x ->
      (
# 218 "<standard.mly>"
    ( [ x ] )
# 4820 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_206 =
    fun x xs ->
      (
# 220 "<standard.mly>"
    ( x :: xs )
# 4828 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_207 =
    fun x ->
      (
# 218 "<standard.mly>"
    ( [ x ] )
# 4836 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_208 =
    fun x xs ->
      (
# 220 "<standard.mly>"
    ( x :: xs )
# 4844 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_209 =
    fun x ->
      (
# 218 "<standard.mly>"
    ( [ x ] )
# 4852 "src/parser/grammar.ml"
       : (bool list))
  
  let _menhir_action_210 =
    fun x xs ->
      (
# 220 "<standard.mly>"
    ( x :: xs )
# 4860 "src/parser/grammar.ml"
       : (bool list))
  
  let _menhir_action_211 =
    fun x ->
      (
# 218 "<standard.mly>"
    ( [ x ] )
# 4868 "src/parser/grammar.ml"
       : (int list))
  
  let _menhir_action_212 =
    fun x xs ->
      (
# 220 "<standard.mly>"
    ( x :: xs )
# 4876 "src/parser/grammar.ml"
       : (int list))
  
  let _menhir_action_213 =
    fun x ->
      (
# 218 "<standard.mly>"
    ( [ x ] )
# 4884 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list))
  
  let _menhir_action_214 =
    fun x xs ->
      (
# 220 "<standard.mly>"
    ( x :: xs )
# 4892 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list))
  
  let _menhir_action_215 =
    fun _endpos_hd_ _startpos_hd_ args b hd ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 349 "src/parser/grammar.mly"
                                                                             (
    let args = binder args b in
    let t = mkApp (loc _loc_hd_) (hd :: args) in
    desugar_multi_binder (loc _loc_hd_) t
)
# 4905 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_216 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 439 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4914 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 4919 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 4928 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_217 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 440 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4937 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 4942 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 4951 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_218 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 441 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4960 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 4965 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 4974 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_219 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 442 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4983 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 4988 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 4997 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_220 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 443 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5006 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 5011 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5020 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_221 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 444 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5029 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 5034 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5043 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_222 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 445 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5052 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 5057 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5066 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_223 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 446 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5075 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 5080 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5089 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_224 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 447 "src/parser/grammar.mly"
                  ( Func.from_string s )
# 5098 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 5103 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5112 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_225 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 448 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5121 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 5126 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5135 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_226 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 449 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5144 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 5149 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5158 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_227 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 450 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5167 "src/parser/grammar.ml"
         in
        
# 427 "src/parser/grammar.mly"
                       ( x )
# 5172 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5181 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_228 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 453 "src/parser/grammar.mly"
         ( Func.consf )
# 5192 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5197 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5203 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5209 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5218 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_229 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 454 "src/parser/grammar.mly"
         ( Func.eqf )
# 5229 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5234 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5240 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5246 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5255 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_230 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 455 "src/parser/grammar.mly"
         ( Func.from_string "-" )
# 5266 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5271 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5277 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5283 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5292 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_231 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 456 "src/parser/grammar.mly"
         ( Func.from_string "r-" )
# 5303 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5308 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5314 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5320 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5329 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_232 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 457 "src/parser/grammar.mly"
         ( Func.from_string "i-" )
# 5340 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5345 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5351 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5357 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5366 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_233 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 458 "src/parser/grammar.mly"
         ( Func.from_string "s-" )
# 5377 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5382 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5388 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5394 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5403 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_234 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 459 "src/parser/grammar.mly"
         ( Func.from_string "==" )
# 5414 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5419 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5425 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5431 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5440 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_235 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 460 "src/parser/grammar.mly"
         ( Func.orf )
# 5451 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5456 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5462 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5468 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5477 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_236 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 461 "src/parser/grammar.mly"
         ( Func.isf )
# 5488 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5493 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5499 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5505 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5514 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_237 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 462 "src/parser/grammar.mly"
         ( Func.from_string "mod" )
# 5525 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5530 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5536 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5542 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5551 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_238 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 463 "src/parser/grammar.mly"
         ( Func.from_string "div" )
# 5562 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5567 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5573 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5579 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5588 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_239 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 464 "src/parser/grammar.mly"
         ( Func.arrowf )
# 5599 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5604 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5610 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5616 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5625 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_240 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 465 "src/parser/grammar.mly"
         ( Func.implf )
# 5636 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5641 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5647 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5653 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5662 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_241 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 466 "src/parser/grammar.mly"
         ( Func.sequentf )
# 5673 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5678 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5684 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5690 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5699 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_242 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 467 "src/parser/grammar.mly"
         ( Func.from_string "/" )
# 5710 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5715 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5721 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5727 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5736 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_243 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 468 "src/parser/grammar.mly"
         ( Func.andf )
# 5747 "src/parser/grammar.ml"
             in
            
# 471 "src/parser/grammar.mly"
                                          ( x )
# 5752 "src/parser/grammar.ml"
            
          in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5758 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5764 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5773 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_244 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 472 "src/parser/grammar.mly"
         ( Func.andf )
# 5783 "src/parser/grammar.ml"
           in
          
# 479 "src/parser/grammar.mly"
                                   ( x )
# 5788 "src/parser/grammar.ml"
          
        in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5794 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5803 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_245 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x = 
# 480 "src/parser/grammar.mly"
         ( Func.rimplf )
# 5812 "src/parser/grammar.ml"
         in
        
# 428 "src/parser/grammar.mly"
                           ( x )
# 5817 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 354 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5826 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_246 =
    fun r s ->
      let s =
        let x = 
# 483 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5835 "src/parser/grammar.ml"
         in
        
# 421 "src/parser/grammar.mly"
                        ( x )
# 5840 "src/parser/grammar.ml"
        
      in
      (
# 355 "src/parser/grammar.mly"
                       ( App(Const s,[r]) )
# 5846 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_247 =
    fun l s ->
      let s =
        let x = 
# 486 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5855 "src/parser/grammar.ml"
         in
        
# 424 "src/parser/grammar.mly"
                         ( x )
# 5860 "src/parser/grammar.ml"
        
      in
      (
# 356 "src/parser/grammar.mly"
                         ( App(Const s,[l]) )
# 5866 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_248 =
    fun _endpos_hd_ _startpos_hd_ args b hd ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 359 "src/parser/grammar.mly"
                                                                             (
    let args = binder args b in
    let t = mkApp (loc _loc_hd_) (hd :: args) in
    desugar_multi_binder (loc _loc_hd_) t
)
# 5879 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_249 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 439 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5888 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                       ( x )
# 5893 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 5902 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_250 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 440 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5911 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                       ( x )
# 5916 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 5925 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_251 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 441 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5934 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                       ( x )
# 5939 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 5948 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_252 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 442 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5957 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                       ( x )
# 5962 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 5971 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_253 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 443 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5980 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                       ( x )
# 5985 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 5994 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_254 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 444 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6003 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                       ( x )
# 6008 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6017 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_255 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 445 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6026 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                       ( x )
# 6031 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6040 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_256 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 446 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6049 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                       ( x )
# 6054 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6063 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_257 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 447 "src/parser/grammar.mly"
                  ( Func.from_string s )
# 6072 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                       ( x )
# 6077 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6086 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_258 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 448 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6095 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                       ( x )
# 6100 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6109 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_259 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 449 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6118 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                       ( x )
# 6123 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6132 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_260 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 450 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6141 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                       ( x )
# 6146 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6155 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_261 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 453 "src/parser/grammar.mly"
         ( Func.consf )
# 6165 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6170 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6176 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6185 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_262 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 454 "src/parser/grammar.mly"
         ( Func.eqf )
# 6195 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6200 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6206 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6215 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_263 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 455 "src/parser/grammar.mly"
         ( Func.from_string "-" )
# 6225 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6230 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6236 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6245 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_264 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 456 "src/parser/grammar.mly"
         ( Func.from_string "r-" )
# 6255 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6260 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6266 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6275 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_265 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 457 "src/parser/grammar.mly"
         ( Func.from_string "i-" )
# 6285 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6290 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6296 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6305 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_266 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 458 "src/parser/grammar.mly"
         ( Func.from_string "s-" )
# 6315 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6320 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6326 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6335 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_267 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 459 "src/parser/grammar.mly"
         ( Func.from_string "==" )
# 6345 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6350 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6356 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6365 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_268 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 460 "src/parser/grammar.mly"
         ( Func.orf )
# 6375 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6380 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6386 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6395 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_269 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 461 "src/parser/grammar.mly"
         ( Func.isf )
# 6405 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6410 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6416 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6425 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_270 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 462 "src/parser/grammar.mly"
         ( Func.from_string "mod" )
# 6435 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6440 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6446 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6455 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_271 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 463 "src/parser/grammar.mly"
         ( Func.from_string "div" )
# 6465 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6470 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6476 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6485 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_272 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 464 "src/parser/grammar.mly"
         ( Func.arrowf )
# 6495 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6500 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6506 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6515 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_273 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 465 "src/parser/grammar.mly"
         ( Func.implf )
# 6525 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6530 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6536 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6545 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_274 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 466 "src/parser/grammar.mly"
         ( Func.sequentf )
# 6555 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6560 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6566 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6575 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_275 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 467 "src/parser/grammar.mly"
         ( Func.from_string "/" )
# 6585 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6590 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6596 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6605 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_276 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 468 "src/parser/grammar.mly"
         ( Func.andf )
# 6615 "src/parser/grammar.ml"
           in
          
# 475 "src/parser/grammar.mly"
                                          ( x )
# 6620 "src/parser/grammar.ml"
          
        in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6626 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6635 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_277 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x = 
# 476 "src/parser/grammar.mly"
         ( Func.rimplf )
# 6644 "src/parser/grammar.ml"
         in
        
# 432 "src/parser/grammar.mly"
                                  ( x )
# 6649 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 364 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6658 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_278 =
    fun r s ->
      let s =
        let x = 
# 483 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6667 "src/parser/grammar.ml"
         in
        
# 421 "src/parser/grammar.mly"
                        ( x )
# 6672 "src/parser/grammar.ml"
        
      in
      (
# 365 "src/parser/grammar.mly"
                              ( App(Const s,[r]) )
# 6678 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_279 =
    fun l s ->
      let s =
        let x = 
# 486 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6687 "src/parser/grammar.ml"
         in
        
# 424 "src/parser/grammar.mly"
                         ( x )
# 6692 "src/parser/grammar.ml"
        
      in
      (
# 366 "src/parser/grammar.mly"
                                ( App(Const s,[l]) )
# 6698 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_280 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6706 "src/parser/grammar.ml"
       : (unit option))
  
  let _menhir_action_281 =
    fun x ->
      (
# 113 "<standard.mly>"
    ( Some x )
# 6714 "src/parser/grammar.ml"
       : (unit option))
  
  let _menhir_action_282 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6722 "src/parser/grammar.ml"
       : ((Ast.Loc.t * Ast.Term.t) option))
  
  let _menhir_action_283 =
    fun x ->
      (
# 113 "<standard.mly>"
    ( Some x )
# 6730 "src/parser/grammar.ml"
       : ((Ast.Loc.t * Ast.Term.t) option))
  
  let _menhir_action_284 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6738 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list option))
  
  let _menhir_action_285 =
    fun x ->
      let x = 
# 180 "<standard.mly>"
    ( x )
# 6746 "src/parser/grammar.ml"
       in
      (
# 113 "<standard.mly>"
    ( Some x )
# 6751 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list option))
  
  let _menhir_action_286 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6759 "src/parser/grammar.ml"
       : (Ast.Chr.sequent option))
  
  let _menhir_action_287 =
    fun x ->
      let x = 
# 180 "<standard.mly>"
    ( x )
# 6767 "src/parser/grammar.ml"
       in
      (
# 113 "<standard.mly>"
    ( Some x )
# 6772 "src/parser/grammar.ml"
       : (Ast.Chr.sequent option))
  
  let _menhir_action_288 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6780 "src/parser/grammar.ml"
       : (Ast.Term.t option))
  
  let _menhir_action_289 =
    fun x ->
      let x = 
# 180 "<standard.mly>"
    ( x )
# 6788 "src/parser/grammar.ml"
       in
      (
# 113 "<standard.mly>"
    ( Some x )
# 6793 "src/parser/grammar.ml"
       : (Ast.Term.t option))
  
  let _menhir_action_290 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6801 "src/parser/grammar.ml"
       : (Ast.Term.t option))
  
  let _menhir_action_291 =
    fun x ->
      (
# 113 "<standard.mly>"
    ( Some x )
# 6809 "src/parser/grammar.ml"
       : (Ast.Term.t option))
  
  let _menhir_action_292 =
    fun s ->
      let x =
        let x = 
# 486 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6818 "src/parser/grammar.ml"
         in
        
# 424 "src/parser/grammar.mly"
                         ( x )
# 6823 "src/parser/grammar.ml"
        
      in
      (
# 418 "src/parser/grammar.mly"
              ( x )
# 6829 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_293 =
    fun _endpos_attributes_ _endpos_c_ _endpos_xs_ _startpos__2_ _startpos_attributes_ _startpos_c_ attributes c xs ->
      let args = 
# 229 "<standard.mly>"
    ( xs )
# 6837 "src/parser/grammar.ml"
       in
      let _endpos_args_ = _endpos_xs_ in
      let _endpos = _endpos_args_ in
      let _symbolstartpos = if _startpos_attributes_ != _endpos_attributes_ then
        _startpos_attributes_
      else
        _startpos__2_ in
      let _loc_c_ = (_startpos_c_, _endpos_c_) in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 163 "src/parser/grammar.mly"
                                                              (
   let name = c in
   { Mode.loc=loc _sloc; name; args = List.map fst args },
   { Type.loc=loc _sloc; attributes; name;
     ty = List.fold_right (fun (_,t) ty ->
       mkApp (loc _loc_c_) [mkCon "->";t;ty]) args (mkCon "prop") }
 )
# 6856 "src/parser/grammar.ml"
       : (Ast.Func.t Ast.Mode.t * Ast.raw_attribute list Ast.Type.t))
  
  let _menhir_action_294 =
    fun io ty ->
      (
# 171 "src/parser/grammar.mly"
                                ( (mode_of_IO io,ty) )
# 6864 "src/parser/grammar.ml"
       : (bool * Ast.Term.t))
  
  let _menhir_action_295 =
    fun s ->
      let x =
        let x = 
# 483 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6873 "src/parser/grammar.ml"
         in
        
# 421 "src/parser/grammar.mly"
                        ( x )
# 6878 "src/parser/grammar.ml"
        
      in
      (
# 415 "src/parser/grammar.mly"
             ( x )
# 6884 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_296 =
    fun () ->
      (
# 114 "src/parser/grammar.mly"
      ( [] )
# 6892 "src/parser/grammar.ml"
       : (Ast.Program.t))
  
  let _menhir_action_297 =
    fun d p ->
      (
# 115 "src/parser/grammar.mly"
                        ( d :: p )
# 6900 "src/parser/grammar.ml"
       : (Ast.Program.t))
  
  let _menhir_action_298 =
    fun x ->
      (
# 238 "<standard.mly>"
    ( [ x ] )
# 6908 "src/parser/grammar.ml"
       : (Ast.raw_attribute list))
  
  let _menhir_action_299 =
    fun x xs ->
      (
# 240 "<standard.mly>"
    ( x :: xs )
# 6916 "src/parser/grammar.ml"
       : (Ast.raw_attribute list))
  
  let _menhir_action_300 =
    fun x ->
      (
# 238 "<standard.mly>"
    ( [ x ] )
# 6924 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_301 =
    fun x xs ->
      (
# 240 "<standard.mly>"
    ( x :: xs )
# 6932 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_302 =
    fun x ->
      (
# 238 "<standard.mly>"
    ( [ x ] )
# 6940 "src/parser/grammar.ml"
       : (string list))
  
  let _menhir_action_303 =
    fun x xs ->
      (
# 240 "<standard.mly>"
    ( x :: xs )
# 6948 "src/parser/grammar.ml"
       : (string list))
  
  let _menhir_action_304 =
    fun x ->
      (
# 238 "<standard.mly>"
    ( [ x ] )
# 6956 "src/parser/grammar.ml"
       : ((string * string) list list))
  
  let _menhir_action_305 =
    fun x xs ->
      (
# 240 "<standard.mly>"
    ( x :: xs )
# 6964 "src/parser/grammar.ml"
       : ((string * string) list list))
  
  let _menhir_action_306 =
    fun x ->
      (
# 238 "<standard.mly>"
    ( [ x ] )
# 6972 "src/parser/grammar.ml"
       : ((bool * Ast.Term.t) list))
  
  let _menhir_action_307 =
    fun x xs ->
      (
# 240 "<standard.mly>"
    ( x :: xs )
# 6980 "src/parser/grammar.ml"
       : ((bool * Ast.Term.t) list))
  
  let _menhir_action_308 =
    fun t ->
      (
# 260 "src/parser/grammar.mly"
                  (
    let context, conclusion = decode_sequent t in
    { Chr.eigen = underscore (); context; conclusion }
  )
# 6991 "src/parser/grammar.ml"
       : (Ast.Chr.sequent))
  
  let _menhir_action_309 =
    fun c t ->
      (
# 264 "src/parser/grammar.mly"
                                                (
    let context, conclusion = decode_sequent t in
    { Chr.eigen = Const c; context; conclusion }
  )
# 7002 "src/parser/grammar.ml"
       : (Ast.Chr.sequent))
  
  let _menhir_action_310 =
    fun l ->
      (
# 245 "src/parser/grammar.mly"
           (
     List.map Func.(fun (x,y) -> from_string x, from_string y) l
  )
# 7012 "src/parser/grammar.ml"
       : ((Ast.Func.t * Ast.Func.t) list))
  
  let _menhir_action_311 =
    fun name ->
      (
# 254 "src/parser/grammar.mly"
                  ( [Func.show name, Func.show name] )
# 7020 "src/parser/grammar.ml"
       : ((string * string) list))
  
  let _menhir_action_312 =
    fun l prefix ->
      (
# 255 "src/parser/grammar.mly"
                                                                                         (
    List.map (fun (p,x) -> Func.show prefix ^ "." ^ p, x) (List.flatten l)
)
# 7030 "src/parser/grammar.ml"
       : ((string * string) list))
  
  let _menhir_action_313 =
    fun t ->
      (
# 305 "src/parser/grammar.mly"
                ( t )
# 7038 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_314 =
    fun t ->
      (
# 306 "src/parser/grammar.mly"
                  ( t )
# 7046 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_315 =
    fun t ->
      (
# 307 "src/parser/grammar.mly"
                  ( t )
# 7054 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_316 =
    fun t ->
      (
# 310 "src/parser/grammar.mly"
                       ( t )
# 7062 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_317 =
    fun t ->
      (
# 311 "src/parser/grammar.mly"
                         ( t )
# 7070 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_318 =
    fun t ->
      (
# 312 "src/parser/grammar.mly"
                  ( t )
# 7078 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_319 =
    fun c l ->
      (
# 250 "src/parser/grammar.mly"
                                                                                    (
    List.map (fun (p,x) -> Func.show c ^ "." ^ p, x) (List.flatten l)
)
# 7088 "src/parser/grammar.ml"
       : ((string * string) list))
  
  let _menhir_action_320 =
    fun _endpos_attributes_ _endpos_t_ _startpos__2_ _startpos_attributes_ attributes names t ->
      let _endpos = _endpos_t_ in
      let _symbolstartpos = if _startpos_attributes_ != _endpos_attributes_ then
        _startpos_attributes_
      else
        _startpos__2_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 180 "src/parser/grammar.mly"
                                                                      (
    names |> List.map (fun n->
     { Type.loc=loc _sloc; attributes; name = n; ty = t })
  )
# 7105 "src/parser/grammar.ml"
       : (Ast.raw_attribute list Ast.Type.t list))
  
  let _menhir_action_321 =
    fun c ->
      (
# 190 "src/parser/grammar.mly"
               ( Const (fix_church c) )
# 7113 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_322 =
    fun _endpos_hd_ _startpos_hd_ args hd ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 191 "src/parser/grammar.mly"
                                                  ( mkAppF (loc _loc_hd_) hd args )
# 7122 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_323 =
    fun _endpos_hd_ _startpos_hd_ hd t ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 192 "src/parser/grammar.mly"
                                       ( mkApp (loc _loc_hd_) [mkCon "->"; hd; t] )
# 7131 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_324 =
    fun t ->
      (
# 193 "src/parser/grammar.mly"
                                ( t )
# 7139 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_325 =
    fun _endpos_t_ _startpos__1_ a t ->
      let _endpos = _endpos_t_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 213 "src/parser/grammar.mly"
                                            (
    let name, args = a in
    let args = List.map Func.show args in
    let nparams = List.length args in
    let value = List.fold_right mkLam args t in
    { TypeAbbreviation.name = name;
      nparams = nparams;
      value = value;
      loc = loc _sloc }
  )
# 7159 "src/parser/grammar.ml"
       : (Ast.Func.t Ast.TypeAbbreviation.t))
  
  let _menhir_print_token : token -> string =
    fun _tok ->
      match _tok with
      | Elpi_lexer_config.Tokens.ACCUMULATE ->
          "ACCUMULATE"
      | Elpi_lexer_config.Tokens.ACCUM_SIG ->
          "ACCUM_SIG"
      | Elpi_lexer_config.Tokens.AFTER ->
          "AFTER"
      | Elpi_lexer_config.Tokens.ARROW ->
          "ARROW"
      | Elpi_lexer_config.Tokens.AS ->
          "AS"
      | Elpi_lexer_config.Tokens.BEFORE ->
          "BEFORE"
      | Elpi_lexer_config.Tokens.BIND ->
          "BIND"
      | Elpi_lexer_config.Tokens.CLOSED ->
          "CLOSED"
      | Elpi_lexer_config.Tokens.COLON ->
          "COLON"
      | Elpi_lexer_config.Tokens.CONJ ->
          "CONJ"
      | Elpi_lexer_config.Tokens.CONJ2 ->
          "CONJ2"
      | Elpi_lexer_config.Tokens.CONS ->
          "CONS"
      | Elpi_lexer_config.Tokens.CONSTANT _ ->
          "CONSTANT"
      | Elpi_lexer_config.Tokens.CONSTRAINT ->
          "CONSTRAINT"
      | Elpi_lexer_config.Tokens.CUT ->
          "CUT"
      | Elpi_lexer_config.Tokens.DARROW ->
          "DARROW"
      | Elpi_lexer_config.Tokens.DIV ->
          "DIV"
      | Elpi_lexer_config.Tokens.EOF ->
          "EOF"
      | Elpi_lexer_config.Tokens.EQ ->
          "EQ"
      | Elpi_lexer_config.Tokens.EQ2 ->
          "EQ2"
      | Elpi_lexer_config.Tokens.EXPORTDEF ->
          "EXPORTDEF"
      | Elpi_lexer_config.Tokens.EXTERNAL ->
          "EXTERNAL"
      | Elpi_lexer_config.Tokens.FAMILY_AND _ ->
          "FAMILY_AND"
      | Elpi_lexer_config.Tokens.FAMILY_BTICK _ ->
          "FAMILY_BTICK"
      | Elpi_lexer_config.Tokens.FAMILY_EQ _ ->
          "FAMILY_EQ"
      | Elpi_lexer_config.Tokens.FAMILY_EXP _ ->
          "FAMILY_EXP"
      | Elpi_lexer_config.Tokens.FAMILY_GT _ ->
          "FAMILY_GT"
      | Elpi_lexer_config.Tokens.FAMILY_LT _ ->
          "FAMILY_LT"
      | Elpi_lexer_config.Tokens.FAMILY_MINUS _ ->
          "FAMILY_MINUS"
      | Elpi_lexer_config.Tokens.FAMILY_OR _ ->
          "FAMILY_OR"
      | Elpi_lexer_config.Tokens.FAMILY_PLUS _ ->
          "FAMILY_PLUS"
      | Elpi_lexer_config.Tokens.FAMILY_QMARK _ ->
          "FAMILY_QMARK"
      | Elpi_lexer_config.Tokens.FAMILY_SHARP _ ->
          "FAMILY_SHARP"
      | Elpi_lexer_config.Tokens.FAMILY_TICK _ ->
          "FAMILY_TICK"
      | Elpi_lexer_config.Tokens.FAMILY_TILDE _ ->
          "FAMILY_TILDE"
      | Elpi_lexer_config.Tokens.FAMILY_TIMES _ ->
          "FAMILY_TIMES"
      | Elpi_lexer_config.Tokens.FIXITY _ ->
          "FIXITY"
      | Elpi_lexer_config.Tokens.FLOAT _ ->
          "FLOAT"
      | Elpi_lexer_config.Tokens.FRESHUV ->
          "FRESHUV"
      | Elpi_lexer_config.Tokens.FULLSTOP ->
          "FULLSTOP"
      | Elpi_lexer_config.Tokens.IF ->
          "IF"
      | Elpi_lexer_config.Tokens.IFF ->
          "IFF"
      | Elpi_lexer_config.Tokens.IMPORT ->
          "IMPORT"
      | Elpi_lexer_config.Tokens.INDEX ->
          "INDEX"
      | Elpi_lexer_config.Tokens.INTEGER _ ->
          "INTEGER"
      | Elpi_lexer_config.Tokens.IO _ ->
          "IO"
      | Elpi_lexer_config.Tokens.IO_COLON _ ->
          "IO_COLON"
      | Elpi_lexer_config.Tokens.IS ->
          "IS"
      | Elpi_lexer_config.Tokens.KIND ->
          "KIND"
      | Elpi_lexer_config.Tokens.LBRACKET ->
          "LBRACKET"
      | Elpi_lexer_config.Tokens.LCURLY ->
          "LCURLY"
      | Elpi_lexer_config.Tokens.LOCAL ->
          "LOCAL"
      | Elpi_lexer_config.Tokens.LOCALKIND ->
          "LOCALKIND"
      | Elpi_lexer_config.Tokens.LPAREN ->
          "LPAREN"
      | Elpi_lexer_config.Tokens.MACRO ->
          "MACRO"
      | Elpi_lexer_config.Tokens.MINUS ->
          "MINUS"
      | Elpi_lexer_config.Tokens.MINUSi ->
          "MINUSi"
      | Elpi_lexer_config.Tokens.MINUSr ->
          "MINUSr"
      | Elpi_lexer_config.Tokens.MINUSs ->
          "MINUSs"
      | Elpi_lexer_config.Tokens.MOD ->
          "MOD"
      | Elpi_lexer_config.Tokens.MODE ->
          "MODE"
      | Elpi_lexer_config.Tokens.MODULE ->
          "MODULE"
      | Elpi_lexer_config.Tokens.NAME ->
          "NAME"
      | Elpi_lexer_config.Tokens.NAMESPACE ->
          "NAMESPACE"
      | Elpi_lexer_config.Tokens.NIL ->
          "NIL"
      | Elpi_lexer_config.Tokens.OR ->
          "OR"
      | Elpi_lexer_config.Tokens.PI ->
          "PI"
      | Elpi_lexer_config.Tokens.PIPE ->
          "PIPE"
      | Elpi_lexer_config.Tokens.PRED ->
          "PRED"
      | Elpi_lexer_config.Tokens.QDASH ->
          "QDASH"
      | Elpi_lexer_config.Tokens.QUOTED _ ->
          "QUOTED"
      | Elpi_lexer_config.Tokens.RBRACKET ->
          "RBRACKET"
      | Elpi_lexer_config.Tokens.RCURLY ->
          "RCURLY"
      | Elpi_lexer_config.Tokens.RPAREN ->
          "RPAREN"
      | Elpi_lexer_config.Tokens.RULE ->
          "RULE"
      | Elpi_lexer_config.Tokens.SHORTEN ->
          "SHORTEN"
      | Elpi_lexer_config.Tokens.SIG ->
          "SIG"
      | Elpi_lexer_config.Tokens.SIGMA ->
          "SIGMA"
      | Elpi_lexer_config.Tokens.SLASH ->
          "SLASH"
      | Elpi_lexer_config.Tokens.STRING _ ->
          "STRING"
      | Elpi_lexer_config.Tokens.TYPE ->
          "TYPE"
      | Elpi_lexer_config.Tokens.TYPEABBREV ->
          "TYPEABBREV"
      | Elpi_lexer_config.Tokens.USEONLY ->
          "USEONLY"
      | Elpi_lexer_config.Tokens.USE_SIG ->
          "USE_SIG"
      | Elpi_lexer_config.Tokens.VDASH ->
          "VDASH"
  
  let _menhir_fail : unit -> 'a =
    fun () ->
      Printf.eprintf "Internal failure -- please contact the parser generator's developers.\n%!";
      assert false
  
  include struct
    
    [@@@ocaml.warning "-4-37-39"]
    
    let rec _menhir_run_398_spec_267 : type  ttv_stack. ttv_stack -> _ -> _menhir_box_program =
      fun _menhir_stack _v ->
        MenhirBox_program _v
    
    let rec _menhir_run_412 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_decl -> _ -> _menhir_box_program =
      fun _menhir_stack _v ->
        let MenhirCell1_decl (_menhir_stack, _menhir_s, d) = _menhir_stack in
        let p = _v in
        let _v = _menhir_action_297 d p in
        _menhir_goto_program _menhir_stack _v _menhir_s
    
    and _menhir_goto_program : type  ttv_stack. ttv_stack -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _v _menhir_s ->
        match _menhir_s with
        | MenhirState411 ->
            _menhir_run_412 _menhir_stack _v
        | MenhirState267 ->
            _menhir_run_398_spec_267 _menhir_stack _v
        | _ ->
            _menhir_fail ()
    
    let rec _menhir_goto_goal : type  ttv_stack. ttv_stack -> _ -> _menhir_box_goal =
      fun _menhir_stack _v ->
        MenhirBox_goal _v
    
    let rec _menhir_run_052_spec_000 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_goal =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_225 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState000 _tok
    
    and _menhir_run_225 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_goal) _menhir_state -> _ -> _menhir_box_goal =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let (_endpos__2_, _startpos_g_, g) = (_endpos_0, _startpos, _v) in
            let _v = _menhir_action_110 _endpos__2_ _startpos_g_ g in
            _menhir_goto_goal _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EOF ->
            let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
            let (_endpos__2_, _startpos_g_, g) = (_endpos_14, _startpos, _v) in
            let _v = _menhir_action_109 _endpos__2_ _startpos_g_ g in
            _menhir_goto_goal _menhir_stack _v
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 225
    
    and _menhir_run_055 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_VDASH (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_055 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState055 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_055 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState055 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState055 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState055 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState055
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState055
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState055
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState055 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_055 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState055 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState055 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState055 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_055 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState055
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState055 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState055 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState055 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState055 _tok
        | _ ->
            _eRR 55
    
    and _menhir_run_052_spec_055 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_VDASH -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState055 _tok
    
    and _menhir_run_056 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_VDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN ->
            let MenhirCell0_VDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_245 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 56
    
    and _menhir_run_057 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_SLASH (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_057 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState057 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_057 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState057 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState057 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState057 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState057 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_057 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState057 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState057 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState057 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_057 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState057
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState057 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState057 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState057 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState057 _tok
        | _ ->
            _eRR 57
    
    and _menhir_run_052_spec_057 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_SLASH -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState057 _tok
    
    and _menhir_run_058 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_SLASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_SLASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_242 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 58
    
    and _menhir_run_059 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_SHARP (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_059 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState059 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_059 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState059 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState059 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState059 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState059
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState059
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState059
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState059 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_059 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState059 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState059 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState059 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_059 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState059
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState059 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState059 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState059 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState059 _tok
        | _ ->
            _eRR 59
    
    and _menhir_run_052_spec_059 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_SHARP -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState059 _tok
    
    and _menhir_run_060 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_SHARP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_SHARP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_225 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 60
    
    and _menhir_run_040 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
        let (_endpos_s_, s) = (_endpos, _v) in
        let _v = _menhir_action_247 l s in
        _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_l_ _v _menhir_s _tok
    
    and _menhir_goto_open_term : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_313 t in
        _menhir_goto_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_goto_term : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState521 ->
            _menhir_run_522 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState519 ->
            _menhir_run_520 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState517 ->
            _menhir_run_518 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState515 ->
            _menhir_run_516 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState513 ->
            _menhir_run_514 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState511 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState509 ->
            _menhir_run_510 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState507 ->
            _menhir_run_508 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState505 ->
            _menhir_run_506 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState503 ->
            _menhir_run_504 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState501 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState499 ->
            _menhir_run_500 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState497 ->
            _menhir_run_498 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState495 ->
            _menhir_run_496 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState493 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState491 ->
            _menhir_run_492 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState489 ->
            _menhir_run_490 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState486 ->
            _menhir_run_487 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState484 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState482 ->
            _menhir_run_483 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState480 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState478 ->
            _menhir_run_479 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState476 ->
            _menhir_run_477 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState474 ->
            _menhir_run_475 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState472 ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState470 ->
            _menhir_run_471 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState468 ->
            _menhir_run_469 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState466 ->
            _menhir_run_467 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState464 ->
            _menhir_run_465 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState462 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState455 ->
            _menhir_run_456 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState452 ->
            _menhir_run_453 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState436 ->
            _menhir_run_437 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState424 ->
            _menhir_run_425 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState336 ->
            _menhir_run_337 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState334 ->
            _menhir_run_335 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_225 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState220 ->
            _menhir_run_221 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState422 ->
            _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState007 ->
            _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState017 ->
            _menhir_run_191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState117 ->
            _menhir_run_118 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState113 ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState111 ->
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState109 ->
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState107 ->
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState105 ->
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState103 ->
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState101 ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState099 ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState097 ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState095 ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState093 ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState091 ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState089 ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState087 ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState085 ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState083 ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState081 ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState079 ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState077 ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState075 ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState073 ->
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState071 ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState069 ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState067 ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState065 ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState063 ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState061 ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState059 ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState057 ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState055 ->
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState037 ->
            _menhir_run_054 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState195 ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState038 ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_522 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_ARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_ARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_055 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 522
    
    and _menhir_run_073 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MOD (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_073 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState073 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_073 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState073 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState073 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState073 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState073
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState073
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState073
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState073 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_073 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState073 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState073 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState073 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_073 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState073
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState073 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState073 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState073 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState073 _tok
        | _ ->
            _eRR 73
    
    and _menhir_run_052_spec_073 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MOD -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState073 _tok
    
    and _menhir_run_074 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MOD (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_237 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 74
    
    and _menhir_run_061 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_OR (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_061 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState061 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_061 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState061 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState061 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState061 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState061 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_061 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState061 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState061 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState061 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_061 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState061
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState061 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState061 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState061 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState061 _tok
        | _ ->
            _eRR 61
    
    and _menhir_run_052_spec_061 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_OR -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState061 _tok
    
    and _menhir_run_062 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_OR (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_224 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 62
    
    and _menhir_run_063 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_AND (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_063 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState063 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_063 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState063 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState063 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState063 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState063
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState063
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState063
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState063 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_063 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState063 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState063 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState063 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_063 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState063
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState063 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState063 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState063 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState063 _tok
        | _ ->
            _eRR 63
    
    and _menhir_run_052_spec_063 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_AND -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState063 _tok
    
    and _menhir_run_064 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_AND (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_223 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 64
    
    and _menhir_run_050 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState050
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FLOAT _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.INTEGER _ | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.LBRACKET | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.QUOTED _ | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.STRING _ | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_111 t in
            _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 50
    
    and _menhir_run_037 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_BIND (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_037 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState037 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_037 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState037 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState037 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState037 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState037
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState037
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState037
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState037 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_037 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState037 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState037 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState037 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_037 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState037
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState037 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState037 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState037 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState037 _tok
        | _ ->
            _eRR 37
    
    and _menhir_run_052_spec_037 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_BIND -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_054 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState037 _tok
    
    and _menhir_run_054 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BIND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN ->
            let MenhirCell1_BIND (_menhir_stack, _menhir_s, _startpos_bind_, _endpos_bind_) = _menhir_stack in
            let (_endpos_b_, b, bind) = (_endpos, _v, ()) in
            let _v = _menhir_action_023 _endpos_bind_ _startpos_bind_ b bind in
            _menhir_goto_binder_body _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _v _menhir_s _tok
        | _ ->
            _eRR 54
    
    and _menhir_run_113 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_QDASH (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_113 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState113 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_113 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState113 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState113 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState113 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState113
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState113
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState113
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState113 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_113 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState113 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState113 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState113 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_113 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState113
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState113 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState113 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState113 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState113 _tok
        | _ ->
            _eRR 113
    
    and _menhir_run_052_spec_113 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_QDASH -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState113 _tok
    
    and _menhir_run_114 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_QDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN ->
            let MenhirCell0_QDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_241 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 114
    
    and _menhir_run_071 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_OR (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_071 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState071 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_071 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState071 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState071 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState071 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState071 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_071 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState071 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState071 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState071 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_071 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState071
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState071 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState071 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState071 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState071 _tok
        | _ ->
            _eRR 71
    
    and _menhir_run_052_spec_071 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_OR -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState071 _tok
    
    and _menhir_run_072 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_OR (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_235 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 72
    
    and _menhir_run_075 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSs (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_075 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState075 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_075 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState075 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState075 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState075 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState075 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_075 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState075 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState075 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState075 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_075 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState075
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState075 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState075 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState075 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState075 _tok
        | _ ->
            _eRR 75
    
    and _menhir_run_052_spec_075 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUSs -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState075 _tok
    
    and _menhir_run_076 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUSs as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSs (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_233 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 76
    
    and _menhir_run_077 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_TIMES (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_077 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState077 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_077 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState077 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState077 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState077 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState077
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState077
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState077
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState077 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_077 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState077 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState077 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState077 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_077 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState077
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState077 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState077 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState077 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState077 _tok
        | _ ->
            _eRR 77
    
    and _menhir_run_052_spec_077 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_TIMES -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState077 _tok
    
    and _menhir_run_078 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_TIMES as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TIMES (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_217 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 78
    
    and _menhir_run_065 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_MINUS (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_065 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState065 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_065 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState065 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState065 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState065 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState065
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState065
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState065
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState065 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_065 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState065 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState065 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState065 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_065 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState065
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState065 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState065 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState065 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState065 _tok
        | _ ->
            _eRR 65
    
    and _menhir_run_052_spec_065 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_MINUS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState065 _tok
    
    and _menhir_run_066 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_MINUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_218 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 66
    
    and _menhir_run_067 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_EQ (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_067 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState067 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_067 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState067 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState067 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState067 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState067
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState067
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState067
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState067 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_067 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState067 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState067 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState067 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_067 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState067
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState067 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState067 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState067 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState067 _tok
        | _ ->
            _eRR 67
    
    and _menhir_run_052_spec_067 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_EQ -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState067 _tok
    
    and _menhir_run_068 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EQ (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_222 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 68
    
    and _menhir_run_007 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_199 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_1, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_007 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SLASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_196 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState007 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_007 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_195 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState007 _tok
        | Elpi_lexer_config.Tokens.OR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_189 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState007 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState007 _tok
        | Elpi_lexer_config.Tokens.MOD ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_191 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_187 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_185 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_186 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_184 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState007
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState007
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState007
        | Elpi_lexer_config.Tokens.IS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_190 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_16, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState007 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_17, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_007 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_18) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState007 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_19) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState007 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState007 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_21, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_007 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_171 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_195 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState007
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_181 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_179 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_201 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_170 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_178 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_172 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_174 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_175 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_173 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_176 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_180 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_177 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_188 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_183 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DIV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_192 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_194 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_39 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_39) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState007 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_40 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_40, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState007 _tok
        | Elpi_lexer_config.Tokens.CONS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_182 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_197 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_198 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_44 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_44) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState007 _tok
        | Elpi_lexer_config.Tokens.AS ->
            _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_193 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_46) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState007 _tok
        | _ ->
            _eRR 7
    
    and _menhir_run_223 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LPAREN -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (s, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_085 s in
            _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR 223
    
    and _menhir_goto_constant : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState525 ->
            _menhir_run_532_spec_525 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState530 ->
            _menhir_run_532_spec_530 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState417 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState442 ->
            _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState422 ->
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState366 ->
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState363 ->
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState353 ->
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState327 ->
            _menhir_run_328 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState324 ->
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok
        | MenhirState321 ->
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState309 ->
            _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState315 ->
            _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState311 ->
            _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState303 ->
            _menhir_run_307 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState301 ->
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok
        | MenhirState291 ->
            _menhir_run_298_spec_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState296 ->
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState293 ->
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState292 ->
            _menhir_run_293 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState418 ->
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState390 ->
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState359 ->
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState346 ->
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState340 ->
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState338 ->
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState289 ->
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState269 ->
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState285 ->
            _menhir_run_284_spec_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState278 ->
            _menhir_run_284_spec_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState444 ->
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState419 ->
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState360 ->
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState341 ->
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState299 ->
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState272 ->
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState273 ->
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState280 ->
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState276 ->
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState018 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState186 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState183 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState020 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState179 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState122 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState138 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState174 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState176 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState172 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState170 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState168 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState166 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState164 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState154 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState162 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState156 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState160 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState158 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState152 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState150 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState148 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState142 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState146 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState144 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState140 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState124 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState132 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState136 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState134 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState128 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState130 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState126 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState027 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState521 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState519 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState517 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState515 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState513 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState511 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState509 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState507 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState505 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState503 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState501 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState499 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState497 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState495 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState493 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState491 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState489 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState486 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState484 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState482 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState480 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState478 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState476 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState474 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState472 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState470 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState468 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState466 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState464 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState462 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState455 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState452 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState436 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState424 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState334 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState336 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState007 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState220 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState195 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState017 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState117 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState037 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState113 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState055 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState071 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState107 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState109 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState111 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState105 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState103 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState101 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState099 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState097 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState087 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState095 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState089 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState093 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState091 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState085 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState083 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState081 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState075 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState079 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState077 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState073 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState057 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState065 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState069 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState067 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState061 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState063 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState059 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState038 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState457 ->
            _menhir_run_047_spec_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState421 ->
            _menhir_run_047_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState439 ->
            _menhir_run_047_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState431 ->
            _menhir_run_047_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState432 ->
            _menhir_run_047_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState427 ->
            _menhir_run_047_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState035 ->
            _menhir_run_047_spec_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState048 ->
            _menhir_run_047_spec_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState042 ->
            _menhir_run_047_spec_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_532_spec_525 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_accumulate -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let c = _v in
        let _v = _menhir_action_105 c in
        _menhir_run_529 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState525 _tok
    
    and _menhir_run_529 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_filename (_menhir_stack, _menhir_s, _v) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_0 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_0 in
                let _v = _menhir_action_106 s in
                _menhir_run_529 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState530 _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_083 () in
                _menhir_run_532_spec_530 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_082 () in
                _menhir_run_532_spec_530 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_087 () in
                _menhir_run_532_spec_530 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_076 () in
                _menhir_run_532_spec_530 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
            | Elpi_lexer_config.Tokens.IO _v_16 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let c = _v_16 in
                let _v = _menhir_action_080 c in
                _menhir_run_532_spec_530 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_079 () in
                _menhir_run_532_spec_530 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_075 () in
                _menhir_run_532_spec_530 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_084 () in
                _menhir_run_532_spec_530 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_081 () in
                _menhir_run_532_spec_530 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_32 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let c = _v_32 in
                let _v = _menhir_action_074 c in
                _menhir_run_532_spec_530 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_077 () in
                _menhir_run_532_spec_530 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_078 () in
                _menhir_run_532_spec_530 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | _ ->
                _eRR 530)
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let x = _v in
            let _v = _menhir_action_302 x in
            _menhir_goto_separated_nonempty_list_CONJ_filename_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 529
    
    and _menhir_run_532_spec_530 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_filename _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let c = _v in
        let _v = _menhir_action_105 c in
        _menhir_run_529 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState530 _tok
    
    and _menhir_run_270 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_199 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.SLASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_196 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_195 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.OR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_189 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MOD ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_191 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_187 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_185 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_186 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_184 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_190 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_171 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_200 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_181 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_179 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_201 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_170 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_178 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_172 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_174 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_175 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_173 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_176 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_180 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_177 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_188 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_183 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DIV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_192 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_194 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_182 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_197 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_198 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AS ->
            _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_193 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR 270
    
    and _menhir_run_215 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LPAREN -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let _endpos__3_ = _endpos in
            let _v = _menhir_action_086 () in
            _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR 215
    
    and _menhir_goto_separated_nonempty_list_CONJ_filename_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState530 ->
            _menhir_run_531 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState525 ->
            _menhir_run_527 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_531 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_filename _menhir_cell0_CONJ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_filename (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_303 x xs in
        _menhir_goto_separated_nonempty_list_CONJ_filename_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_527 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_accumulate -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_accumulate (_menhir_stack, _menhir_s, ext, _startpos_ext_) = _menhir_stack in
        let (_endpos__3_, l) = (_endpos, _v) in
        let _v = _menhir_action_101 _endpos__3_ _startpos_ext_ ext l in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_goto_decl : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_411 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_decl (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.USE_SIG ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_010 () in
            _menhir_run_525 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState411 _tok
        | Elpi_lexer_config.Tokens.USEONLY ->
            _menhir_run_269 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Elpi_lexer_config.Tokens.TYPEABBREV ->
            _menhir_run_291 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Elpi_lexer_config.Tokens.SIG ->
            _menhir_run_301 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Elpi_lexer_config.Tokens.SHORTEN ->
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Elpi_lexer_config.Tokens.RCURLY ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_100 _endpos__1_ _startpos__1_ in
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v MenhirState411 _tok
        | Elpi_lexer_config.Tokens.NAMESPACE ->
            _menhir_run_321 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Elpi_lexer_config.Tokens.MODULE ->
            _menhir_run_324 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Elpi_lexer_config.Tokens.MODE ->
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Elpi_lexer_config.Tokens.MACRO ->
            _menhir_run_334 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Elpi_lexer_config.Tokens.LOCALKIND ->
            _menhir_run_338 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Elpi_lexer_config.Tokens.LOCAL ->
            _menhir_run_340 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_099 _endpos__1_ _startpos__1_ in
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v MenhirState411 _tok
        | Elpi_lexer_config.Tokens.KIND ->
            _menhir_run_346 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Elpi_lexer_config.Tokens.IMPORT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_008 () in
            _menhir_run_525 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState411 _tok
        | Elpi_lexer_config.Tokens.FIXITY _v_4 ->
            _menhir_run_353 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState411
        | Elpi_lexer_config.Tokens.EXTERNAL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_018 () in
            _menhir_run_417 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState411 _tok
        | Elpi_lexer_config.Tokens.EXPORTDEF ->
            _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Elpi_lexer_config.Tokens.EOF ->
            let _v = _menhir_action_296 () in
            _menhir_run_412 _menhir_stack _v
        | Elpi_lexer_config.Tokens.CONSTRAINT ->
            _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Elpi_lexer_config.Tokens.COLON ->
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Elpi_lexer_config.Tokens.CLOSED ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Elpi_lexer_config.Tokens.ACCUM_SIG ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_009 () in
            _menhir_run_525 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState411 _tok
        | Elpi_lexer_config.Tokens.ACCUMULATE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_007 () in
            _menhir_run_525 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState411 _tok
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FAMILY_TILDE _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PRED | Elpi_lexer_config.Tokens.RULE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.TYPE ->
            let _v = _menhir_action_017 () in
            _menhir_run_417 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _endpos _v MenhirState411 _tok
        | _ ->
            _eRR 411
    
    and _menhir_run_525 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_accumulate (_menhir_stack, _menhir_s, _v, _startpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v_0 in
            let _v = _menhir_action_106 s in
            _menhir_run_529 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState525 _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_083 () in
            _menhir_run_532_spec_525 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_082 () in
            _menhir_run_532_spec_525 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_087 () in
            _menhir_run_532_spec_525 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_076 () in
            _menhir_run_532_spec_525 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState525
        | Elpi_lexer_config.Tokens.IO _v_11 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let c = _v_11 in
            let _v = _menhir_action_080 c in
            _menhir_run_532_spec_525 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_079 () in
            _menhir_run_532_spec_525 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_075 () in
            _menhir_run_532_spec_525 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_084 () in
            _menhir_run_532_spec_525 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_081 () in
            _menhir_run_532_spec_525 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_22 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let c = _v_22 in
            let _v = _menhir_action_074 c in
            _menhir_run_532_spec_525 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_077 () in
            _menhir_run_532_spec_525 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_078 () in
            _menhir_run_532_spec_525 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR 525
    
    and _menhir_run_269 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_USEONLY (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_083 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState269 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_082 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState269 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_087 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState269 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_076 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState269 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_4, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState269 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_5) in
            let _v = _menhir_action_079 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState269 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_075 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState269 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_084 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState269 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_081 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState269 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_9, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState269 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
            let _v = _menhir_action_077 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState269 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_078 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState269 _tok
        | _ ->
            _eRR 269
    
    and _menhir_run_288 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos_0, _endpos_1) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
                let _v = _menhir_action_083 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState289 _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos_5) in
                let _v = _menhir_action_082 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState289 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
                let _v = _menhir_action_087 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState289 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
                let _v = _menhir_action_076 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState289 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState289
            | Elpi_lexer_config.Tokens.IO _v_14 ->
                let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_16 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_16, _startpos_15, _v_14) in
                let _v = _menhir_action_080 c in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState289 _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
                let _v = _menhir_action_079 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState289 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_22, _startpos_21) in
                let _v = _menhir_action_075 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState289 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
                let _v = _menhir_action_084 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState289 _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_27 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_28 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_28, _startpos_27) in
                let _v = _menhir_action_081 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState289 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_30 ->
                let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_32, _startpos_31, _v_30) in
                let _v = _menhir_action_074 c in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState289 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
                let _v = _menhir_action_077 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState289 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
                let _v = _menhir_action_078 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState289 _tok
            | _ ->
                _eRR 289)
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.TYPE ->
            let (_endpos_x_, x) = (_endpos, _v) in
            let _v = _menhir_action_300 x in
            _menhir_goto_separated_nonempty_list_CONJ_constant_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR 288
    
    and _menhir_goto_separated_nonempty_list_CONJ_constant_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState418 ->
            _menhir_run_419 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState390 ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok
        | MenhirState359 ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState346 ->
            _menhir_run_347 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState340 ->
            _menhir_run_341 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState338 ->
            _menhir_run_339 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok
        | MenhirState289 ->
            _menhir_run_290 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState269 ->
            _menhir_run_272 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_419 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_TYPE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_0, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState419 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_2, _startpos) in
            let _v = _menhir_action_082 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState419 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos) in
            let _v = _menhir_action_087 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState419 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState419 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_273 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.IO _v_8 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_9, _startpos, _v_8) in
            let _v = _menhir_action_080 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState419 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState419 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos) in
            let _v = _menhir_action_075 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState419 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState419 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState419 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_19 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_20, _startpos, _v_19) in
            let _v = _menhir_action_074 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState419 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_22, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState419 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_24, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState419 _tok
        | _ ->
            _eRR 419
    
    and _menhir_run_278 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_2, _v_0) in
            let _v = _menhir_action_020 c in
            _menhir_run_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v MenhirState278 _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_5 in
            let _v = _menhir_action_083 () in
            _menhir_run_284_spec_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_8 in
            let _v = _menhir_action_082 () in
            _menhir_run_284_spec_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_11 in
            let _v = _menhir_action_087 () in
            _menhir_run_284_spec_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_14 in
            let _v = _menhir_action_076 () in
            _menhir_run_284_spec_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_280 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState278
        | Elpi_lexer_config.Tokens.IO _v_16 ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_18, _v_16) in
            let _v = _menhir_action_080 c in
            _menhir_run_284_spec_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_21 in
            let _v = _menhir_action_079 () in
            _menhir_run_284_spec_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_24 in
            let _v = _menhir_action_075 () in
            _menhir_run_284_spec_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_27 in
            let _v = _menhir_action_084 () in
            _menhir_run_284_spec_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_30 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_30 in
            let _v = _menhir_action_081 () in
            _menhir_run_284_spec_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_32 ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_34 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_34, _v_32) in
            let _v = _menhir_action_074 c in
            _menhir_run_284_spec_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_37 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_37 in
            let _v = _menhir_action_077 () in
            _menhir_run_284_spec_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_40 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_40 in
            let _v = _menhir_action_078 () in
            _menhir_run_284_spec_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IO_COLON _ | Elpi_lexer_config.Tokens.RPAREN ->
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_321 c in
            _menhir_goto_type_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _menhir_s _tok
        | _ ->
            _eRR 278
    
    and _menhir_run_285 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_1, _v_0) in
            let _v = _menhir_action_020 c in
            _menhir_run_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v MenhirState285 _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_3 in
            let _v = _menhir_action_083 () in
            _menhir_run_284_spec_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_5 in
            let _v = _menhir_action_082 () in
            _menhir_run_284_spec_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_7 in
            let _v = _menhir_action_087 () in
            _menhir_run_284_spec_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_9 in
            let _v = _menhir_action_076 () in
            _menhir_run_284_spec_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_280 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState285
        | Elpi_lexer_config.Tokens.IO _v_11 ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_12, _v_11) in
            let _v = _menhir_action_080 c in
            _menhir_run_284_spec_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_14 in
            let _v = _menhir_action_079 () in
            _menhir_run_284_spec_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_16 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_16 in
            let _v = _menhir_action_075 () in
            _menhir_run_284_spec_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_18 in
            let _v = _menhir_action_084 () in
            _menhir_run_284_spec_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_20 in
            let _v = _menhir_action_081 () in
            _menhir_run_284_spec_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_22 ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_23, _v_22) in
            let _v = _menhir_action_074 c in
            _menhir_run_284_spec_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_25 in
            let _v = _menhir_action_077 () in
            _menhir_run_284_spec_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_27 in
            let _v = _menhir_action_078 () in
            _menhir_run_284_spec_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IO_COLON _ | Elpi_lexer_config.Tokens.RPAREN ->
            let (_endpos_x_, x) = (_endpos, _v) in
            let _v = _menhir_action_203 x in
            _menhir_goto_nonempty_list_atype_term_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR 285
    
    and _menhir_run_284_spec_285 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_atype_term -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_c_, c) = (_endpos, _v) in
        let _v = _menhir_action_021 c in
        _menhir_run_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v MenhirState285 _tok
    
    and _menhir_run_280 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_199 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.SLASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_196 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState280 _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_195 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_082 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState280 _tok
        | Elpi_lexer_config.Tokens.OR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_189 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_087 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState280 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_076 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState280 _tok
        | Elpi_lexer_config.Tokens.MOD ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_191 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_187 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_185 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_186 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_184 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_273 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Elpi_lexer_config.Tokens.IS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_190 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_14, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState280 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_15) in
            let _v = _menhir_action_079 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState280 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_16) in
            let _v = _menhir_action_075 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState280 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_17) in
            let _v = _menhir_action_084 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState280 _tok
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_171 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_200 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_181 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_179 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_201 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_170 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_178 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_172 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_174 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_175 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_173 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_176 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_180 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_177 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_188 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_183 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DIV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_192 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_194 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_36 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_36) in
            let _v = _menhir_action_081 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState280 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_37, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState280 _tok
        | Elpi_lexer_config.Tokens.CONS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_182 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_197 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_198 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_41) in
            let _v = _menhir_action_077 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState280 _tok
        | Elpi_lexer_config.Tokens.AS ->
            _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_193 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_43 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_43) in
            let _v = _menhir_action_078 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState280 _tok
        | _ ->
            _eRR 280
    
    and _menhir_run_273 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_199 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.SLASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_196 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_195 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_082 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.OR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_189 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_087 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_076 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.MOD ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_191 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_187 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_185 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_186 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_184 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_273 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Elpi_lexer_config.Tokens.IS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_190 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_14, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_15) in
            let _v = _menhir_action_079 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_16) in
            let _v = _menhir_action_075 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_17) in
            let _v = _menhir_action_084 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_171 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_200 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_181 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_179 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_201 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_170 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_178 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_172 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_174 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_175 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_173 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_176 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_180 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_177 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_188 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_183 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DIV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_192 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_194 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_36 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_36) in
            let _v = _menhir_action_081 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_37, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.CONS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_182 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_197 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_198 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_41) in
            let _v = _menhir_action_077 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.AS ->
            _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_193 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_43 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_43) in
            let _v = _menhir_action_078 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | _ ->
            _eRR 273
    
    and _menhir_goto_nonempty_list_atype_term_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState285 ->
            _menhir_run_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState278 ->
            _menhir_run_283 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_286 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_atype_term -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_atype_term (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_204 x xs in
        _menhir_goto_nonempty_list_atype_term_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_283 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_constant (_menhir_stack, _menhir_s, hd, _startpos_hd_, _endpos_hd_) = _menhir_stack in
        let (_endpos_args_, args) = (_endpos, _v) in
        let _v = _menhir_action_322 _endpos_hd_ _startpos_hd_ args hd in
        _menhir_goto_type_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_args_ _startpos_hd_ _v _menhir_s _tok
    
    and _menhir_goto_type_term : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState444 ->
            _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState419 ->
            _menhir_run_420 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState360 ->
            _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState341 ->
            _menhir_run_342 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState299 ->
            _menhir_run_300 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState272 ->
            _menhir_run_287 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState280 ->
            _menhir_run_281 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState276 ->
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState273 ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_445 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_IO_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_276 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IO_COLON _ ->
            let MenhirCell1_IO_COLON (_menhir_stack, _menhir_s, io) = _menhir_stack in
            let (_endpos_ty_, ty) = (_endpos, _v) in
            let _v = _menhir_action_294 io ty in
            let _endpos = _endpos_ty_ in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.CONJ ->
                let _menhir_stack = MenhirCell1_pred_item (_menhir_stack, _menhir_s, _v, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let x = () in
                let _v = _menhir_action_281 x in
                _menhir_goto_option_CONJ_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.IO_COLON _ ->
                let _menhir_stack = MenhirCell1_pred_item (_menhir_stack, _menhir_s, _v, _endpos) in
                let _v = _menhir_action_280 () in
                _menhir_goto_option_CONJ_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FULLSTOP ->
                let (_endpos_x_, x) = (_endpos, _v) in
                let _v = _menhir_action_306 x in
                _menhir_goto_separated_nonempty_list_option_CONJ__pred_item_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s
            | _ ->
                _menhir_fail ())
        | _ ->
            _eRR 445
    
    and _menhir_run_276 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_type_term -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_ARROW (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_1, _startpos_0) in
            let _v = _menhir_action_083 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState276 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_082 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState276 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_087 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState276 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_076 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState276 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_273 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState276
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_9, _startpos_8, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState276 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_079 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState276 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_075 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState276 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState276 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_081 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState276 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_19, _startpos_18, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState276 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState276 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_078 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState276 _tok
        | _ ->
            _eRR 276
    
    and _menhir_goto_option_CONJ_ : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_pred_item -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let _menhir_stack = MenhirCell0_option_CONJ_ (_menhir_stack, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.IO_COLON _v_0 ->
            _menhir_run_444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState449
        | _ ->
            _eRR 449
    
    and _menhir_run_444 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_IO_COLON (_menhir_stack, _menhir_s, _v) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState444 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_082 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState444 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_087 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState444 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState444 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_273 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState444
        | Elpi_lexer_config.Tokens.IO _v_4 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v_4) in
            let _v = _menhir_action_080 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState444 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState444 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_075 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState444 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState444 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState444 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_10 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v_10) in
            let _v = _menhir_action_074 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState444 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState444 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState444 _tok
        | _ ->
            _eRR 444
    
    and _menhir_goto_separated_nonempty_list_option_CONJ__pred_item_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s ->
        match _menhir_s with
        | MenhirState449 ->
            _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v
        | MenhirState443 ->
            _menhir_run_446_spec_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_450 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_pred_item _menhir_cell0_option_CONJ_ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v ->
        let MenhirCell0_option_CONJ_ (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_pred_item (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_307 x xs in
        _menhir_goto_separated_nonempty_list_option_CONJ__pred_item_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s
    
    and _menhir_run_446_spec_443 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_PRED, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v ->
        let (_endpos_x_, x) = (_endpos, _v) in
        let _v = _menhir_action_168 x in
        _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v
    
    and _menhir_run_451 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_PRED, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v ->
        let MenhirCell1_constant (_menhir_stack, _, c, _startpos_c_, _endpos_c_) = _menhir_stack in
        let MenhirCell1_PRED (_menhir_stack, _, _startpos__2_) = _menhir_stack in
        let MenhirCell1_attributes (_menhir_stack, _menhir_s, attributes, _startpos_attributes_, _endpos_attributes_) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_293 _endpos_attributes_ _endpos_c_ _endpos_xs_ _startpos__2_ _startpos_attributes_ _startpos_c_ attributes c xs in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let p = _v in
        let _v = _menhir_action_090 p in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_420 : type  ttv_stack. ((((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_TYPE, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_276 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _, names, _) = _menhir_stack in
            let MenhirCell1_TYPE (_menhir_stack, _, _startpos__2_, _) = _menhir_stack in
            let MenhirCell1_attributes (_menhir_stack, _menhir_s, attributes, _startpos_attributes_, _endpos_attributes_) = _menhir_stack in
            let (_endpos_t_, t) = (_endpos, _v) in
            let _v = _menhir_action_320 _endpos_attributes_ _endpos_t_ _startpos__2_ _startpos_attributes_ attributes names t in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let t = _v in
            let _v = _menhir_action_091 t in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 420
    
    and _menhir_run_361 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_EXPORTDEF, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_276 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_EXPORTDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let _endpos__3_ = _endpos in
            let _ = _menhir_action_117 _endpos__3_ _startpos__1_ in
            _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
        | _ ->
            _eRR 361
    
    and _menhir_goto_ignored : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_startpos__1_, _endpos__2_) = (_startpos, _endpos) in
            let _v = _menhir_action_103 _endpos__2_ _startpos__1_ in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 407
    
    and _menhir_run_342 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_LOCAL, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_276 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let x = _v in
            let _ = _menhir_action_291 x in
            _menhir_run_343 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 342
    
    and _menhir_run_343 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_LOCAL, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _, l, _) = _menhir_stack in
        let MenhirCell1_LOCAL (_menhir_stack, _menhir_s) = _menhir_stack in
        let _v = _menhir_action_102 l in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_300 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_abbrevform as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_276 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_abbrevform (_menhir_stack, _, a) = _menhir_stack in
            let MenhirCell1_TYPEABBREV (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos_t_, t) = (_endpos, _v) in
            let _v = _menhir_action_325 _endpos_t_ _startpos__1_ a t in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let a = _v in
            let _v = _menhir_action_098 a in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 300
    
    and _menhir_run_287 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_USEONLY, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_276 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_USEONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let _endpos__3_ = _endpos in
            let _ = _menhir_action_120 _endpos__3_ _startpos__1_ in
            _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
        | _ ->
            _eRR 287
    
    and _menhir_run_281 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _) = _menhir_stack in
            let (_endpos__3_, t) = (_endpos_0, _v) in
            let _v = _menhir_action_022 t in
            _menhir_run_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_276 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 281
    
    and _menhir_run_277 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_type_term _menhir_cell0_ARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_276 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IO_COLON _ | Elpi_lexer_config.Tokens.RPAREN ->
            let MenhirCell0_ARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_type_term (_menhir_stack, _menhir_s, hd, _startpos_hd_, _endpos_hd_) = _menhir_stack in
            let (_endpos_t_, t) = (_endpos, _v) in
            let _v = _menhir_action_323 _endpos_hd_ _startpos_hd_ hd t in
            _menhir_goto_type_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_hd_ _v _menhir_s _tok
        | _ ->
            _eRR 277
    
    and _menhir_run_274 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos__3_, t) = (_endpos_0, _v) in
            let _v = _menhir_action_324 t in
            _menhir_goto_type_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_276 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 274
    
    and _menhir_run_284_spec_278 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_c_, c) = (_endpos, _v) in
        let _v = _menhir_action_021 c in
        _menhir_run_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v MenhirState278 _tok
    
    and _menhir_run_391 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_CLOSED -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok ->
        let MenhirCell1_CLOSED (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let _endpos__2_ = _endpos in
        let _ = _menhir_action_121 _endpos__2_ _startpos__1_ in
        _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
    
    and _menhir_run_360 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_EXPORTDEF as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_0, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_2, _startpos) in
            let _v = _menhir_action_082 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos) in
            let _v = _menhir_action_087 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_273 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState360
        | Elpi_lexer_config.Tokens.IO _v_8 ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_9, _startpos, _v_8) in
            let _v = _menhir_action_080 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos) in
            let _v = _menhir_action_075 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_19 ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_20, _startpos, _v_19) in
            let _v = _menhir_action_074 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_22, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_24, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_EXPORTDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let _endpos__2_ = _endpos in
            let _ = _menhir_action_116 _endpos__2_ _startpos__1_ in
            _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
        | _ ->
            _eRR 360
    
    and _menhir_run_347 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_KIND as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.TYPE ->
            _menhir_run_348 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState347
        | _ ->
            _eRR 347
    
    and _menhir_run_348 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_ARROW (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.TYPE ->
                _menhir_run_348 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState349
            | _ ->
                _eRR 349)
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos__1_ = _endpos in
            let _v = _menhir_action_155 () in
            _menhir_goto_kind_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s
        | _ ->
            _eRR 348
    
    and _menhir_goto_kind_term : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s ->
        match _menhir_s with
        | MenhirState347 ->
            _menhir_run_351 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v
        | MenhirState349 ->
            _menhir_run_350 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_351 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_KIND, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v ->
        let MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _, names, _) = _menhir_stack in
        let MenhirCell1_KIND (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_endpos_k_, k) = (_endpos, _v) in
        let _v = _menhir_action_154 _endpos_k_ _startpos__1_ k names in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let t = _v in
        let _v = _menhir_action_092 t in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_350 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_TYPE _menhir_cell0_ARROW -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v ->
        let MenhirCell0_ARROW (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos_hd_, _endpos_hd_) = _menhir_stack in
        let (_endpos_t_, t, hd) = (_endpos, _v, ()) in
        let _v = _menhir_action_156 _endpos_hd_ _startpos_hd_ hd t in
        _menhir_goto_kind_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _menhir_s
    
    and _menhir_run_341 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_LOCAL as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_0, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_2, _startpos) in
            let _v = _menhir_action_082 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos) in
            let _v = _menhir_action_087 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_273 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState341
        | Elpi_lexer_config.Tokens.IO _v_8 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_9, _startpos, _v_8) in
            let _v = _menhir_action_080 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos) in
            let _v = _menhir_action_075 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_19 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_20, _startpos, _v_19) in
            let _v = _menhir_action_074 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_22, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_24, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _ = _menhir_action_290 () in
            _menhir_run_343 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 341
    
    and _menhir_run_339 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_LOCALKIND -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok ->
        let MenhirCell1_LOCALKIND (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let _endpos__2_ = _endpos in
        let _ = _menhir_action_118 _endpos__2_ _startpos__1_ in
        _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
    
    and _menhir_run_290 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_constant (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_301 x xs in
        _menhir_goto_separated_nonempty_list_CONJ_constant_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_272 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_USEONLY as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_0, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState272 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_2, _startpos) in
            let _v = _menhir_action_082 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState272 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos) in
            let _v = _menhir_action_087 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState272 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState272 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_273 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Elpi_lexer_config.Tokens.IO _v_8 ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_9, _startpos, _v_8) in
            let _v = _menhir_action_080 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState272 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState272 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos) in
            let _v = _menhir_action_075 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState272 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState272 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState272 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_19 ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_20, _startpos, _v_19) in
            let _v = _menhir_action_074 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState272 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_22, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState272 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_24, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState272 _tok
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_USEONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let _endpos__2_ = _endpos in
            let _ = _menhir_action_119 _endpos__2_ _startpos__1_ in
            _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
        | _ ->
            _eRR 272
    
    and _menhir_run_291 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_TYPEABBREV (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_083 () in
            _menhir_run_298_spec_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_082 () in
            _menhir_run_298_spec_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_087 () in
            _menhir_run_298_spec_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_076 () in
            _menhir_run_298_spec_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, MenhirState291, _startpos_4) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.VDASH ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_199 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.SLASH ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_196 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
                let _v = _menhir_action_083 () in
                _menhir_run_293 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState292 _tok
            | Elpi_lexer_config.Tokens.QDASH ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_195 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
                let _v = _menhir_action_082 () in
                _menhir_run_293 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState292 _tok
            | Elpi_lexer_config.Tokens.OR ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_189 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
                let _v = _menhir_action_087 () in
                _menhir_run_293 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState292 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_12) in
                let _v = _menhir_action_076 () in
                _menhir_run_293 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState292 _tok
            | Elpi_lexer_config.Tokens.MOD ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_191 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUSs ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_187 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUSr ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_185 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUSi ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_186 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUS ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_184 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState292
            | Elpi_lexer_config.Tokens.IS ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_190 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.IO _v ->
                let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_19, _v) in
                let _v = _menhir_action_080 c in
                _menhir_run_293 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState292 _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_20) in
                let _v = _menhir_action_079 () in
                _menhir_run_293 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState292 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_21) in
                let _v = _menhir_action_075 () in
                _menhir_run_293 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState292 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_22) in
                let _v = _menhir_action_084 () in
                _menhir_run_293 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState292 _tok
            | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_171 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_200 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_181 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_179 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_201 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_170 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_178 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_172 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_174 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_175 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_173 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_176 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_180 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_177 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.EQ2 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_188 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.EQ ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_183 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.DIV ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_192 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.DARROW ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_194 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_41) in
                let _v = _menhir_action_081 () in
                _menhir_run_293 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState292 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_42, _v) in
                let _v = _menhir_action_074 c in
                _menhir_run_293 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState292 _tok
            | Elpi_lexer_config.Tokens.CONS ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_182 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CONJ2 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_197 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CONJ ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_198 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_46) in
                let _v = _menhir_action_077 () in
                _menhir_run_293 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState292 _tok
            | Elpi_lexer_config.Tokens.AS ->
                _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer
            | Elpi_lexer_config.Tokens.ARROW ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_193 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_48 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_48) in
                let _v = _menhir_action_078 () in
                _menhir_run_293 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState292 _tok
            | _ ->
                _eRR 292)
        | Elpi_lexer_config.Tokens.IO _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let c = _v in
            let _v = _menhir_action_080 c in
            _menhir_run_298_spec_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_079 () in
            _menhir_run_298_spec_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_075 () in
            _menhir_run_298_spec_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_084 () in
            _menhir_run_298_spec_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_081 () in
            _menhir_run_298_spec_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let c = _v in
            let _v = _menhir_action_074 c in
            _menhir_run_298_spec_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_077 () in
            _menhir_run_298_spec_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_078 () in
            _menhir_run_298_spec_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR 291
    
    and _menhir_run_298_spec_291 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_TYPEABBREV -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let c = _v in
        let _v = _menhir_action_005 c in
        _menhir_run_299 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState291 _tok
    
    and _menhir_run_299 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_TYPEABBREV as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_abbrevform (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState299 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_082 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState299 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_087 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState299 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState299 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_273 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Elpi_lexer_config.Tokens.IO _v_4 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v_4) in
            let _v = _menhir_action_080 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState299 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState299 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_075 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState299 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState299 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState299 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_10 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v_10) in
            let _v = _menhir_action_074 c in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState299 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState299 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState299 _tok
        | _ ->
            _eRR 299
    
    and _menhir_run_293 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_1, _startpos_0) in
            let _v = _menhir_action_083 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos_3) in
            let _v = _menhir_action_082 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_087 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_10, _startpos_9) in
            let _v = _menhir_action_076 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState293
        | Elpi_lexer_config.Tokens.IO _v_12 ->
            let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_14, _startpos_13, _v_12) in
            let _v = _menhir_action_080 c in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState293 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
            let _v = _menhir_action_075 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_084 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos_25) in
            let _v = _menhir_action_081 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_28 ->
            let _startpos_29 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_30 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_30, _startpos_29, _v_28) in
            let _v = _menhir_action_074 c in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState293 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_077 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_36, _startpos_35) in
            let _v = _menhir_action_078 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
        | _ ->
            _eRR 293
    
    and _menhir_run_296 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_constant as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_1, _startpos_0) in
            let _v = _menhir_action_083 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState296 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos_3) in
            let _v = _menhir_action_082 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState296 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_087 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState296 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_10, _startpos_9) in
            let _v = _menhir_action_076 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState296 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState296
        | Elpi_lexer_config.Tokens.IO _v_12 ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_14, _startpos_13, _v_12) in
            let _v = _menhir_action_080 c in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState296 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState296 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
            let _v = _menhir_action_075 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState296 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_084 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState296 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos_25) in
            let _v = _menhir_action_081 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState296 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_28 ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_29 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_30 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_30, _startpos_29, _v_28) in
            let _v = _menhir_action_074 c in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState296 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_077 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState296 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_36, _startpos_35) in
            let _v = _menhir_action_078 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState296 _tok
        | Elpi_lexer_config.Tokens.RPAREN ->
            let x = _v in
            let _v = _menhir_action_207 x in
            _menhir_goto_nonempty_list_constant_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 296
    
    and _menhir_goto_nonempty_list_constant_ : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_constant as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState296 ->
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState293 ->
            _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_297 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_constant (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_208 x xs in
        _menhir_goto_nonempty_list_constant_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_294 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_constant (_menhir_stack, _, hd, _, _) = _menhir_stack in
        let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let args = _v in
        let _v = _menhir_action_006 args hd in
        _menhir_run_299 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_301 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_SIG (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_083 () in
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_082 () in
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_087 () in
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_076 () in
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Elpi_lexer_config.Tokens.IO _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos, _v) in
            let _ = _menhir_action_080 c in
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_079 () in
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_075 () in
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_084 () in
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_081 () in
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos, _v) in
            let _ = _menhir_action_074 c in
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_077 () in
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_078 () in
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | _ ->
            _eRR 301
    
    and _menhir_run_302 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_SIG -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok ->
        let MenhirCell1_SIG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let _endpos__2_ = _endpos in
        let _ = _menhir_action_115 _endpos__2_ _startpos__1_ in
        _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
    
    and _menhir_run_303 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_SHORTEN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_083 () in
            _menhir_run_307 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState303 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_082 () in
            _menhir_run_307 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState303 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_087 () in
            _menhir_run_307 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState303 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_076 () in
            _menhir_run_307 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState303 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_4, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_307 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState303 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_5) in
            let _v = _menhir_action_079 () in
            _menhir_run_307 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState303 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_075 () in
            _menhir_run_307 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState303 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_084 () in
            _menhir_run_307 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState303 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_081 () in
            _menhir_run_307 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState303 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_9, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_307 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState303 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
            let _v = _menhir_action_077 () in
            _menhir_run_307 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState303 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_078 () in
            _menhir_run_307 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState303 _tok
        | _ ->
            _eRR 303
    
    and _menhir_run_307 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_SHORTEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FULLSTOP (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.LCURLY ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_LCURLY (_menhir_stack, _startpos_1, _endpos_2) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Elpi_lexer_config.Tokens.SIGMA ->
                    let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos_3) in
                    let _v = _menhir_action_083 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState309 _tok
                | Elpi_lexer_config.Tokens.PI ->
                    let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
                    let _v = _menhir_action_082 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState309 _tok
                | Elpi_lexer_config.Tokens.NIL ->
                    let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_10, _startpos_9) in
                    let _v = _menhir_action_087 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState309 _tok
                | Elpi_lexer_config.Tokens.NAME ->
                    let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
                    let _v = _menhir_action_076 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState309 _tok
                | Elpi_lexer_config.Tokens.LPAREN ->
                    _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
                | Elpi_lexer_config.Tokens.IO _v_15 ->
                    let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos_c_, _startpos_c_, c) = (_endpos_17, _startpos_16, _v_15) in
                    let _v = _menhir_action_080 c in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState309 _tok
                | Elpi_lexer_config.Tokens.INDEX ->
                    let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
                    let _v = _menhir_action_079 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState309 _tok
                | Elpi_lexer_config.Tokens.IF ->
                    let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
                    let _v = _menhir_action_075 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState309 _tok
                | Elpi_lexer_config.Tokens.FRESHUV ->
                    let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos_25) in
                    let _v = _menhir_action_084 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState309 _tok
                | Elpi_lexer_config.Tokens.CUT ->
                    let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
                    let _v = _menhir_action_081 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState309 _tok
                | Elpi_lexer_config.Tokens.CONSTANT _v_31 ->
                    let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos_c_, _startpos_c_, c) = (_endpos_33, _startpos_32, _v_31) in
                    let _v = _menhir_action_074 c in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState309 _tok
                | Elpi_lexer_config.Tokens.BEFORE ->
                    let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_36, _startpos_35) in
                    let _v = _menhir_action_077 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState309 _tok
                | Elpi_lexer_config.Tokens.AFTER ->
                    let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_39, _startpos_38) in
                    let _v = _menhir_action_078 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState309 _tok
                | _ ->
                    _eRR 309)
            | _ ->
                _eRR 308)
        | _ ->
            _eRR 307
    
    and _menhir_run_313 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FULLSTOP (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.LCURLY ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_LCURLY (_menhir_stack, _startpos_1, _endpos_2) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Elpi_lexer_config.Tokens.SIGMA ->
                    let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos_3) in
                    let _v = _menhir_action_083 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState315 _tok
                | Elpi_lexer_config.Tokens.PI ->
                    let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
                    let _v = _menhir_action_082 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState315 _tok
                | Elpi_lexer_config.Tokens.NIL ->
                    let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_10, _startpos_9) in
                    let _v = _menhir_action_087 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState315 _tok
                | Elpi_lexer_config.Tokens.NAME ->
                    let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
                    let _v = _menhir_action_076 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState315 _tok
                | Elpi_lexer_config.Tokens.LPAREN ->
                    _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState315
                | Elpi_lexer_config.Tokens.IO _v_15 ->
                    let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos_c_, _startpos_c_, c) = (_endpos_17, _startpos_16, _v_15) in
                    let _v = _menhir_action_080 c in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState315 _tok
                | Elpi_lexer_config.Tokens.INDEX ->
                    let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
                    let _v = _menhir_action_079 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState315 _tok
                | Elpi_lexer_config.Tokens.IF ->
                    let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
                    let _v = _menhir_action_075 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState315 _tok
                | Elpi_lexer_config.Tokens.FRESHUV ->
                    let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos_25) in
                    let _v = _menhir_action_084 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState315 _tok
                | Elpi_lexer_config.Tokens.CUT ->
                    let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
                    let _v = _menhir_action_081 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState315 _tok
                | Elpi_lexer_config.Tokens.CONSTANT _v_31 ->
                    let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos_c_, _startpos_c_, c) = (_endpos_33, _startpos_32, _v_31) in
                    let _v = _menhir_action_074 c in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState315 _tok
                | Elpi_lexer_config.Tokens.BEFORE ->
                    let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_36, _startpos_35) in
                    let _v = _menhir_action_077 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState315 _tok
                | Elpi_lexer_config.Tokens.AFTER ->
                    let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_39, _startpos_38) in
                    let _v = _menhir_action_078 () in
                    _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState315 _tok
                | _ ->
                    _eRR 315)
            | _ ->
                _eRR 314)
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.RCURLY ->
            let name = _v in
            let _v = _menhir_action_311 name in
            _menhir_goto_subtrie _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR 313
    
    and _menhir_goto_subtrie : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_subtrie (_menhir_stack, _menhir_s, _v) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1, _startpos_0) in
                let _v = _menhir_action_083 () in
                _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState311 _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos_3) in
                let _v = _menhir_action_082 () in
                _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState311 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
                let _v = _menhir_action_087 () in
                _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState311 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_10, _startpos_9) in
                let _v = _menhir_action_076 () in
                _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState311 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
            | Elpi_lexer_config.Tokens.IO _v_12 ->
                let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_14, _startpos_13, _v_12) in
                let _v = _menhir_action_080 c in
                _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState311 _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
                let _v = _menhir_action_079 () in
                _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState311 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
                let _v = _menhir_action_075 () in
                _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState311 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
                let _v = _menhir_action_084 () in
                _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState311 _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos_25) in
                let _v = _menhir_action_081 () in
                _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState311 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_28 ->
                let _startpos_29 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_30 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_30, _startpos_29, _v_28) in
                let _v = _menhir_action_074 c in
                _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState311 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
                let _v = _menhir_action_077 () in
                _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState311 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_36, _startpos_35) in
                let _v = _menhir_action_078 () in
                _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState311 _tok
            | _ ->
                _eRR 311)
        | Elpi_lexer_config.Tokens.RCURLY ->
            let x = _v in
            let _v = _menhir_action_304 x in
            _menhir_goto_separated_nonempty_list_CONJ_subtrie_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 310
    
    and _menhir_goto_separated_nonempty_list_CONJ_subtrie_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState309 ->
            _menhir_run_318 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState315 ->
            _menhir_run_316 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState311 ->
            _menhir_run_312 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_318 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_SHORTEN, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_FULLSTOP _menhir_cell0_LCURLY -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LCURLY (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_FULLSTOP (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_constant (_menhir_stack, _, c, _, _) = _menhir_stack in
        let l = _v in
        let _v = _menhir_action_319 c l in
        let l = _v in
        let _v = _menhir_action_310 l in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_SHORTEN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (s, _endpos__3_) = (_v, _endpos) in
            let _v = _menhir_action_097 _endpos__3_ _startpos__1_ s in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 305
    
    and _menhir_run_316 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_FULLSTOP _menhir_cell0_LCURLY -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LCURLY (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_FULLSTOP (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_constant (_menhir_stack, _menhir_s, prefix, _, _) = _menhir_stack in
        let l = _v in
        let _v = _menhir_action_312 l prefix in
        _menhir_goto_subtrie _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_312 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_subtrie _menhir_cell0_CONJ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_subtrie (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_305 x xs in
        _menhir_goto_separated_nonempty_list_CONJ_subtrie_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_321 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_NAMESPACE (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_083 () in
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_082 () in
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_087 () in
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_076 () in
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState321
        | Elpi_lexer_config.Tokens.IO _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let c = _v in
            let _v = _menhir_action_080 c in
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_079 () in
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_075 () in
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_084 () in
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_081 () in
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let c = _v in
            let _v = _menhir_action_074 c in
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_077 () in
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_078 () in
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR 321
    
    and _menhir_run_322 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_NAMESPACE -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_NAMESPACE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos, c, _endpos__3_) = (_endpos_1, _v, _endpos_1) in
            let _v = _menhir_action_096 _endpos__3_ _startpos__1_ c in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 322
    
    and _menhir_run_324 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_MODULE (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_083 () in
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_082 () in
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_087 () in
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_076 () in
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState324
        | Elpi_lexer_config.Tokens.IO _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos, _v) in
            let _ = _menhir_action_080 c in
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_079 () in
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_075 () in
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_084 () in
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_081 () in
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos, _v) in
            let _ = _menhir_action_074 c in
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_077 () in
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_078 () in
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | _ ->
            _eRR 324
    
    and _menhir_run_325 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_MODULE -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok ->
        let MenhirCell1_MODULE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let _endpos__2_ = _endpos in
        let _ = _menhir_action_114 _endpos__2_ _startpos__1_ in
        _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
    
    and _menhir_run_326 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_MODE (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAREN (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
                let _v = _menhir_action_083 () in
                _menhir_run_328 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState327 _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
                let _v = _menhir_action_082 () in
                _menhir_run_328 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState327 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
                let _v = _menhir_action_087 () in
                _menhir_run_328 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState327 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
                let _v = _menhir_action_076 () in
                _menhir_run_328 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState327 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState327
            | Elpi_lexer_config.Tokens.IO _v ->
                let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_5, _v) in
                let _v = _menhir_action_080 c in
                _menhir_run_328 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState327 _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
                let _v = _menhir_action_079 () in
                _menhir_run_328 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState327 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
                let _v = _menhir_action_075 () in
                _menhir_run_328 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState327 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
                let _v = _menhir_action_084 () in
                _menhir_run_328 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState327 _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
                let _v = _menhir_action_081 () in
                _menhir_run_328 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState327 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_10, _v) in
                let _v = _menhir_action_074 c in
                _menhir_run_328 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState327 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
                let _v = _menhir_action_077 () in
                _menhir_run_328 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState327 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_12) in
                let _v = _menhir_action_078 () in
                _menhir_run_328 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState327 _tok
            | _ ->
                _eRR 327)
        | _ ->
            _eRR 326
    
    and _menhir_run_328 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_MODE _menhir_cell0_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.IO _v_0 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let io = _v_0 in
            let _v = _menhir_action_113 io in
            _menhir_run_332 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState328 _tok
        | _ ->
            _eRR 328
    
    and _menhir_run_332 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.IO _v_0 ->
            let _menhir_stack = MenhirCell1_i_o (_menhir_stack, _menhir_s, _v) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let io = _v_0 in
            let _v = _menhir_action_113 io in
            _menhir_run_332 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState332 _tok
        | Elpi_lexer_config.Tokens.RPAREN ->
            let x = _v in
            let _v = _menhir_action_209 x in
            _menhir_goto_nonempty_list_i_o_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 332
    
    and _menhir_goto_nonempty_list_i_o_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState332 ->
            _menhir_run_333 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState328 ->
            _menhir_run_330 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_333 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_i_o -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_i_o (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_210 x xs in
        _menhir_goto_nonempty_list_i_o_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_330 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_MODE _menhir_cell0_LPAREN, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_constant (_menhir_stack, _, c, _, _) = _menhir_stack in
        let MenhirCell0_LPAREN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_MODE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (l, _endpos__5_) = (_v, _endpos) in
        let _v = _menhir_action_202 _endpos__5_ _startpos__1_ c l in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let m = _v in
            let _v = _menhir_action_093 m in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 401
    
    and _menhir_run_334 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_MACRO (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_334 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState334 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_2, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_334 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState334 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState334 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_5) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState334 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState334
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState334
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState334
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_6, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState334 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_7, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_334 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState334 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState334 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState334 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_11, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_334 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState334
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_12) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState334 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_13, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState334 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_14) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState334 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_15) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState334 _tok
        | _ ->
            _eRR 334
    
    and _menhir_run_052_spec_334 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_MACRO -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_335 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState334 _tok
    
    and _menhir_run_335 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_MACRO as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_VDASH (_menhir_stack, _startpos_0, _endpos_1) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_2 ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_4, _startpos_3, _v_2) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_336 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState336 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_9 ->
                let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_11, _startpos_10, _v_9) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_336 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_14, _startpos_13) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState336 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState336 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState336 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
            | Elpi_lexer_config.Tokens.IO _v_22 ->
                let _startpos_23 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_24, _startpos_23, _v_22) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState336 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_26 ->
                let _startpos_27 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_28 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_28, _startpos_27, _v_26) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_336 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState336 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_33 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_34 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_34, _startpos_33) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState336 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_36 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_37 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_37, _startpos_36) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState336 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_39 ->
                let _startpos_40 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_41 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_41, _startpos_40, _v_39) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_336 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_43 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_43 MenhirState336
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_44 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_45 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_45, _startpos_44) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState336 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_47 ->
                let _startpos_48 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_49 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_49, _startpos_48, _v_47) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState336 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_51 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_52, _startpos_51) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState336 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_54 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_55 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_55, _startpos_54) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState336 _tok
            | _ ->
                _eRR 336)
        | Elpi_lexer_config.Tokens.SLASH ->
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_57 ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_57
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_58 ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_58
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_59 ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_59
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_60 ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_60
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_61 ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_61
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_62 ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_62
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_63 ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_63
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_64 ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_64
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_65 ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_65
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_66 ->
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_66
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_67 ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_67
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_68 ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_68
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_69 ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_69
        | Elpi_lexer_config.Tokens.EQ2 ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 335
    
    and _menhir_run_052_spec_336 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_MACRO, _menhir_box_program) _menhir_cell1_term _menhir_cell0_VDASH -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_337 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState336 _tok
    
    and _menhir_run_337 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_MACRO, _menhir_box_program) _menhir_cell1_term _menhir_cell0_VDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell0_VDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _, m, _, _) = _menhir_stack in
            let MenhirCell1_MACRO (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos_b_, b) = (_endpos, _v) in
            let _v = _menhir_action_169 _endpos_b_ _startpos__1_ b m in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let m = _v in
            let _v = _menhir_action_094 m in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 337
    
    and _menhir_run_081 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSr (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_081 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState081 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_081 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState081 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState081 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState081 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState081
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState081
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState081
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState081 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_081 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState081 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState081 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState081 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_081 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState081
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState081 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState081 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState081 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState081 _tok
        | _ ->
            _eRR 81
    
    and _menhir_run_052_spec_081 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUSr -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState081 _tok
    
    and _menhir_run_082 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUSr as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSr (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_231 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 82
    
    and _menhir_run_069 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_BTICK (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_069 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState069 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_069 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState069 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState069 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState069 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState069
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState069
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState069
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState069 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_069 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState069 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState069 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState069 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_069 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState069
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState069 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState069 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState069 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState069 _tok
        | _ ->
            _eRR 69
    
    and _menhir_run_052_spec_069 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_BTICK -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState069 _tok
    
    and _menhir_run_070 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_BTICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_BTICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_226 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 70
    
    and _menhir_run_017 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_LCURLY (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_017 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState017 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_017 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState017 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState017 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState017 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState017
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState017
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState017
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState017 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_017 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState017 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState017 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState017 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_017 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState017
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState017 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState017 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState017 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState017 _tok
        | _ ->
            _eRR 17
    
    and _menhir_run_052_spec_017 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LCURLY -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState017 _tok
    
    and _menhir_run_191 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LCURLY as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RCURLY ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LCURLY (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
            let (_endpos__3_, t) = (_endpos_1, _v) in
            let _v = _menhir_action_072 t in
            _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_14 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_14
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 191
    
    and _menhir_goto_closed_term : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState421 ->
            _menhir_run_429_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState439 ->
            _menhir_run_429_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState431 ->
            _menhir_run_429_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState432 ->
            _menhir_run_429_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState427 ->
            _menhir_run_429_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState018 ->
            _menhir_run_119_spec_018 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState186 ->
            _menhir_run_119_spec_186 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState183 ->
            _menhir_run_119_spec_183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState020 ->
            _menhir_run_119_spec_020 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState179 ->
            _menhir_run_119_spec_179 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState122 ->
            _menhir_run_119_spec_122 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState138 ->
            _menhir_run_119_spec_138 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState174 ->
            _menhir_run_119_spec_174 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState176 ->
            _menhir_run_119_spec_176 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState172 ->
            _menhir_run_119_spec_172 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState170 ->
            _menhir_run_119_spec_170 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState168 ->
            _menhir_run_119_spec_168 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState166 ->
            _menhir_run_119_spec_166 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState164 ->
            _menhir_run_119_spec_164 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState154 ->
            _menhir_run_119_spec_154 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState162 ->
            _menhir_run_119_spec_162 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState156 ->
            _menhir_run_119_spec_156 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState160 ->
            _menhir_run_119_spec_160 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState158 ->
            _menhir_run_119_spec_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState152 ->
            _menhir_run_119_spec_152 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState150 ->
            _menhir_run_119_spec_150 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState148 ->
            _menhir_run_119_spec_148 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState142 ->
            _menhir_run_119_spec_142 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState146 ->
            _menhir_run_119_spec_146 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState144 ->
            _menhir_run_119_spec_144 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState140 ->
            _menhir_run_119_spec_140 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState124 ->
            _menhir_run_119_spec_124 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState132 ->
            _menhir_run_119_spec_132 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState136 ->
            _menhir_run_119_spec_136 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState134 ->
            _menhir_run_119_spec_134 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState128 ->
            _menhir_run_119_spec_128 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState130 ->
            _menhir_run_119_spec_130 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState126 ->
            _menhir_run_119_spec_126 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState027 ->
            _menhir_run_119_spec_027 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState521 ->
            _menhir_run_052_spec_521 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState519 ->
            _menhir_run_052_spec_519 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState517 ->
            _menhir_run_052_spec_517 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState515 ->
            _menhir_run_052_spec_515 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState513 ->
            _menhir_run_052_spec_513 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState511 ->
            _menhir_run_052_spec_511 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState509 ->
            _menhir_run_052_spec_509 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState507 ->
            _menhir_run_052_spec_507 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState505 ->
            _menhir_run_052_spec_505 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState503 ->
            _menhir_run_052_spec_503 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState501 ->
            _menhir_run_052_spec_501 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState499 ->
            _menhir_run_052_spec_499 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState497 ->
            _menhir_run_052_spec_497 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState495 ->
            _menhir_run_052_spec_495 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState493 ->
            _menhir_run_052_spec_493 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState491 ->
            _menhir_run_052_spec_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState489 ->
            _menhir_run_052_spec_489 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState486 ->
            _menhir_run_052_spec_486 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState484 ->
            _menhir_run_052_spec_484 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState482 ->
            _menhir_run_052_spec_482 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState480 ->
            _menhir_run_052_spec_480 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState478 ->
            _menhir_run_052_spec_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState476 ->
            _menhir_run_052_spec_476 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState474 ->
            _menhir_run_052_spec_474 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState472 ->
            _menhir_run_052_spec_472 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState470 ->
            _menhir_run_052_spec_470 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState468 ->
            _menhir_run_052_spec_468 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState466 ->
            _menhir_run_052_spec_466 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState464 ->
            _menhir_run_052_spec_464 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState462 ->
            _menhir_run_052_spec_462 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState455 ->
            _menhir_run_052_spec_455 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState452 ->
            _menhir_run_052_spec_452 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState436 ->
            _menhir_run_052_spec_436 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState422 ->
            _menhir_run_052_spec_422 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState424 ->
            _menhir_run_052_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState334 ->
            _menhir_run_052_spec_334 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState336 ->
            _menhir_run_052_spec_336 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState000 ->
            _menhir_run_052_spec_000 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState007 ->
            _menhir_run_052_spec_007 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState220 ->
            _menhir_run_052_spec_220 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState195 ->
            _menhir_run_052_spec_195 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState017 ->
            _menhir_run_052_spec_017 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState117 ->
            _menhir_run_052_spec_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState037 ->
            _menhir_run_052_spec_037 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState113 ->
            _menhir_run_052_spec_113 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState055 ->
            _menhir_run_052_spec_055 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState071 ->
            _menhir_run_052_spec_071 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState107 ->
            _menhir_run_052_spec_107 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState109 ->
            _menhir_run_052_spec_109 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState111 ->
            _menhir_run_052_spec_111 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState105 ->
            _menhir_run_052_spec_105 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState103 ->
            _menhir_run_052_spec_103 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState101 ->
            _menhir_run_052_spec_101 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState099 ->
            _menhir_run_052_spec_099 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState097 ->
            _menhir_run_052_spec_097 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState087 ->
            _menhir_run_052_spec_087 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState095 ->
            _menhir_run_052_spec_095 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState089 ->
            _menhir_run_052_spec_089 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState093 ->
            _menhir_run_052_spec_093 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState091 ->
            _menhir_run_052_spec_091 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState085 ->
            _menhir_run_052_spec_085 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState083 ->
            _menhir_run_052_spec_083 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState081 ->
            _menhir_run_052_spec_081 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState075 ->
            _menhir_run_052_spec_075 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState079 ->
            _menhir_run_052_spec_079 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState077 ->
            _menhir_run_052_spec_077 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState073 ->
            _menhir_run_052_spec_073 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState057 ->
            _menhir_run_052_spec_057 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState065 ->
            _menhir_run_052_spec_065 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState069 ->
            _menhir_run_052_spec_069 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState067 ->
            _menhir_run_052_spec_067 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState061 ->
            _menhir_run_052_spec_061 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState063 ->
            _menhir_run_052_spec_063 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState059 ->
            _menhir_run_052_spec_059 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState038 ->
            _menhir_run_052_spec_038 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState457 ->
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState035 ->
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState048 ->
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState042 ->
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_429_spec_421 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_308 t in
        _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v MenhirState421 _tok
    
    and _menhir_run_427 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, x) = (_endpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_429_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_3 in
            let _v = _menhir_action_083 () in
            _menhir_run_047_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_5 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_6, _startpos, _v_5) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_429_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_8 in
            let _v = _menhir_action_082 () in
            _menhir_run_047_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_10 in
            let _v = _menhir_action_087 () in
            _menhir_run_047_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_12 in
            let _v = _menhir_action_076 () in
            _menhir_run_047_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_422 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Elpi_lexer_config.Tokens.IO _v_14 ->
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_15, _v_14) in
            let _v = _menhir_action_080 c in
            _menhir_run_047_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_17 ->
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, x) = (_endpos_18, _v_17) in
            let _v = _menhir_action_065 x in
            _menhir_run_429_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_20 in
            let _v = _menhir_action_079 () in
            _menhir_run_047_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_22 in
            let _v = _menhir_action_075 () in
            _menhir_run_047_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_24 in
            let _v = _menhir_action_084 () in
            _menhir_run_047_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_26 ->
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, x) = (_endpos_27, _v_26) in
            let _v = _menhir_action_066 x in
            _menhir_run_429_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_29 in
            let _v = _menhir_action_081 () in
            _menhir_run_047_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_31 ->
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_32, _v_31) in
            let _v = _menhir_action_074 c in
            _menhir_run_047_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _endpos_34 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_34 in
            let _v = _menhir_action_077 () in
            _menhir_run_047_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_36 in
            let _v = _menhir_action_078 () in
            _menhir_run_047_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.BIND | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE ->
            let _v = _menhir_action_159 () in
            _menhir_run_428 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _eRR 427
    
    and _menhir_run_429_spec_427 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_308 t in
        _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v MenhirState427 _tok
    
    and _menhir_run_047_spec_427 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_111 t in
        _menhir_run_046_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_046_spec_427 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_073 t in
        _menhir_run_429_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_422 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_199 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_1, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_422 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SLASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_196 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_083 () in
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_422 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_195 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.OR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_189 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
            let _v = _menhir_action_076 () in
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.MOD ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_191 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_187 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_185 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_186 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_184 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState422
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState422
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState422
        | Elpi_lexer_config.Tokens.IS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_190 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_16, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_17, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_422 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_18) in
            let _v = _menhir_action_079 () in
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_19) in
            let _v = _menhir_action_075 () in
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_21, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_422 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_171 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_195 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState422
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_181 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_179 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_201 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_170 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_178 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_172 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_174 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_175 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_173 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_176 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_180 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_177 s in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_188 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_183 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DIV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_192 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_194 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_39 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_39) in
            let _v = _menhir_action_081 () in
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_40 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_40, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.CONS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_182 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_197 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_198 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_44 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_44) in
            let _v = _menhir_action_077 () in
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.AS ->
            _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_193 () in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_46) in
            let _v = _menhir_action_078 () in
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | _ ->
            _eRR 422
    
    and _menhir_run_052_spec_422 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState422 _tok
    
    and _menhir_run_218 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos__3_, t) = (_endpos_0, _v) in
            let _v = _menhir_action_112 t in
            _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_14 ->
                let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_16 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_16, _startpos_15, _v_14) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_220 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState220 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_21 ->
                let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v_21) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_220 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos_25) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState220 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState220 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState220 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
            | Elpi_lexer_config.Tokens.IO _v_34 ->
                let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_36, _startpos_35, _v_34) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState220 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_38 ->
                let _startpos_39 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_40 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_40, _startpos_39, _v_38) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_220 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState220 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState220 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_48 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_49 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_49, _startpos_48) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState220 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_51 ->
                let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_53, _startpos_52, _v_51) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_220 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_55 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_55 MenhirState220
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_56 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_57 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_57, _startpos_56) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState220 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_59 ->
                let _startpos_60 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_61 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_61, _startpos_60, _v_59) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState220 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_63 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_64 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_64, _startpos_63) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState220 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_66 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_67 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_67, _startpos_66) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState220 _tok
            | _ ->
                _eRR 220)
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 218
    
    and _menhir_goto_head_term : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState417 ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState457 ->
            _menhir_run_046_spec_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState421 ->
            _menhir_run_046_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState439 ->
            _menhir_run_046_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState431 ->
            _menhir_run_046_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState432 ->
            _menhir_run_046_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState427 ->
            _menhir_run_046_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState035 ->
            _menhir_run_046_spec_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState048 ->
            _menhir_run_046_spec_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState042 ->
            _menhir_run_046_spec_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState521 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState519 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState517 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState515 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState513 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState511 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState509 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState507 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState505 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState503 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState501 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState499 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState497 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState495 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState493 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState491 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState489 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState486 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState484 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState482 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState480 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState478 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState476 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState474 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState472 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState470 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState468 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState466 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState464 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState462 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState455 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState452 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState436 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState424 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState422 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState334 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState336 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState007 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState220 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState195 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState017 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState117 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState037 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState113 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState055 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState071 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState107 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState109 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState111 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState105 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState103 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState101 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState099 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState097 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState087 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState095 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState089 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState093 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState091 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState085 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState083 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState081 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState075 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState079 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState077 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState073 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState057 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState065 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState069 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState067 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState061 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState063 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState059 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState038 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState018 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState186 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState183 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState020 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState179 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState122 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState138 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState174 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState176 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState172 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState170 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState168 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState166 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState164 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState154 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState162 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState156 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState160 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState158 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState152 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState150 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState148 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState142 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState146 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState144 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState140 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState124 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState132 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState136 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState134 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState128 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState130 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState126 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState027 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_457 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState457 _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_047_spec_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState457 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_047_spec_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_047_spec_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_047_spec_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState457
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_047_spec_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState457 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_047_spec_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_047_spec_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_047_spec_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState457 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_42, _startpos_41) in
            let _v = _menhir_action_081 () in
            _menhir_run_047_spec_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_44 ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_46, _startpos_45, _v_44) in
            let _v = _menhir_action_074 c in
            _menhir_run_047_spec_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_48 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_49 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_49, _startpos_48) in
            let _v = _menhir_action_077 () in
            _menhir_run_047_spec_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_51 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_52, _startpos_51) in
            let _v = _menhir_action_078 () in
            _menhir_run_047_spec_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | _ ->
            _eRR 457
    
    and _menhir_run_048 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState048 _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_047_spec_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState048 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_047_spec_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_047_spec_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_047_spec_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState048
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState048
        | Elpi_lexer_config.Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState048
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_047_spec_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState048 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_047_spec_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_047_spec_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_047_spec_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState048 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_42, _startpos_41) in
            let _v = _menhir_action_081 () in
            _menhir_run_047_spec_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_44 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_46, _startpos_45, _v_44) in
            let _v = _menhir_action_074 c in
            _menhir_run_047_spec_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_48 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_49 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_49, _startpos_48) in
            let _v = _menhir_action_077 () in
            _menhir_run_047_spec_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_51 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_52, _startpos_51) in
            let _v = _menhir_action_078 () in
            _menhir_run_047_spec_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.BIND | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let x = _v in
            let _v = _menhir_action_205 x in
            _menhir_goto_nonempty_list_closed_term_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 48
    
    and _menhir_run_047_spec_048 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_closed_term -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_111 t in
        _menhir_run_046_spec_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _tok
    
    and _menhir_run_046_spec_048 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_closed_term -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_073 t in
        _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState048 _tok
    
    and _menhir_run_018 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACKET (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_018 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.RBRACKET ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _v = _menhir_action_161 () in
            _menhir_run_190 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_2, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_018 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PIPE ->
            _menhir_run_020 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState018
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_5) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState018
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState018
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState018
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_6, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_7, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_018 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_11, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_018 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState018
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_12) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_13, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_14) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_15) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | _ ->
            _eRR 18
    
    and _menhir_run_119_spec_018 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACKET -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState018 _tok
    
    and _menhir_run_181 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_122 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (x, _endpos__2_) = (_v, _endpos_0) in
            let _v = _menhir_action_162 x in
            _menhir_goto_list_items _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_179 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.PIPE ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1 ->
                let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_3, _startpos_2, _v_1) in
                let _v = _menhir_action_067 x in
                _menhir_run_119_spec_183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos_5) in
                let _v = _menhir_action_083 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState183 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_8 ->
                let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_10, _startpos_9, _v_8) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_119_spec_183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
                let _v = _menhir_action_082 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState183 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_16 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_16, _startpos_15) in
                let _v = _menhir_action_087 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState183 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
                let _v = _menhir_action_076 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState183 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
            | Elpi_lexer_config.Tokens.IO _v_21 ->
                let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_23, _startpos_22, _v_21) in
                let _v = _menhir_action_080 c in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState183 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_25 ->
                let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_27, _startpos_26, _v_25) in
                let _v = _menhir_action_065 x in
                _menhir_run_119_spec_183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_29 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_30 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_30, _startpos_29) in
                let _v = _menhir_action_079 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState183 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
                let _v = _menhir_action_075 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState183 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_36, _startpos_35) in
                let _v = _menhir_action_084 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState183 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_38 ->
                let _startpos_39 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_40 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_40, _startpos_39, _v_38) in
                let _v = _menhir_action_066 x in
                _menhir_run_119_spec_183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_42 ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_42 MenhirState183
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_43 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_44 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_44, _startpos_43) in
                let _v = _menhir_action_081 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState183 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_46 ->
                let _startpos_47 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_48 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_48, _startpos_47, _v_46) in
                let _v = _menhir_action_074 c in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState183 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_50 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_51 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_51, _startpos_50) in
                let _v = _menhir_action_077 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState183 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_53 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_54 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_54, _startpos_53) in
                let _v = _menhir_action_078 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState183 _tok
            | _ ->
                _eRR 183)
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_138 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_56 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_56
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_57 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_57
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_58 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_58
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_59 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_59
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_60 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_60
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_61 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_61
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_62 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_62
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_63 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_164 _menhir_stack _menhir_lexbuf _menhir_lexer _v_63
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_64 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v_64
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_65 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_65
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_66 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_66
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_67 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_67
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_68 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_68
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_168 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_69 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_70 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos_69, _endpos_70) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_71 ->
                let _startpos_72 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_73 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_73, _startpos_72, _v_71) in
                let _v = _menhir_action_067 x in
                _menhir_run_119_spec_186 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_75 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_76 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_76, _startpos_75) in
                let _v = _menhir_action_083 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState186 _tok
            | Elpi_lexer_config.Tokens.RBRACKET ->
                let _endpos_78 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_78 in
                let _v = _menhir_action_161 () in
                _menhir_run_188 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_80 ->
                let _startpos_81 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_82 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_82, _startpos_81, _v_80) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_119_spec_186 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PIPE ->
                _menhir_run_020 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_84 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_85 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_85, _startpos_84) in
                let _v = _menhir_action_082 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState186 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_87 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_88 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_88, _startpos_87) in
                let _v = _menhir_action_087 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState186 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_90 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_91 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_91, _startpos_90) in
                let _v = _menhir_action_076 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState186 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
            | Elpi_lexer_config.Tokens.IO _v_93 ->
                let _startpos_94 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_95 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_95, _startpos_94, _v_93) in
                let _v = _menhir_action_080 c in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState186 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_97 ->
                let _startpos_98 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_99 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_99, _startpos_98, _v_97) in
                let _v = _menhir_action_065 x in
                _menhir_run_119_spec_186 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_101 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_102 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_102, _startpos_101) in
                let _v = _menhir_action_079 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState186 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_104 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_105 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_105, _startpos_104) in
                let _v = _menhir_action_075 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState186 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_107 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_108 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_108, _startpos_107) in
                let _v = _menhir_action_084 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState186 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_110 ->
                let _startpos_111 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_112 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_112, _startpos_111, _v_110) in
                let _v = _menhir_action_066 x in
                _menhir_run_119_spec_186 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_114 ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_114 MenhirState186
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_115 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_116 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_116, _startpos_115) in
                let _v = _menhir_action_081 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState186 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_118 ->
                let _startpos_119 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_120 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_120, _startpos_119, _v_118) in
                let _v = _menhir_action_074 c in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState186 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_122 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_123 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_123, _startpos_122) in
                let _v = _menhir_action_077 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState186 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_125 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_126 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_126, _startpos_125) in
                let _v = _menhir_action_078 () in
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState186 _tok
            | _ ->
                _eRR 186)
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_176 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 181
    
    and _menhir_run_122 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_VDASH (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_122 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState122 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_122 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState122 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState122 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState122 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState122
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState122
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState122
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState122 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_122 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState122 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState122 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState122 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_122 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState122
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState122 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState122 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState122 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState122 _tok
        | _ ->
            _eRR 122
    
    and _menhir_run_119_spec_122 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_VDASH -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_123 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState122 _tok
    
    and _menhir_run_123 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_VDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_138 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_164 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_168 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_176 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET ->
            let MenhirCell0_VDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_277 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 123
    
    and _menhir_run_124 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_SLASH (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_124 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState124 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_124 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState124 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState124 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState124 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState124
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState124
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState124
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState124 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_124 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState124 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState124 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState124 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_124 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState124
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState124 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState124 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState124 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState124 _tok
        | _ ->
            _eRR 124
    
    and _menhir_run_119_spec_124 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_SLASH -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState124 _tok
    
    and _menhir_run_125 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_SLASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_SLASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_275 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 125
    
    and _menhir_run_126 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_SHARP (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_126 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState126 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_126 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState126 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState126 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState126 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState126
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState126
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState126
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState126 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_126 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState126 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState126 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState126 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_126 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState126
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState126 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState126 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState126 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState126 _tok
        | _ ->
            _eRR 126
    
    and _menhir_run_119_spec_126 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_SHARP -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState126 _tok
    
    and _menhir_run_127 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_SHARP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_SHARP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_258 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 127
    
    and _menhir_run_033 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
        let (_endpos_s_, s) = (_endpos, _v) in
        let _v = _menhir_action_279 l s in
        _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_l_ _v _menhir_s _tok
    
    and _menhir_goto_open_term_noconj : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_316 t in
        _menhir_goto_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_goto_term_noconj : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState183 ->
            _menhir_run_184 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState186 ->
            _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState018 ->
            _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState179 ->
            _menhir_run_180 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState176 ->
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState174 ->
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState172 ->
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState170 ->
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState168 ->
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState166 ->
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState164 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState162 ->
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState160 ->
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState158 ->
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState156 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState154 ->
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState152 ->
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState150 ->
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState148 ->
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState146 ->
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState144 ->
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState142 ->
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState140 ->
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState138 ->
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState136 ->
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState134 ->
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState132 ->
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState130 ->
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState128 ->
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState126 ->
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState124 ->
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState122 ->
            _menhir_run_123 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState020 ->
            _menhir_run_121 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState027 ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_184 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_122 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
            let (xs, _endpos__4_) = (_v, _endpos_0) in
            let _v = _menhir_action_165 x xs in
            _menhir_goto_list_items_tail _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_179 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_138 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_164 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_168 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_176 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 184
    
    and _menhir_goto_list_items_tail : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState018 ->
            _menhir_run_189 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState186 ->
            _menhir_run_187 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_189 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACKET -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_endpos_l_, l) = (_endpos, _v) in
        let _v = _menhir_action_071 l in
        _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_l_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_187 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_166 x xs in
        _menhir_goto_list_items_tail _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_179 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_QDASH (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_179 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState179 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_179 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState179 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState179 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState179 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState179
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState179
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState179
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState179 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_179 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState179 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState179 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState179 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_179 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState179
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState179 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState179 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState179 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState179 _tok
        | _ ->
            _eRR 179
    
    and _menhir_run_119_spec_179 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_QDASH -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_180 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState179 _tok
    
    and _menhir_run_180 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_QDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_138 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_164 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_168 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_176 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET ->
            let MenhirCell0_QDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_274 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 180
    
    and _menhir_run_138 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_OR (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_138 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState138 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_138 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState138 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState138 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState138 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState138 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_138 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState138 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState138 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState138 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_138 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState138
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState138 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState138 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState138 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState138 _tok
        | _ ->
            _eRR 138
    
    and _menhir_run_119_spec_138 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_OR -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState138 _tok
    
    and _menhir_run_139 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_138 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_164 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_168 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_176 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_OR (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_268 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 139
    
    and _menhir_run_140 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MOD (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_140 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState140 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_140 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState140 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState140 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState140 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState140 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_140 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState140 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState140 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState140 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_140 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState140
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState140 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState140 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState140 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState140 _tok
        | _ ->
            _eRR 140
    
    and _menhir_run_119_spec_140 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MOD -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState140 _tok
    
    and _menhir_run_141 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MOD (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_270 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 141
    
    and _menhir_run_128 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_OR (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_128 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState128 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_128 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState128 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState128 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState128 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState128
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState128
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState128
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState128 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_128 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState128 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState128 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState128 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_128 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState128
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState128 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState128 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState128 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState128 _tok
        | _ ->
            _eRR 128
    
    and _menhir_run_119_spec_128 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_OR -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState128 _tok
    
    and _menhir_run_129 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_OR (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_257 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 129
    
    and _menhir_run_130 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_AND (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_130 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState130 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_130 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState130 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState130 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState130 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState130
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState130
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState130
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState130 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_130 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState130 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState130 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState130 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_130 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState130
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState130 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState130 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState130 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState130 _tok
        | _ ->
            _eRR 130
    
    and _menhir_run_119_spec_130 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_AND -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState130 _tok
    
    and _menhir_run_131 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_AND (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_256 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 131
    
    and _menhir_run_116 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_BIND (_menhir_stack, _startpos_0, _endpos_1) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_2 ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_4, _startpos_3, _v_2) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState117 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_9 ->
                let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_11, _startpos_10, _v_9) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_14, _startpos_13) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState117 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState117 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState117 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
            | Elpi_lexer_config.Tokens.IO _v_22 ->
                let _startpos_23 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_24, _startpos_23, _v_22) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState117 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_26 ->
                let _startpos_27 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_28 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_28, _startpos_27, _v_26) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState117 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_33 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_34 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_34, _startpos_33) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState117 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_36 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_37 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_37, _startpos_36) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState117 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_39 ->
                let _startpos_40 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_41 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_41, _startpos_40, _v_39) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_43 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_43 MenhirState117
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_44 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_45 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_45, _startpos_44) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState117 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_47 ->
                let _startpos_48 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_49 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_49, _startpos_48, _v_47) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState117 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_51 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_52, _startpos_51) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState117 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_54 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_55 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_55, _startpos_54) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState117 _tok
            | _ ->
                _eRR 117)
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FLOAT _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.INTEGER _ | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.LBRACKET | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.QUOTED _ | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.STRING _ | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_111 t in
            _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 116
    
    and _menhir_run_052_spec_117 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_constant _menhir_cell0_BIND -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_118 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState117 _tok
    
    and _menhir_run_118 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_constant _menhir_cell0_BIND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET ->
            let MenhirCell0_BIND (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_constant (_menhir_stack, _menhir_s, t, _startpos_t_, _) = _menhir_stack in
            let (_endpos_b_, b) = (_endpos, _v) in
            let _v = _menhir_action_025 b t in
            let (_endpos, _startpos) = (_endpos_b_, _startpos_t_) in
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_317 t in
            _menhir_goto_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 118
    
    and _menhir_run_083 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSi (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_083 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState083 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_083 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState083 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState083 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState083 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState083
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState083
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState083
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState083 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_083 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState083 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState083 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState083 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_083 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState083
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState083 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState083 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState083 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState083 _tok
        | _ ->
            _eRR 83
    
    and _menhir_run_052_spec_083 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUSi -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState083 _tok
    
    and _menhir_run_084 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUSi as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSi (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_232 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 84
    
    and _menhir_run_079 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_DIV (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_079 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState079 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_079 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState079 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState079 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState079 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState079 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_079 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState079 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState079 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState079 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_079 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState079
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState079 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState079 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState079 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState079 _tok
        | _ ->
            _eRR 79
    
    and _menhir_run_052_spec_079 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_DIV -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState079 _tok
    
    and _menhir_run_080 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DIV (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_238 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 80
    
    and _menhir_run_038 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_038 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_038 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState038
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState038
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState038
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_038 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_038 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState038
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | _ ->
            _eRR 38
    
    and _menhir_run_052_spec_038 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_FAMILY_TILDE -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState038 _tok
    
    and _menhir_run_039 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_FAMILY_TILDE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, s, _startpos_s_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_246 r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 39
    
    and _menhir_run_085 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUS (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_085 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState085 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_085 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState085 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState085 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState085 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState085 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_085 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState085 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState085 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState085 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_085 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState085
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState085 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState085 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState085 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState085 _tok
        | _ ->
            _eRR 85
    
    and _menhir_run_052_spec_085 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState085 _tok
    
    and _menhir_run_086 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_230 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 86
    
    and _menhir_run_087 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_IS (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_087 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState087 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_087 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState087 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState087 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState087 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState087 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_087 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState087 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState087 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState087 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_087 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState087
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState087 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState087 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState087 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState087 _tok
        | _ ->
            _eRR 87
    
    and _menhir_run_052_spec_087 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_IS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState087 _tok
    
    and _menhir_run_088 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_IS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_IS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_236 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 88
    
    and _menhir_run_089 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_TICK (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_089 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState089 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_089 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState089 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState089 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState089 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState089 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_089 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState089 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState089 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState089 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_089 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState089
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState089 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState089 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState089 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState089 _tok
        | _ ->
            _eRR 89
    
    and _menhir_run_052_spec_089 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_TICK -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState089 _tok
    
    and _menhir_run_090 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_TICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_227 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 90
    
    and _menhir_run_091 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_PLUS (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_091 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState091 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_091 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState091 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState091 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState091 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState091 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_091 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState091 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState091 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState091 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_091 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState091
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState091 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState091 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState091 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState091 _tok
        | _ ->
            _eRR 91
    
    and _menhir_run_052_spec_091 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_PLUS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState091 _tok
    
    and _menhir_run_092 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_PLUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_216 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 92
    
    and _menhir_run_093 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_EXP (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_093 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState093 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_093 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState093 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState093 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState093 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState093 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_093 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState093 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState093 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState093 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_093 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState093
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState093 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState093 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState093 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState093 _tok
        | _ ->
            _eRR 93
    
    and _menhir_run_052_spec_093 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_EXP -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState093 _tok
    
    and _menhir_run_094 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_EXP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EXP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_219 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 94
    
    and _menhir_run_095 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_CONS (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_095 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState095 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_095 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState095 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState095 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState095 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState095 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_095 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState095 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState095 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState095 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_095 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState095
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState095 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState095 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState095 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState095 _tok
        | _ ->
            _eRR 95
    
    and _menhir_run_052_spec_095 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_CONS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState095 _tok
    
    and _menhir_run_096 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_CONS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_228 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 96
    
    and _menhir_run_097 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_LT (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_097 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState097 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_097 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState097 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState097 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState097 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState097 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_097 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState097 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState097 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState097 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_097 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState097
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState097 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState097 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState097 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState097 _tok
        | _ ->
            _eRR 97
    
    and _menhir_run_052_spec_097 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_LT -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState097 _tok
    
    and _menhir_run_098 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_LT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_220 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 98
    
    and _menhir_run_099 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_GT (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_099 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState099 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_099 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState099 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState099 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState099 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState099 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_099 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState099 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState099 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState099 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_099 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState099
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState099 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState099 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState099 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState099 _tok
        | _ ->
            _eRR 99
    
    and _menhir_run_052_spec_099 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_GT -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState099 _tok
    
    and _menhir_run_100 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_GT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_221 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 100
    
    and _menhir_run_101 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_EQ2 (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_101 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState101 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_101 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState101 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState101 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState101 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState101
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState101
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState101
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState101 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_101 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState101 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState101 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState101 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_101 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState101
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState101 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState101 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState101 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState101 _tok
        | _ ->
            _eRR 101
    
    and _menhir_run_052_spec_101 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_EQ2 -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState101 _tok
    
    and _menhir_run_102 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_EQ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_234 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 102
    
    and _menhir_run_103 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_EQ (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_103 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState103 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_103 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState103 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState103 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState103 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState103
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState103
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState103
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState103 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_103 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState103 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState103 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState103 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_103 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState103
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState103 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState103 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState103 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState103 _tok
        | _ ->
            _eRR 103
    
    and _menhir_run_052_spec_103 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_EQ -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState103 _tok
    
    and _menhir_run_104 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_229 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 104
    
    and _menhir_run_105 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_DARROW (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_105 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState105 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_105 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState105 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState105 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState105 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState105 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_105 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState105 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState105 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState105 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_105 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState105
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState105 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState105 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState105 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState105 _tok
        | _ ->
            _eRR 105
    
    and _menhir_run_052_spec_105 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_DARROW -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState105 _tok
    
    and _menhir_run_106 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_DARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_240 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 106
    
    and _menhir_run_107 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_CONJ2 (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_107 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState107 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_107 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState107 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState107 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState107 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState107
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState107
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState107
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState107 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_107 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState107 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState107 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState107 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_107 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState107
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState107 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState107 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState107 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState107 _tok
        | _ ->
            _eRR 107
    
    and _menhir_run_052_spec_107 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_CONJ2 -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState107 _tok
    
    and _menhir_run_108 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_CONJ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONJ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_243 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 108
    
    and _menhir_run_109 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_109 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState109 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_109 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState109 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState109 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState109 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState109
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState109
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState109
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState109 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_109 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState109 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState109 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState109 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_109 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState109
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState109 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState109 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState109 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState109 _tok
        | _ ->
            _eRR 109
    
    and _menhir_run_052_spec_109 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState109 _tok
    
    and _menhir_run_110 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_CONJ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_244 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 110
    
    and _menhir_run_111 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_ARROW (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_111 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState111 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_111 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState111 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState111 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState111 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState111
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState111
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState111
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState111 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_111 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState111 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState111 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState111 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_111 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState111
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState111 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState111 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState111 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState111 _tok
        | _ ->
            _eRR 111
    
    and _menhir_run_052_spec_111 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_ARROW -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState111 _tok
    
    and _menhir_run_112 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_ARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_ARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_239 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 112
    
    and _menhir_run_027 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_027 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState027 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_027 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState027 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState027 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState027 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState027 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_027 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState027 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState027 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState027 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_027 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState027
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState027 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState027 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState027 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState027 _tok
        | _ ->
            _eRR 27
    
    and _menhir_run_119_spec_027 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_FAMILY_TILDE -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState027 _tok
    
    and _menhir_run_032 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_FAMILY_TILDE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, s, _startpos_s_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_278 r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 32
    
    and _menhir_run_132 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_MINUS (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_132 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState132 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_132 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState132 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState132 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState132 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState132 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_132 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState132 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState132 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState132 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_132 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState132
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState132 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState132 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState132 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState132 _tok
        | _ ->
            _eRR 132
    
    and _menhir_run_119_spec_132 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_MINUS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState132 _tok
    
    and _menhir_run_133 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_MINUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_251 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 133
    
    and _menhir_run_134 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_EQ (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_134 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState134 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_134 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState134 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState134 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState134 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState134 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_134 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState134 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState134 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState134 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_134 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState134
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState134 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState134 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState134 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState134 _tok
        | _ ->
            _eRR 134
    
    and _menhir_run_119_spec_134 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EQ -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState134 _tok
    
    and _menhir_run_135 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EQ (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_255 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 135
    
    and _menhir_run_136 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_BTICK (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_136 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState136 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_136 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState136 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState136 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState136 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState136 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_136 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState136 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState136 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState136 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_136 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState136
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState136 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState136 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState136 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState136 _tok
        | _ ->
            _eRR 136
    
    and _menhir_run_119_spec_136 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_BTICK -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState136 _tok
    
    and _menhir_run_137 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_BTICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_BTICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_259 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 137
    
    and _menhir_run_142 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSs (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_142 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState142 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_142 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState142 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState142 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState142 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState142
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState142
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState142
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState142 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_142 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState142 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState142 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState142 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_142 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState142
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState142 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState142 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState142 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState142 _tok
        | _ ->
            _eRR 142
    
    and _menhir_run_119_spec_142 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUSs -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState142 _tok
    
    and _menhir_run_143 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUSs as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSs (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_266 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 143
    
    and _menhir_run_144 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_TIMES (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_144 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState144 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_144 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState144 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState144 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState144 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState144
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState144
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState144
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState144 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_144 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState144 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState144 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState144 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_144 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState144
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState144 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState144 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState144 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState144 _tok
        | _ ->
            _eRR 144
    
    and _menhir_run_119_spec_144 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TIMES -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState144 _tok
    
    and _menhir_run_145 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TIMES as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TIMES (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_250 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 145
    
    and _menhir_run_146 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_DIV (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_146 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState146 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_146 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState146 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState146 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState146 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState146
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState146
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState146
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState146 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_146 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState146 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState146 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState146 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_146 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState146
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState146 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState146 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState146 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState146 _tok
        | _ ->
            _eRR 146
    
    and _menhir_run_119_spec_146 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_DIV -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState146 _tok
    
    and _menhir_run_147 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DIV (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_271 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 147
    
    and _menhir_run_148 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSr (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_148 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState148 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_148 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState148 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState148 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState148 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState148
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState148
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState148
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState148 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_148 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState148 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState148 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState148 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_148 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState148
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState148 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState148 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState148 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState148 _tok
        | _ ->
            _eRR 148
    
    and _menhir_run_119_spec_148 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUSr -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState148 _tok
    
    and _menhir_run_149 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUSr as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSr (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_264 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 149
    
    and _menhir_run_150 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSi (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_150 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState150 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_150 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState150 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState150 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState150 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState150
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState150
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState150
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState150 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_150 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState150 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState150 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState150 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_150 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState150
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState150 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState150 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState150 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState150 _tok
        | _ ->
            _eRR 150
    
    and _menhir_run_119_spec_150 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUSi -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState150 _tok
    
    and _menhir_run_151 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUSi as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSi (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_265 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 151
    
    and _menhir_run_152 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUS (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_152 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState152 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_152 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState152 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState152 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState152 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState152
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState152
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState152
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState152 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_152 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState152 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState152 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState152 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_152 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState152
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState152 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState152 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState152 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState152 _tok
        | _ ->
            _eRR 152
    
    and _menhir_run_119_spec_152 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState152 _tok
    
    and _menhir_run_153 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_263 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 153
    
    and _menhir_run_154 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_IS (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_154 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState154 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_154 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState154 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState154 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState154 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState154
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState154
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState154
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState154 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_154 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState154 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState154 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState154 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_154 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState154
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState154 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState154 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState154 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState154 _tok
        | _ ->
            _eRR 154
    
    and _menhir_run_119_spec_154 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_IS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState154 _tok
    
    and _menhir_run_155 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_IS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_IS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_269 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 155
    
    and _menhir_run_156 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_TICK (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_156 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState156 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_156 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState156 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState156 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState156 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState156 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_156 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState156 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState156 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState156 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_156 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState156
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState156 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState156 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState156 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState156 _tok
        | _ ->
            _eRR 156
    
    and _menhir_run_119_spec_156 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TICK -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState156 _tok
    
    and _menhir_run_157 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_260 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 157
    
    and _menhir_run_158 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_PLUS (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState158 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState158 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState158 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState158 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState158 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState158 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState158 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState158 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState158
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState158 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState158 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState158 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState158 _tok
        | _ ->
            _eRR 158
    
    and _menhir_run_119_spec_158 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_PLUS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState158 _tok
    
    and _menhir_run_159 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_PLUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_249 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 159
    
    and _menhir_run_160 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_EXP (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_160 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState160 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_160 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState160 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState160 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState160 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState160
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState160
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState160
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState160 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_160 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState160 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState160 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState160 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_160 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState160
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState160 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState160 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState160 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState160 _tok
        | _ ->
            _eRR 160
    
    and _menhir_run_119_spec_160 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EXP -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState160 _tok
    
    and _menhir_run_161 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EXP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EXP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_252 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 161
    
    and _menhir_run_162 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_CONS (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_162 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState162 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_162 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState162 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState162 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState162 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState162
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState162
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState162
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState162 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_162 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState162 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState162 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState162 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_162 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState162
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState162 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState162 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState162 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState162 _tok
        | _ ->
            _eRR 162
    
    and _menhir_run_119_spec_162 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState162 _tok
    
    and _menhir_run_163 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_261 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 163
    
    and _menhir_run_164 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_LT (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_164 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState164 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_164 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState164 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState164 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState164 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState164
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState164
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState164
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState164 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_164 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState164 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState164 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState164 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_164 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState164
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState164 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState164 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState164 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState164 _tok
        | _ ->
            _eRR 164
    
    and _menhir_run_119_spec_164 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_LT -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState164 _tok
    
    and _menhir_run_165 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_LT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_253 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 165
    
    and _menhir_run_166 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_GT (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_166 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState166 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_166 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState166 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState166 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState166 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState166
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState166
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState166
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState166 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_166 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState166 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState166 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState166 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_166 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState166
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState166 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState166 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState166 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState166 _tok
        | _ ->
            _eRR 166
    
    and _menhir_run_119_spec_166 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_GT -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState166 _tok
    
    and _menhir_run_167 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_GT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_254 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 167
    
    and _menhir_run_168 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_EQ2 (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_168 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState168 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_168 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState168 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState168 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState168 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState168
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState168
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState168
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState168 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_168 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState168 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState168 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState168 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_168 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState168
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState168 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState168 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState168 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState168 _tok
        | _ ->
            _eRR 168
    
    and _menhir_run_119_spec_168 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_EQ2 -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState168 _tok
    
    and _menhir_run_169 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_EQ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_267 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 169
    
    and _menhir_run_170 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_EQ (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_170 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState170 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_170 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState170 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState170 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState170 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState170
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState170
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState170
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState170 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_170 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState170 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState170 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState170 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_170 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState170
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState170 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState170 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState170 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState170 _tok
        | _ ->
            _eRR 170
    
    and _menhir_run_119_spec_170 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_EQ -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState170 _tok
    
    and _menhir_run_171 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_262 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 171
    
    and _menhir_run_172 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_DARROW (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_172 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState172 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_172 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState172 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState172 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState172 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState172 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_172 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState172 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState172 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState172 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_172 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState172
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState172 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState172 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState172 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState172 _tok
        | _ ->
            _eRR 172
    
    and _menhir_run_119_spec_172 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_DARROW -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState172 _tok
    
    and _menhir_run_173 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_DARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_164 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_168 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_273 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 173
    
    and _menhir_run_174 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_CONJ2 (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_174 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState174 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_174 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState174 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState174 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState174 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState174
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState174
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState174
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState174 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_174 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState174 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState174 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState174 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_174 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState174
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState174 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState174 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState174 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState174 _tok
        | _ ->
            _eRR 174
    
    and _menhir_run_119_spec_174 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONJ2 -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState174 _tok
    
    and _menhir_run_175 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONJ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_164 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_168 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_176 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONJ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_276 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 175
    
    and _menhir_run_176 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_ARROW (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_176 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState176 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_5, _startpos_4, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_176 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState176 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState176 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState176 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState176
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState176
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState176
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_13, _startpos_12, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState176 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_176 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState176 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState176 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState176 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_23, _startpos_22, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_176 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState176
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState176 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState176 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState176 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState176 _tok
        | _ ->
            _eRR 176
    
    and _menhir_run_119_spec_176 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_ARROW -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState176 _tok
    
    and _menhir_run_177 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_ARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_164 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_168 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_176 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_ARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_272 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 177
    
    and _menhir_run_121 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_PIPE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_122 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_PIPE (_menhir_stack, _menhir_s) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_164 x in
            _menhir_goto_list_items_tail _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_179 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_138 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_164 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_168 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_176 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 121
    
    and _menhir_goto_list_items : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState018 ->
            _menhir_run_190 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState186 ->
            _menhir_run_188 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_190 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACKET -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_endpos_l_, l) = (_endpos, _v) in
        let _v = _menhir_action_070 l in
        _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_l_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_188 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_163 x xs in
        _menhir_goto_list_items _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_119_spec_183 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_184 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState183 _tok
    
    and _menhir_run_119_spec_186 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState186 _tok
    
    and _menhir_run_020 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_PIPE (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_119_spec_020 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState020 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_119_spec_020 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_082 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState020 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_087 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState020 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState020 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState020 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_119_spec_020 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState020 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_075 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState020 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState020 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_119_spec_020 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState020 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState020 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState020 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState020 _tok
        | _ ->
            _eRR 20
    
    and _menhir_run_119_spec_020 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_PIPE -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_run_121 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState020 _tok
    
    and _menhir_goto_nonempty_list_closed_term_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState457 ->
            _menhir_run_458 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState048 ->
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState042 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState035 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_458 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState458
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let _v = _menhir_action_282 () in
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _eRR 458
    
    and _menhir_run_459 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term, _menhir_box_program) _menhir_cell1_nonempty_list_closed_term_ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _, args) = _menhir_stack in
        let MenhirCell1_head_term (_menhir_stack, _menhir_s, hd, _startpos_hd_, _endpos_hd_) = _menhir_stack in
        let (_endpos_b_, b) = (_endpos, _v) in
        let _v = _menhir_action_031 _endpos_hd_ _startpos_hd_ args b hd in
        _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_hd_ _v _menhir_s _tok
    
    and _menhir_goto_clause_hd_open_term : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_063 t in
        _menhir_goto_clause_hd_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_goto_clause_hd_term : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_VDASH (_menhir_stack, _startpos_0, _endpos_1) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_2 ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_4, _startpos_3, _v_2) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_462 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState462 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_9 ->
                let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_11, _startpos_10, _v_9) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_462 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_14, _startpos_13) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState462 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState462 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState462 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState462
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState462
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState462
            | Elpi_lexer_config.Tokens.IO _v_22 ->
                let _startpos_23 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_24, _startpos_23, _v_22) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState462 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_26 ->
                let _startpos_27 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_28 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_28, _startpos_27, _v_26) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_462 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState462 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_33 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_34 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_34, _startpos_33) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState462 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_36 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_37 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_37, _startpos_36) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState462 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_39 ->
                let _startpos_40 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_41 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_41, _startpos_40, _v_39) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_462 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_43 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_43 MenhirState462
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_44 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_45 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_45, _startpos_44) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState462 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_47 ->
                let _startpos_48 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_49 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_49, _startpos_48, _v_47) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState462 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_51 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_52, _startpos_51) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState462 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_54 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_55 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_55, _startpos_54) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState462 _tok
            | _ ->
                _eRR 462)
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_57 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_58 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_SLASH (_menhir_stack, _startpos_57, _endpos_58) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_59 ->
                let _startpos_60 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_61 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_61, _startpos_60, _v_59) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_464 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_63 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_64 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_64, _startpos_63) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState464 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_66 ->
                let _startpos_67 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_68 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_68, _startpos_67, _v_66) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_464 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_70 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_71 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_71, _startpos_70) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState464 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_73 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_74 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_74, _startpos_73) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState464 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_76 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_77 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_77, _startpos_76) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState464 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState464
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState464
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState464
            | Elpi_lexer_config.Tokens.IO _v_79 ->
                let _startpos_80 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_81 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_81, _startpos_80, _v_79) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState464 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_83 ->
                let _startpos_84 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_85 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_85, _startpos_84, _v_83) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_464 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_87 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_88 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_88, _startpos_87) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState464 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_90 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_91 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_91, _startpos_90) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState464 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_93 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_94 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_94, _startpos_93) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState464 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_96 ->
                let _startpos_97 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_98 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_98, _startpos_97, _v_96) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_464 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_100 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_100 MenhirState464
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_101 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_102 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_102, _startpos_101) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState464 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_104 ->
                let _startpos_105 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_106 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_106, _startpos_105, _v_104) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState464 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_108 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_109 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_109, _startpos_108) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState464 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_111 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_112 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_112, _startpos_111) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState464 _tok
            | _ ->
                _eRR 464)
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_114 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_115 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_QDASH (_menhir_stack, _startpos_114, _endpos_115) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_116 ->
                let _startpos_117 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_118 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_118, _startpos_117, _v_116) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_466 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_120 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_121 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_121, _startpos_120) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState466 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_123 ->
                let _startpos_124 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_125 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_125, _startpos_124, _v_123) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_466 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_127 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_128 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_128, _startpos_127) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState466 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_130 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_131 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_131, _startpos_130) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState466 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_133 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_134 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_134, _startpos_133) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState466 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState466
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState466
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState466
            | Elpi_lexer_config.Tokens.IO _v_136 ->
                let _startpos_137 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_138 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_138, _startpos_137, _v_136) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState466 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_140 ->
                let _startpos_141 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_142 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_142, _startpos_141, _v_140) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_466 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_144 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_145 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_145, _startpos_144) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState466 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_147 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_148 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_148, _startpos_147) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState466 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_150 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_151 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_151, _startpos_150) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState466 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_153 ->
                let _startpos_154 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_155 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_155, _startpos_154, _v_153) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_466 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_157 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_157 MenhirState466
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_158 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_159 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_159, _startpos_158) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState466 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_161 ->
                let _startpos_162 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_163 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_163, _startpos_162, _v_161) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState466 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_165 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_166 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_166, _startpos_165) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState466 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_168 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_169 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_169, _startpos_168) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState466 _tok
            | _ ->
                _eRR 466)
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_171 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_172 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_OR (_menhir_stack, _startpos_171, _endpos_172) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_173 ->
                let _startpos_174 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_175 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_175, _startpos_174, _v_173) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_468 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_177 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_178 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_178, _startpos_177) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState468 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_180 ->
                let _startpos_181 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_182 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_182, _startpos_181, _v_180) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_468 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_184 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_185 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_185, _startpos_184) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState468 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_187 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_188 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_188, _startpos_187) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState468 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_190 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_191 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_191, _startpos_190) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState468 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState468
            | Elpi_lexer_config.Tokens.IO _v_193 ->
                let _startpos_194 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_195 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_195, _startpos_194, _v_193) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState468 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_197 ->
                let _startpos_198 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_199 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_199, _startpos_198, _v_197) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_468 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_201 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_202 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_202, _startpos_201) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState468 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_204 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_205 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_205, _startpos_204) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState468 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_207 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_208 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_208, _startpos_207) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState468 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_210 ->
                let _startpos_211 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_212 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_212, _startpos_211, _v_210) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_468 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_214 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_214 MenhirState468
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_215 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_216 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_216, _startpos_215) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState468 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_218 ->
                let _startpos_219 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_220 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_220, _startpos_219, _v_218) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState468 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_222 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_223 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_223, _startpos_222) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState468 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_225 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_226 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_226, _startpos_225) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState468 _tok
            | _ ->
                _eRR 468)
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_228 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_229 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MOD (_menhir_stack, _startpos_228, _endpos_229) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_230 ->
                let _startpos_231 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_232 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_232, _startpos_231, _v_230) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_470 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_234 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_235 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_235, _startpos_234) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState470 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_237 ->
                let _startpos_238 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_239 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_239, _startpos_238, _v_237) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_470 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_241 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_242 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_242, _startpos_241) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState470 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_244 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_245 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_245, _startpos_244) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState470 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_247 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_248 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_248, _startpos_247) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState470 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState470
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState470
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState470
            | Elpi_lexer_config.Tokens.IO _v_250 ->
                let _startpos_251 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_252 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_252, _startpos_251, _v_250) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState470 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_254 ->
                let _startpos_255 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_256 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_256, _startpos_255, _v_254) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_470 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_258 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_259 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_259, _startpos_258) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState470 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_261 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_262 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_262, _startpos_261) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState470 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_264 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_265 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_265, _startpos_264) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState470 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_267 ->
                let _startpos_268 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_269 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_269, _startpos_268, _v_267) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_470 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_271 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_271 MenhirState470
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_272 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_273 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_273, _startpos_272) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState470 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_275 ->
                let _startpos_276 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_277 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_277, _startpos_276, _v_275) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState470 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_279 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_280 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_280, _startpos_279) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState470 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_282 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_283 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_283, _startpos_282) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState470 _tok
            | _ ->
                _eRR 470)
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_285 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_286 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUSs (_menhir_stack, _startpos_285, _endpos_286) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_287 ->
                let _startpos_288 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_289 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_289, _startpos_288, _v_287) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_472 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_291 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_292 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_292, _startpos_291) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState472 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_294 ->
                let _startpos_295 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_296 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_296, _startpos_295, _v_294) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_472 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_298 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_299 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_299, _startpos_298) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState472 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_301 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_302 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_302, _startpos_301) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState472 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_304 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_305 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_305, _startpos_304) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState472 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState472
            | Elpi_lexer_config.Tokens.IO _v_307 ->
                let _startpos_308 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_309 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_309, _startpos_308, _v_307) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState472 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_311 ->
                let _startpos_312 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_313 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_313, _startpos_312, _v_311) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_472 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_315 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_316 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_316, _startpos_315) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState472 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_318 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_319 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_319, _startpos_318) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState472 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_321 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_322 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_322, _startpos_321) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState472 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_324 ->
                let _startpos_325 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_326 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_326, _startpos_325, _v_324) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_472 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_328 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_328 MenhirState472
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_329 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_330 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_330, _startpos_329) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState472 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_332 ->
                let _startpos_333 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_334 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_334, _startpos_333, _v_332) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState472 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_336 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_337 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_337, _startpos_336) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState472 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_339 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_340 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_340, _startpos_339) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState472 _tok
            | _ ->
                _eRR 472)
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_342 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_343 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUSr (_menhir_stack, _startpos_342, _endpos_343) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_344 ->
                let _startpos_345 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_346 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_346, _startpos_345, _v_344) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_474 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_348 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_349 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_349, _startpos_348) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState474 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_351 ->
                let _startpos_352 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_353 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_353, _startpos_352, _v_351) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_474 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_355 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_356 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_356, _startpos_355) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState474 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_358 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_359 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_359, _startpos_358) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState474 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_361 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_362 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_362, _startpos_361) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState474 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
            | Elpi_lexer_config.Tokens.IO _v_364 ->
                let _startpos_365 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_366 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_366, _startpos_365, _v_364) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState474 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_368 ->
                let _startpos_369 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_370 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_370, _startpos_369, _v_368) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_474 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_372 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_373 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_373, _startpos_372) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState474 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_375 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_376 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_376, _startpos_375) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState474 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_378 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_379 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_379, _startpos_378) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState474 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_381 ->
                let _startpos_382 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_383 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_383, _startpos_382, _v_381) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_474 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_385 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_385 MenhirState474
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_386 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_387 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_387, _startpos_386) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState474 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_389 ->
                let _startpos_390 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_391 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_391, _startpos_390, _v_389) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState474 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_393 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_394 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_394, _startpos_393) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState474 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_396 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_397 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_397, _startpos_396) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState474 _tok
            | _ ->
                _eRR 474)
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_399 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_400 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUSi (_menhir_stack, _startpos_399, _endpos_400) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_401 ->
                let _startpos_402 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_403 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_403, _startpos_402, _v_401) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_476 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_405 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_406 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_406, _startpos_405) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState476 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_408 ->
                let _startpos_409 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_410 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_410, _startpos_409, _v_408) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_476 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_412 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_413 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_413, _startpos_412) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState476 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_415 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_416 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_416, _startpos_415) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState476 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_418 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_419 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_419, _startpos_418) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState476 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
            | Elpi_lexer_config.Tokens.IO _v_421 ->
                let _startpos_422 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_423 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_423, _startpos_422, _v_421) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState476 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_425 ->
                let _startpos_426 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_427 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_427, _startpos_426, _v_425) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_476 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_429 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_430 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_430, _startpos_429) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState476 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_432 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_433 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_433, _startpos_432) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState476 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_435 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_436 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_436, _startpos_435) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState476 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_438 ->
                let _startpos_439 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_440 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_440, _startpos_439, _v_438) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_476 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_442 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_442 MenhirState476
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_443 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_444 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_444, _startpos_443) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState476 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_446 ->
                let _startpos_447 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_448 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_448, _startpos_447, _v_446) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState476 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_450 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_451 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_451, _startpos_450) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState476 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_453 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_454 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_454, _startpos_453) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState476 _tok
            | _ ->
                _eRR 476)
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_456 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_457 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUS (_menhir_stack, _startpos_456, _endpos_457) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_458 ->
                let _startpos_459 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_460 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_460, _startpos_459, _v_458) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_462 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_463 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_463, _startpos_462) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState478 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_465 ->
                let _startpos_466 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_467 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_467, _startpos_466, _v_465) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_469 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_470 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_470, _startpos_469) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState478 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_472 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_473 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_473, _startpos_472) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState478 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_475 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_476 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_476, _startpos_475) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState478 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState478
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState478
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState478
            | Elpi_lexer_config.Tokens.IO _v_478 ->
                let _startpos_479 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_480 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_480, _startpos_479, _v_478) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState478 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_482 ->
                let _startpos_483 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_484 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_484, _startpos_483, _v_482) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_486 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_487 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_487, _startpos_486) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState478 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_489 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_490 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_490, _startpos_489) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState478 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_492 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_493 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_493, _startpos_492) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState478 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_495 ->
                let _startpos_496 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_497 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_497, _startpos_496, _v_495) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_499 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_499 MenhirState478
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_500 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_501 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_501, _startpos_500) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState478 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_503 ->
                let _startpos_504 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_505 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_505, _startpos_504, _v_503) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState478 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_507 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_508 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_508, _startpos_507) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState478 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_510 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_511 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_511, _startpos_510) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState478 _tok
            | _ ->
                _eRR 478)
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_513 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_514 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IS (_menhir_stack, _startpos_513, _endpos_514) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_515 ->
                let _startpos_516 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_517 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_517, _startpos_516, _v_515) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_480 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_519 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_520 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_520, _startpos_519) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState480 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_522 ->
                let _startpos_523 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_524 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_524, _startpos_523, _v_522) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_480 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_526 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_527 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_527, _startpos_526) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState480 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_529 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_530 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_530, _startpos_529) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState480 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_532 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_533 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_533, _startpos_532) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState480 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState480
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState480
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState480
            | Elpi_lexer_config.Tokens.IO _v_535 ->
                let _startpos_536 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_537 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_537, _startpos_536, _v_535) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState480 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_539 ->
                let _startpos_540 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_541 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_541, _startpos_540, _v_539) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_480 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_543 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_544 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_544, _startpos_543) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState480 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_546 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_547 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_547, _startpos_546) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState480 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_549 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_550 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_550, _startpos_549) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState480 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_552 ->
                let _startpos_553 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_554 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_554, _startpos_553, _v_552) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_480 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_556 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_556 MenhirState480
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_557 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_558 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_558, _startpos_557) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState480 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_560 ->
                let _startpos_561 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_562 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_562, _startpos_561, _v_560) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState480 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_564 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_565 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_565, _startpos_564) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState480 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_567 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_568 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_568, _startpos_567) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState480 _tok
            | _ ->
                _eRR 480)
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_570 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_571 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_572 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_TIMES (_menhir_stack, _v_570, _startpos_571, _endpos_572) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_573 ->
                let _startpos_574 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_575 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_575, _startpos_574, _v_573) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_482 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_577 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_578 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_578, _startpos_577) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState482 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_580 ->
                let _startpos_581 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_582 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_582, _startpos_581, _v_580) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_482 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_584 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_585 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_585, _startpos_584) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState482 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_587 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_588 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_588, _startpos_587) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState482 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_590 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_591 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_591, _startpos_590) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState482 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
            | Elpi_lexer_config.Tokens.IO _v_593 ->
                let _startpos_594 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_595 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_595, _startpos_594, _v_593) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState482 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_597 ->
                let _startpos_598 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_599 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_599, _startpos_598, _v_597) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_482 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_601 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_602 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_602, _startpos_601) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState482 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_604 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_605 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_605, _startpos_604) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState482 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_607 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_608 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_608, _startpos_607) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState482 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_610 ->
                let _startpos_611 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_612 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_612, _startpos_611, _v_610) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_482 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_614 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_614 MenhirState482
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_615 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_616 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_616, _startpos_615) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState482 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_618 ->
                let _startpos_619 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_620 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_620, _startpos_619, _v_618) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState482 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_622 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_623 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_623, _startpos_622) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState482 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_625 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_626 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_626, _startpos_625) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState482 _tok
            | _ ->
                _eRR 482)
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_628 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_629 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_630 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_TICK (_menhir_stack, _v_628, _startpos_629, _endpos_630) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_631 ->
                let _startpos_632 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_633 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_633, _startpos_632, _v_631) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_484 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_635 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_636 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_636, _startpos_635) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState484 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_638 ->
                let _startpos_639 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_640 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_640, _startpos_639, _v_638) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_484 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_642 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_643 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_643, _startpos_642) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState484 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_645 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_646 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_646, _startpos_645) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState484 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_648 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_649 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_649, _startpos_648) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState484 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState484
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState484
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState484
            | Elpi_lexer_config.Tokens.IO _v_651 ->
                let _startpos_652 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_653 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_653, _startpos_652, _v_651) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState484 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_655 ->
                let _startpos_656 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_657 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_657, _startpos_656, _v_655) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_484 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_659 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_660 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_660, _startpos_659) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState484 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_662 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_663 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_663, _startpos_662) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState484 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_665 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_666 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_666, _startpos_665) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState484 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_668 ->
                let _startpos_669 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_670 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_670, _startpos_669, _v_668) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_484 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_672 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_672 MenhirState484
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_673 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_674 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_674, _startpos_673) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState484 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_676 ->
                let _startpos_677 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_678 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_678, _startpos_677, _v_676) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState484 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_680 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_681 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_681, _startpos_680) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState484 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_683 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_684 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_684, _startpos_683) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState484 _tok
            | _ ->
                _eRR 484)
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_686 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_687 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_688 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_SHARP (_menhir_stack, _v_686, _startpos_687, _endpos_688) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_689 ->
                let _startpos_690 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_691 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_691, _startpos_690, _v_689) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_486 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_693 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_694 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_694, _startpos_693) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState486 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_696 ->
                let _startpos_697 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_698 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_698, _startpos_697, _v_696) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_486 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_700 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_701 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_701, _startpos_700) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState486 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_703 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_704 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_704, _startpos_703) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState486 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_706 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_707 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_707, _startpos_706) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState486 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState486
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState486
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState486
            | Elpi_lexer_config.Tokens.IO _v_709 ->
                let _startpos_710 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_711 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_711, _startpos_710, _v_709) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState486 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_713 ->
                let _startpos_714 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_715 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_715, _startpos_714, _v_713) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_486 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_717 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_718 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_718, _startpos_717) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState486 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_720 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_721 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_721, _startpos_720) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState486 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_723 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_724 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_724, _startpos_723) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState486 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_726 ->
                let _startpos_727 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_728 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_728, _startpos_727, _v_726) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_486 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_730 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_730 MenhirState486
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_731 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_732 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_732, _startpos_731) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState486 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_734 ->
                let _startpos_735 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_736 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_736, _startpos_735, _v_734) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState486 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_738 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_739 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_739, _startpos_738) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState486 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_741 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_742 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_742, _startpos_741) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState486 _tok
            | _ ->
                _eRR 486)
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_744 ->
            let _endpos_746 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s, _startpos_l_, l) = (_endpos_746, _v_744, _startpos, _v) in
            let _v = _menhir_action_062 l s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_l_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_747 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_748 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_749 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_PLUS (_menhir_stack, _v_747, _startpos_748, _endpos_749) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_750 ->
                let _startpos_751 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_752 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_752, _startpos_751, _v_750) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_489 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_754 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_755 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_755, _startpos_754) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_757 ->
                let _startpos_758 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_759 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_759, _startpos_758, _v_757) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_489 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_761 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_762 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_762, _startpos_761) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_764 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_765 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_765, _startpos_764) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_767 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_768 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_768, _startpos_767) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
            | Elpi_lexer_config.Tokens.IO _v_770 ->
                let _startpos_771 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_772 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_772, _startpos_771, _v_770) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_774 ->
                let _startpos_775 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_776 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_776, _startpos_775, _v_774) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_489 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_778 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_779 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_779, _startpos_778) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_781 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_782 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_782, _startpos_781) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_784 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_785 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_785, _startpos_784) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_787 ->
                let _startpos_788 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_789 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_789, _startpos_788, _v_787) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_489 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_791 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_791 MenhirState489
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_792 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_793 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_793, _startpos_792) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_795 ->
                let _startpos_796 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_797 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_797, _startpos_796, _v_795) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_799 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_800 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_800, _startpos_799) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_802 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_803 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_803, _startpos_802) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | _ ->
                _eRR 489)
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_805 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_806 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_807 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_OR (_menhir_stack, _v_805, _startpos_806, _endpos_807) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_808 ->
                let _startpos_809 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_810 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_810, _startpos_809, _v_808) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_812 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_813 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_813, _startpos_812) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState491 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_815 ->
                let _startpos_816 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_817 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_817, _startpos_816, _v_815) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_819 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_820 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_820, _startpos_819) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState491 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_822 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_823 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_823, _startpos_822) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState491 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_825 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_826 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_826, _startpos_825) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState491 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState491
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState491
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState491
            | Elpi_lexer_config.Tokens.IO _v_828 ->
                let _startpos_829 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_830 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_830, _startpos_829, _v_828) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState491 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_832 ->
                let _startpos_833 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_834 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_834, _startpos_833, _v_832) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_836 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_837 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_837, _startpos_836) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState491 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_839 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_840 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_840, _startpos_839) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState491 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_842 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_843 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_843, _startpos_842) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState491 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_845 ->
                let _startpos_846 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_847 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_847, _startpos_846, _v_845) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_849 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_849 MenhirState491
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_850 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_851 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_851, _startpos_850) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState491 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_853 ->
                let _startpos_854 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_855 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_855, _startpos_854, _v_853) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState491 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_857 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_858 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_858, _startpos_857) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState491 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_860 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_861 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_861, _startpos_860) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState491 _tok
            | _ ->
                _eRR 491)
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_863 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_864 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_865 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_MINUS (_menhir_stack, _v_863, _startpos_864, _endpos_865) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_866 ->
                let _startpos_867 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_868 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_868, _startpos_867, _v_866) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_493 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_870 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_871 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_871, _startpos_870) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState493 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_873 ->
                let _startpos_874 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_875 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_875, _startpos_874, _v_873) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_493 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_877 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_878 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_878, _startpos_877) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState493 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_880 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_881 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_881, _startpos_880) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState493 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_883 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_884 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_884, _startpos_883) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState493 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState493
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState493
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState493
            | Elpi_lexer_config.Tokens.IO _v_886 ->
                let _startpos_887 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_888 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_888, _startpos_887, _v_886) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState493 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_890 ->
                let _startpos_891 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_892 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_892, _startpos_891, _v_890) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_493 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_894 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_895 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_895, _startpos_894) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState493 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_897 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_898 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_898, _startpos_897) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState493 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_900 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_901 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_901, _startpos_900) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState493 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_903 ->
                let _startpos_904 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_905 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_905, _startpos_904, _v_903) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_493 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_907 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_907 MenhirState493
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_908 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_909 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_909, _startpos_908) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState493 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_911 ->
                let _startpos_912 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_913 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_913, _startpos_912, _v_911) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState493 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_915 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_916 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_916, _startpos_915) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState493 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_918 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_919 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_919, _startpos_918) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState493 _tok
            | _ ->
                _eRR 493)
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_921 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_922 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_923 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_LT (_menhir_stack, _v_921, _startpos_922, _endpos_923) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_924 ->
                let _startpos_925 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_926 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_926, _startpos_925, _v_924) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_495 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_928 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_929 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_929, _startpos_928) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState495 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_931 ->
                let _startpos_932 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_933 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_933, _startpos_932, _v_931) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_495 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_935 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_936 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_936, _startpos_935) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState495 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_938 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_939 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_939, _startpos_938) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState495 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_941 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_942 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_942, _startpos_941) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState495 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState495
            | Elpi_lexer_config.Tokens.IO _v_944 ->
                let _startpos_945 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_946 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_946, _startpos_945, _v_944) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState495 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_948 ->
                let _startpos_949 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_950 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_950, _startpos_949, _v_948) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_495 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_952 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_953 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_953, _startpos_952) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState495 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_955 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_956 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_956, _startpos_955) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState495 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_958 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_959 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_959, _startpos_958) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState495 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_961 ->
                let _startpos_962 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_963 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_963, _startpos_962, _v_961) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_495 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_965 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_965 MenhirState495
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_966 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_967 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_967, _startpos_966) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState495 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_969 ->
                let _startpos_970 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_971 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_971, _startpos_970, _v_969) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState495 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_973 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_974 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_974, _startpos_973) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState495 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_976 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_977 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_977, _startpos_976) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState495 _tok
            | _ ->
                _eRR 495)
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_979 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_980 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_981 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_GT (_menhir_stack, _v_979, _startpos_980, _endpos_981) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_982 ->
                let _startpos_983 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_984 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_984, _startpos_983, _v_982) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_497 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_986 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_987 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_987, _startpos_986) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState497 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_989 ->
                let _startpos_990 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_991 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_991, _startpos_990, _v_989) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_497 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_993 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_994 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_994, _startpos_993) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState497 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_996 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_997 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_997, _startpos_996) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState497 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_999 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1000 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1000, _startpos_999) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState497 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState497
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState497
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState497
            | Elpi_lexer_config.Tokens.IO _v_1002 ->
                let _startpos_1003 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1004 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1004, _startpos_1003, _v_1002) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState497 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1006 ->
                let _startpos_1007 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1008 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1008, _startpos_1007, _v_1006) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_497 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1010 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1011 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1011, _startpos_1010) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState497 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1013 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1014 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1014, _startpos_1013) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState497 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1016 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1017 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1017, _startpos_1016) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState497 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1019 ->
                let _startpos_1020 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1021 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1021, _startpos_1020, _v_1019) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_497 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1023 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1023 MenhirState497
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1024 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1025 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1025, _startpos_1024) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState497 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1027 ->
                let _startpos_1028 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1029 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1029, _startpos_1028, _v_1027) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState497 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1031 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1032 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1032, _startpos_1031) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState497 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1034 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1035 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1035, _startpos_1034) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState497 _tok
            | _ ->
                _eRR 497)
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_1037 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1038 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1039 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_EXP (_menhir_stack, _v_1037, _startpos_1038, _endpos_1039) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1040 ->
                let _startpos_1041 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1042 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1042, _startpos_1041, _v_1040) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_499 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1044 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1045 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1045, _startpos_1044) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState499 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1047 ->
                let _startpos_1048 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1049 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1049, _startpos_1048, _v_1047) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_499 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1051 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1052 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1052, _startpos_1051) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState499 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1054 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1055 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1055, _startpos_1054) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState499 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1057 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1058 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1058, _startpos_1057) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState499 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState499
            | Elpi_lexer_config.Tokens.IO _v_1060 ->
                let _startpos_1061 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1062 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1062, _startpos_1061, _v_1060) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState499 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1064 ->
                let _startpos_1065 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1066 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1066, _startpos_1065, _v_1064) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_499 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1068 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1069 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1069, _startpos_1068) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState499 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1071 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1072 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1072, _startpos_1071) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState499 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1074 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1075 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1075, _startpos_1074) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState499 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1077 ->
                let _startpos_1078 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1079 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1079, _startpos_1078, _v_1077) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_499 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1081 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1081 MenhirState499
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1082 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1083 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1083, _startpos_1082) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState499 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1085 ->
                let _startpos_1086 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1087 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1087, _startpos_1086, _v_1085) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState499 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1089 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1090 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1090, _startpos_1089) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState499 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1092 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1093 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1093, _startpos_1092) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState499 _tok
            | _ ->
                _eRR 499)
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_1095 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1096 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1097 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_EQ (_menhir_stack, _v_1095, _startpos_1096, _endpos_1097) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1098 ->
                let _startpos_1099 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1100 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1100, _startpos_1099, _v_1098) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_501 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1102 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1103 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1103, _startpos_1102) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState501 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1105 ->
                let _startpos_1106 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1107 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1107, _startpos_1106, _v_1105) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_501 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1109 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1110 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1110, _startpos_1109) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState501 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1112 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1113 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1113, _startpos_1112) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState501 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1115 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1116 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1116, _startpos_1115) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState501 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState501
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState501
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState501
            | Elpi_lexer_config.Tokens.IO _v_1118 ->
                let _startpos_1119 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1120 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1120, _startpos_1119, _v_1118) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState501 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1122 ->
                let _startpos_1123 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1124 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1124, _startpos_1123, _v_1122) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_501 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1126 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1127 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1127, _startpos_1126) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState501 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1129 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1130 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1130, _startpos_1129) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState501 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1132 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1133 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1133, _startpos_1132) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState501 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1135 ->
                let _startpos_1136 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1137 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1137, _startpos_1136, _v_1135) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_501 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1139 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1139 MenhirState501
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1140 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1141 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1141, _startpos_1140) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState501 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1143 ->
                let _startpos_1144 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1145 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1145, _startpos_1144, _v_1143) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState501 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1147 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1148 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1148, _startpos_1147) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState501 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1150 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1151 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1151, _startpos_1150) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState501 _tok
            | _ ->
                _eRR 501)
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_1153 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1154 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1155 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_BTICK (_menhir_stack, _v_1153, _startpos_1154, _endpos_1155) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1156 ->
                let _startpos_1157 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1158 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1158, _startpos_1157, _v_1156) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_503 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1160 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1161 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1161, _startpos_1160) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState503 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1163 ->
                let _startpos_1164 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1165 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1165, _startpos_1164, _v_1163) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_503 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1167 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1168 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1168, _startpos_1167) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState503 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1170 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1171 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1171, _startpos_1170) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState503 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1173 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1174 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1174, _startpos_1173) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState503 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState503
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState503
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState503
            | Elpi_lexer_config.Tokens.IO _v_1176 ->
                let _startpos_1177 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1178 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1178, _startpos_1177, _v_1176) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState503 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1180 ->
                let _startpos_1181 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1182 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1182, _startpos_1181, _v_1180) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_503 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1184 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1185 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1185, _startpos_1184) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState503 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1187 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1188 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1188, _startpos_1187) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState503 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1190 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1191 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1191, _startpos_1190) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState503 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1193 ->
                let _startpos_1194 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1195 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1195, _startpos_1194, _v_1193) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_503 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1197 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1197 MenhirState503
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1198 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1199 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1199, _startpos_1198) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState503 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1201 ->
                let _startpos_1202 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1203 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1203, _startpos_1202, _v_1201) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState503 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1205 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1206 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1206, _startpos_1205) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState503 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1208 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1209 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1209, _startpos_1208) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState503 _tok
            | _ ->
                _eRR 503)
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_1211 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1212 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1213 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_AND (_menhir_stack, _v_1211, _startpos_1212, _endpos_1213) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1214 ->
                let _startpos_1215 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1216 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1216, _startpos_1215, _v_1214) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_505 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1218 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1219 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1219, _startpos_1218) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState505 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1221 ->
                let _startpos_1222 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1223 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1223, _startpos_1222, _v_1221) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_505 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1225 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1226 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1226, _startpos_1225) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState505 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1228 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1229 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1229, _startpos_1228) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState505 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1231 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1232 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1232, _startpos_1231) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState505 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
            | Elpi_lexer_config.Tokens.IO _v_1234 ->
                let _startpos_1235 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1236 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1236, _startpos_1235, _v_1234) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState505 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1238 ->
                let _startpos_1239 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1240 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1240, _startpos_1239, _v_1238) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_505 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1242 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1243 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1243, _startpos_1242) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState505 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1245 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1246 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1246, _startpos_1245) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState505 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1248 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1249 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1249, _startpos_1248) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState505 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1251 ->
                let _startpos_1252 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1253 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1253, _startpos_1252, _v_1251) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_505 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1255 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1255 MenhirState505
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1256 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1257 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1257, _startpos_1256) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState505 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1259 ->
                let _startpos_1260 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1261 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1261, _startpos_1260, _v_1259) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState505 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1263 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1264 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1264, _startpos_1263) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState505 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1266 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1267 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1267, _startpos_1266) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState505 _tok
            | _ ->
                _eRR 505)
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1269 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1270 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_EQ2 (_menhir_stack, _startpos_1269, _endpos_1270) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1271 ->
                let _startpos_1272 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1273 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1273, _startpos_1272, _v_1271) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_507 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1275 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1276 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1276, _startpos_1275) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState507 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1278 ->
                let _startpos_1279 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1280 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1280, _startpos_1279, _v_1278) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_507 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1282 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1283 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1283, _startpos_1282) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState507 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1285 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1286 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1286, _startpos_1285) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState507 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1288 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1289 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1289, _startpos_1288) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState507 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState507
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState507
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState507
            | Elpi_lexer_config.Tokens.IO _v_1291 ->
                let _startpos_1292 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1293 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1293, _startpos_1292, _v_1291) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState507 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1295 ->
                let _startpos_1296 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1297 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1297, _startpos_1296, _v_1295) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_507 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1299 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1300 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1300, _startpos_1299) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState507 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1302 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1303 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1303, _startpos_1302) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState507 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1305 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1306 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1306, _startpos_1305) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState507 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1308 ->
                let _startpos_1309 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1310 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1310, _startpos_1309, _v_1308) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_507 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1312 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1312 MenhirState507
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1313 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1314 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1314, _startpos_1313) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState507 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1316 ->
                let _startpos_1317 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1318 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1318, _startpos_1317, _v_1316) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState507 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1320 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1321 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1321, _startpos_1320) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState507 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1323 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1324 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1324, _startpos_1323) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState507 _tok
            | _ ->
                _eRR 507)
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1326 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1327 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_EQ (_menhir_stack, _startpos_1326, _endpos_1327) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1328 ->
                let _startpos_1329 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1330 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1330, _startpos_1329, _v_1328) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_509 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1332 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1333 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1333, _startpos_1332) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState509 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1335 ->
                let _startpos_1336 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1337 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1337, _startpos_1336, _v_1335) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_509 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1339 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1340 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1340, _startpos_1339) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState509 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1342 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1343 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1343, _startpos_1342) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState509 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1345 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1346 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1346, _startpos_1345) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState509 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
            | Elpi_lexer_config.Tokens.IO _v_1348 ->
                let _startpos_1349 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1350 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1350, _startpos_1349, _v_1348) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState509 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1352 ->
                let _startpos_1353 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1354 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1354, _startpos_1353, _v_1352) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_509 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1356 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1357 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1357, _startpos_1356) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState509 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1359 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1360 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1360, _startpos_1359) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState509 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1362 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1363 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1363, _startpos_1362) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState509 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1365 ->
                let _startpos_1366 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1367 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1367, _startpos_1366, _v_1365) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_509 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1369 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1369 MenhirState509
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1370 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1371 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1371, _startpos_1370) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState509 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1373 ->
                let _startpos_1374 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1375 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1375, _startpos_1374, _v_1373) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState509 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1377 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1378 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1378, _startpos_1377) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState509 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1380 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1381 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1381, _startpos_1380) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState509 _tok
            | _ ->
                _eRR 509)
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1383 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1384 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_DIV (_menhir_stack, _startpos_1383, _endpos_1384) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1385 ->
                let _startpos_1386 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1387 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1387, _startpos_1386, _v_1385) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_511 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1389 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1390 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1390, _startpos_1389) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState511 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1392 ->
                let _startpos_1393 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1394 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1394, _startpos_1393, _v_1392) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_511 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1396 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1397 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1397, _startpos_1396) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState511 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1399 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1400 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1400, _startpos_1399) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState511 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1402 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1403 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1403, _startpos_1402) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState511 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState511
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState511
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState511
            | Elpi_lexer_config.Tokens.IO _v_1405 ->
                let _startpos_1406 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1407 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1407, _startpos_1406, _v_1405) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState511 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1409 ->
                let _startpos_1410 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1411 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1411, _startpos_1410, _v_1409) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_511 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1413 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1414 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1414, _startpos_1413) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState511 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1416 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1417 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1417, _startpos_1416) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState511 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1419 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1420 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1420, _startpos_1419) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState511 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1422 ->
                let _startpos_1423 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1424 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1424, _startpos_1423, _v_1422) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_511 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1426 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1426 MenhirState511
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1427 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1428 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1428, _startpos_1427) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState511 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1430 ->
                let _startpos_1431 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1432 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1432, _startpos_1431, _v_1430) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState511 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1434 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1435 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1435, _startpos_1434) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState511 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1437 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1438 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1438, _startpos_1437) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState511 _tok
            | _ ->
                _eRR 511)
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1440 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1441 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_DARROW (_menhir_stack, _startpos_1440, _endpos_1441) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1442 ->
                let _startpos_1443 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1444 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1444, _startpos_1443, _v_1442) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_513 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1446 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1447 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1447, _startpos_1446) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState513 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1449 ->
                let _startpos_1450 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1451 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1451, _startpos_1450, _v_1449) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_513 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1453 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1454 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1454, _startpos_1453) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState513 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1456 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1457 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1457, _startpos_1456) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState513 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1459 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1460 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1460, _startpos_1459) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState513 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState513
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState513
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState513
            | Elpi_lexer_config.Tokens.IO _v_1462 ->
                let _startpos_1463 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1464 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1464, _startpos_1463, _v_1462) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState513 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1466 ->
                let _startpos_1467 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1468 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1468, _startpos_1467, _v_1466) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_513 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1470 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1471 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1471, _startpos_1470) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState513 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1473 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1474 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1474, _startpos_1473) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState513 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1476 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1477 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1477, _startpos_1476) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState513 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1479 ->
                let _startpos_1480 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1481 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1481, _startpos_1480, _v_1479) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_513 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1483 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1483 MenhirState513
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1484 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1485 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1485, _startpos_1484) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState513 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1487 ->
                let _startpos_1488 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1489 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1489, _startpos_1488, _v_1487) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState513 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1491 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1492 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1492, _startpos_1491) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState513 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1494 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1495 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1495, _startpos_1494) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState513 _tok
            | _ ->
                _eRR 513)
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1497 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1498 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONS (_menhir_stack, _startpos_1497, _endpos_1498) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1499 ->
                let _startpos_1500 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1501 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1501, _startpos_1500, _v_1499) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_515 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1503 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1504 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1504, _startpos_1503) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState515 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1506 ->
                let _startpos_1507 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1508 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1508, _startpos_1507, _v_1506) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_515 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1510 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1511 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1511, _startpos_1510) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState515 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1513 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1514 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1514, _startpos_1513) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState515 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1516 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1517 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1517, _startpos_1516) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState515 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState515
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState515
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState515
            | Elpi_lexer_config.Tokens.IO _v_1519 ->
                let _startpos_1520 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1521 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1521, _startpos_1520, _v_1519) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState515 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1523 ->
                let _startpos_1524 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1525 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1525, _startpos_1524, _v_1523) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_515 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1527 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1528 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1528, _startpos_1527) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState515 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1530 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1531 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1531, _startpos_1530) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState515 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1533 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1534 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1534, _startpos_1533) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState515 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1536 ->
                let _startpos_1537 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1538 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1538, _startpos_1537, _v_1536) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_515 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1540 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1540 MenhirState515
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1541 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1542 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1542, _startpos_1541) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState515 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1544 ->
                let _startpos_1545 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1546 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1546, _startpos_1545, _v_1544) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState515 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1548 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1549 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1549, _startpos_1548) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState515 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1551 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1552 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1552, _startpos_1551) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState515 _tok
            | _ ->
                _eRR 515)
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1554 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1555 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ2 (_menhir_stack, _startpos_1554, _endpos_1555) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1556 ->
                let _startpos_1557 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1558 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1558, _startpos_1557, _v_1556) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_517 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1560 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1561 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1561, _startpos_1560) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState517 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1563 ->
                let _startpos_1564 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1565 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1565, _startpos_1564, _v_1563) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_517 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1567 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1568 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1568, _startpos_1567) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState517 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1570 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1571 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1571, _startpos_1570) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState517 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1573 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1574 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1574, _startpos_1573) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState517 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState517
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState517
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState517
            | Elpi_lexer_config.Tokens.IO _v_1576 ->
                let _startpos_1577 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1578 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1578, _startpos_1577, _v_1576) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState517 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1580 ->
                let _startpos_1581 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1582 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1582, _startpos_1581, _v_1580) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_517 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1584 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1585 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1585, _startpos_1584) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState517 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1587 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1588 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1588, _startpos_1587) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState517 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1590 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1591 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1591, _startpos_1590) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState517 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1593 ->
                let _startpos_1594 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1595 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1595, _startpos_1594, _v_1593) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_517 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1597 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1597 MenhirState517
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1598 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1599 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1599, _startpos_1598) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState517 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1601 ->
                let _startpos_1602 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1603 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1603, _startpos_1602, _v_1601) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState517 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1605 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1606 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1606, _startpos_1605) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState517 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1608 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1609 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1609, _startpos_1608) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState517 _tok
            | _ ->
                _eRR 517)
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1611 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1612 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos_1611, _endpos_1612) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1613 ->
                let _startpos_1614 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1615 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1615, _startpos_1614, _v_1613) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_519 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1617 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1618 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1618, _startpos_1617) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState519 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1620 ->
                let _startpos_1621 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1622 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1622, _startpos_1621, _v_1620) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_519 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1624 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1625 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1625, _startpos_1624) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState519 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1627 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1628 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1628, _startpos_1627) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState519 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1630 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1631 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1631, _startpos_1630) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState519 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState519
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState519
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState519
            | Elpi_lexer_config.Tokens.IO _v_1633 ->
                let _startpos_1634 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1635 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1635, _startpos_1634, _v_1633) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState519 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1637 ->
                let _startpos_1638 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1639 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1639, _startpos_1638, _v_1637) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_519 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1641 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1642 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1642, _startpos_1641) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState519 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1644 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1645 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1645, _startpos_1644) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState519 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1647 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1648 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1648, _startpos_1647) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState519 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1650 ->
                let _startpos_1651 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1652 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1652, _startpos_1651, _v_1650) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_519 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1654 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1654 MenhirState519
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1655 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1656 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1656, _startpos_1655) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState519 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1658 ->
                let _startpos_1659 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1660 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1660, _startpos_1659, _v_1658) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState519 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1662 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1663 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1663, _startpos_1662) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState519 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1665 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1666 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1666, _startpos_1665) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState519 _tok
            | _ ->
                _eRR 519)
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1668 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1669 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_ARROW (_menhir_stack, _startpos_1668, _endpos_1669) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1670 ->
                let _startpos_1671 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1672 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1672, _startpos_1671, _v_1670) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_521 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1674 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1675 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1675, _startpos_1674) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState521 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1677 ->
                let _startpos_1678 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1679 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1679, _startpos_1678, _v_1677) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_521 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1681 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1682 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1682, _startpos_1681) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState521 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1684 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1685 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1685, _startpos_1684) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState521 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1687 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1688 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1688, _startpos_1687) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState521 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState521
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState521
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState521
            | Elpi_lexer_config.Tokens.IO _v_1690 ->
                let _startpos_1691 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1692 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1692, _startpos_1691, _v_1690) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState521 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1694 ->
                let _startpos_1695 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1696 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1696, _startpos_1695, _v_1694) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_521 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1698 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1699 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1699, _startpos_1698) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState521 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1701 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1702 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1702, _startpos_1701) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState521 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1704 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1705 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1705, _startpos_1704) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState521 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1707 ->
                let _startpos_1708 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1709 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1709, _startpos_1708, _v_1707) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_521 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1711 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1711 MenhirState521
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1712 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1713 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1713, _startpos_1712) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState521 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1715 ->
                let _startpos_1716 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1717 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1717, _startpos_1716, _v_1715) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState521 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1719 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1720 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1720, _startpos_1719) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState521 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1722 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1723 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1723, _startpos_1722) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState521 _tok
            | _ ->
                _eRR 521)
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_attributes (_menhir_stack, _menhir_s, attributes, _startpos_attributes_, _endpos_attributes_) = _menhir_stack in
            let (_endpos_body_, _startpos_body_, body) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_027 _endpos_attributes_ _endpos_body_ _startpos_attributes_ _startpos_body_ attributes body in
            _menhir_goto_clause _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 461
    
    and _menhir_run_052_spec_462 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_VDASH -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState462 _tok
    
    and _menhir_run_463 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_VDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell0_VDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _, l, _startpos_l_, _) = _menhir_stack in
            let MenhirCell1_attributes (_menhir_stack, _menhir_s, attributes, _startpos_attributes_, _endpos_attributes_) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_028 _endpos_attributes_ _endpos_r_ _startpos_attributes_ _startpos_l_ attributes l r in
            _menhir_goto_clause _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 463
    
    and _menhir_goto_clause : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let c = _v in
        let _v = _menhir_action_088 c in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_052_spec_464 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_SLASH -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_465 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState464 _tok
    
    and _menhir_run_465 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_SLASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_SLASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_058 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 465
    
    and _menhir_run_052_spec_466 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_QDASH -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_467 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState466 _tok
    
    and _menhir_run_467 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_QDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell0_QDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_057 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 467
    
    and _menhir_run_052_spec_468 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_OR -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_469 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState468 _tok
    
    and _menhir_run_469 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_OR (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_051 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 469
    
    and _menhir_run_052_spec_470 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MOD -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_471 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState470 _tok
    
    and _menhir_run_471 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MOD (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_053 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 471
    
    and _menhir_run_052_spec_472 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSs -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState472 _tok
    
    and _menhir_run_473 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSs as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSs (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_049 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 473
    
    and _menhir_run_052_spec_474 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSr -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_475 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState474 _tok
    
    and _menhir_run_475 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSr as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSr (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_047 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 475
    
    and _menhir_run_052_spec_476 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSi -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_477 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState476 _tok
    
    and _menhir_run_477 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSi as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSi (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_048 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 477
    
    and _menhir_run_052_spec_478 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUS -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_479 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState478 _tok
    
    and _menhir_run_479 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_046 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 479
    
    and _menhir_run_052_spec_480 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_IS -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState480 _tok
    
    and _menhir_run_481 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_IS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_IS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_052 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 481
    
    and _menhir_run_052_spec_482 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TIMES -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_483 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState482 _tok
    
    and _menhir_run_483 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TIMES as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TIMES (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_033 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 483
    
    and _menhir_run_052_spec_484 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TICK -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState484 _tok
    
    and _menhir_run_485 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_043 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 485
    
    and _menhir_run_052_spec_486 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_SHARP -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_487 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState486 _tok
    
    and _menhir_run_487 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_SHARP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_SHARP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_041 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 487
    
    and _menhir_run_052_spec_489 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_PLUS -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_490 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState489 _tok
    
    and _menhir_run_490 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_PLUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_032 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 490
    
    and _menhir_run_052_spec_491 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_OR -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_492 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState491 _tok
    
    and _menhir_run_492 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_OR (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_040 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 492
    
    and _menhir_run_052_spec_493 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_MINUS -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState493 _tok
    
    and _menhir_run_494 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_MINUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_034 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 494
    
    and _menhir_run_052_spec_495 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_LT -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_496 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState495 _tok
    
    and _menhir_run_496 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_LT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_036 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 496
    
    and _menhir_run_052_spec_497 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_GT -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_498 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState497 _tok
    
    and _menhir_run_498 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_GT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_037 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 498
    
    and _menhir_run_052_spec_499 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EXP -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_500 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState499 _tok
    
    and _menhir_run_500 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EXP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EXP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_035 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 500
    
    and _menhir_run_052_spec_501 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EQ -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState501 _tok
    
    and _menhir_run_502 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EQ (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_038 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 502
    
    and _menhir_run_052_spec_503 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_BTICK -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_504 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState503 _tok
    
    and _menhir_run_504 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_BTICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_BTICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_042 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 504
    
    and _menhir_run_052_spec_505 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_AND -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_506 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState505 _tok
    
    and _menhir_run_506 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_AND (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_039 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 506
    
    and _menhir_run_052_spec_507 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ2 -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_508 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState507 _tok
    
    and _menhir_run_508 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_050 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 508
    
    and _menhir_run_052_spec_509 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_510 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState509 _tok
    
    and _menhir_run_510 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_045 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 510
    
    and _menhir_run_052_spec_511 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DIV -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState511 _tok
    
    and _menhir_run_512 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DIV (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_054 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 512
    
    and _menhir_run_052_spec_513 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DARROW -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_514 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState513 _tok
    
    and _menhir_run_514 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_056 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 514
    
    and _menhir_run_052_spec_515 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONS -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_516 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState515 _tok
    
    and _menhir_run_516 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_044 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 516
    
    and _menhir_run_052_spec_517 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ2 -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_518 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState517 _tok
    
    and _menhir_run_518 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONJ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_059 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 518
    
    and _menhir_run_052_spec_519 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_520 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState519 _tok
    
    and _menhir_run_520 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_060 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 520
    
    and _menhir_run_052_spec_521 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_ARROW -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_522 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState521 _tok
    
    and _menhir_run_049 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_closed_term -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_closed_term (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_206 x xs in
        _menhir_goto_nonempty_list_closed_term_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_043 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let _v = _menhir_action_282 () in
            _menhir_run_044 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_044 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term, ttv_result) _menhir_cell1_nonempty_list_closed_term_ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _, args) = _menhir_stack in
        let MenhirCell1_head_term (_menhir_stack, _menhir_s, hd, _startpos_hd_, _endpos_hd_) = _menhir_stack in
        let (_endpos_b_, b) = (_endpos, _v) in
        let _v = _menhir_action_215 _endpos_hd_ _startpos_hd_ args b hd in
        _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_hd_ _v _menhir_s _tok
    
    and _menhir_run_036 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let _v = _menhir_action_282 () in
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _eRR 36
    
    and _menhir_run_115 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term, ttv_result) _menhir_cell1_nonempty_list_closed_term_ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _, args) = _menhir_stack in
        let MenhirCell1_head_term (_menhir_stack, _menhir_s, hd, _startpos_hd_, _endpos_hd_) = _menhir_stack in
        let (_endpos_b_, b) = (_endpos, _v) in
        let _v = _menhir_action_248 _endpos_hd_ _startpos_hd_ args b hd in
        _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_hd_ _v _menhir_s _tok
    
    and _menhir_run_047_spec_457 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_111 t in
        _menhir_run_046_spec_457 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _tok
    
    and _menhir_run_046_spec_457 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_073 t in
        _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState457 _tok
    
    and _menhir_run_046_spec_421 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_073 t in
        _menhir_run_429_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_046_spec_439 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ _menhir_cell0_option_preceded_PIPE_term__ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_073 t in
        _menhir_run_429_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_429_spec_439 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ _menhir_cell0_option_preceded_PIPE_term__ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_308 t in
        _menhir_run_440 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_440 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ _menhir_cell0_option_preceded_PIPE_term__ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_x_, x) = (_endpos, _v) in
        let _v = _menhir_action_287 x in
        _menhir_goto_option_preceded_IFF_sequent__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
    
    and _menhir_goto_option_preceded_IFF_sequent__ : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ _menhir_cell0_option_preceded_PIPE_term__ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_option_preceded_PIPE_term__ (_menhir_stack, guard) = _menhir_stack in
        let MenhirCell0_option_preceded_BIND_nonempty_list_sequent___ (_menhir_stack, to_remove) = _menhir_stack in
        let MenhirCell1_list_sequent_ (_menhir_stack, _, to_match) = _menhir_stack in
        let MenhirCell1_RULE (_menhir_stack, _, _startpos__2_) = _menhir_stack in
        let MenhirCell1_attributes (_menhir_stack, _menhir_s, attributes, _startpos_attributes_, _endpos_attributes_) = _menhir_stack in
        let (_endpos_new_goal_, new_goal) = (_endpos, _v) in
        let _v = _menhir_action_026 _endpos_attributes_ _endpos_new_goal_ _startpos__2_ _startpos_attributes_ attributes guard new_goal to_match to_remove in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let r = _v in
            let _v = _menhir_action_089 r in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 415
    
    and _menhir_run_046_spec_431 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_BIND -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_073 t in
        _menhir_run_429_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_429_spec_431 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_BIND -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_308 t in
        _menhir_run_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v MenhirState431 _tok
    
    and _menhir_run_432 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, x) = (_endpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_429_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_3 in
            let _v = _menhir_action_083 () in
            _menhir_run_047_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_5 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_6, _startpos, _v_5) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_429_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_8 in
            let _v = _menhir_action_082 () in
            _menhir_run_047_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_10 in
            let _v = _menhir_action_087 () in
            _menhir_run_047_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_12 in
            let _v = _menhir_action_076 () in
            _menhir_run_047_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_422 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState432
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState432
        | Elpi_lexer_config.Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState432
        | Elpi_lexer_config.Tokens.IO _v_14 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_15, _v_14) in
            let _v = _menhir_action_080 c in
            _menhir_run_047_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_17 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, x) = (_endpos_18, _v_17) in
            let _v = _menhir_action_065 x in
            _menhir_run_429_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_20 in
            let _v = _menhir_action_079 () in
            _menhir_run_047_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_22 in
            let _v = _menhir_action_075 () in
            _menhir_run_047_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_24 in
            let _v = _menhir_action_084 () in
            _menhir_run_047_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_26 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, x) = (_endpos_27, _v_26) in
            let _v = _menhir_action_066 x in
            _menhir_run_429_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_29 in
            let _v = _menhir_action_081 () in
            _menhir_run_047_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_31 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_32, _v_31) in
            let _v = _menhir_action_074 c in
            _menhir_run_047_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_34 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_34 in
            let _v = _menhir_action_077 () in
            _menhir_run_047_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_36 in
            let _v = _menhir_action_078 () in
            _menhir_run_047_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE ->
            let x = _v in
            let _v = _menhir_action_213 x in
            _menhir_goto_nonempty_list_sequent_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 432
    
    and _menhir_run_429_spec_432 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_308 t in
        _menhir_run_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v MenhirState432 _tok
    
    and _menhir_run_047_spec_432 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_111 t in
        _menhir_run_046_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_046_spec_432 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_073 t in
        _menhir_run_429_spec_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_goto_nonempty_list_sequent_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState431 ->
            _menhir_run_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState432 ->
            _menhir_run_433 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_434 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_BIND -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_BIND (_menhir_stack, _, _) = _menhir_stack in
        let x = _v in
        let _v = _menhir_action_285 x in
        _menhir_goto_option_preceded_BIND_nonempty_list_sequent___ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
    
    and _menhir_goto_option_preceded_BIND_nonempty_list_sequent___ : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let _menhir_stack = MenhirCell0_option_preceded_BIND_nonempty_list_sequent___ (_menhir_stack, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.PIPE ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_0 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v_0) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_436 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState436 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_3 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v_3) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_436 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState436 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState436 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState436 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState436
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState436
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState436
            | Elpi_lexer_config.Tokens.IO _v_8 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v_8) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState436 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_10 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v_10) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_436 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState436 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState436 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState436 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_15 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v_15) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_436 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_17 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_17 MenhirState436
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState436 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_19 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v_19) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState436 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState436 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState436 _tok
            | _ ->
                _eRR 436)
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF ->
            let _v = _menhir_action_288 () in
            _menhir_goto_option_preceded_PIPE_term__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_052_spec_436 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_437 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState436 _tok
    
    and _menhir_run_437 : type  ttv_stack. ((((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF ->
            let x = _v in
            let _v = _menhir_action_289 x in
            _menhir_goto_option_preceded_PIPE_term__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _eRR 437
    
    and _menhir_goto_option_preceded_PIPE_term__ : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let _menhir_stack = MenhirCell0_option_preceded_PIPE_term__ (_menhir_stack, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.IFF ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_0 ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos, _v_0) in
                let _v = _menhir_action_067 x in
                _menhir_run_429_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_083 () in
                _menhir_run_047_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_3 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v_3) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_429_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_082 () in
                _menhir_run_047_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_087 () in
                _menhir_run_047_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_076 () in
                _menhir_run_047_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_422 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState439
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState439
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState439
            | Elpi_lexer_config.Tokens.IO _v_8 ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, c) = (_endpos, _v_8) in
                let _v = _menhir_action_080 c in
                _menhir_run_047_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_10 ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos, _v_10) in
                let _v = _menhir_action_065 x in
                _menhir_run_429_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_079 () in
                _menhir_run_047_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_075 () in
                _menhir_run_047_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_084 () in
                _menhir_run_047_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_15 ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos, _v_15) in
                let _v = _menhir_action_066 x in
                _menhir_run_429_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_081 () in
                _menhir_run_047_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_18 ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, c) = (_endpos, _v_18) in
                let _v = _menhir_action_074 c in
                _menhir_run_047_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_077 () in
                _menhir_run_047_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_078 () in
                _menhir_run_047_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | _ ->
                _eRR 439)
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _v = _menhir_action_286 () in
            _menhir_goto_option_preceded_IFF_sequent__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_047_spec_439 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ _menhir_cell0_option_preceded_PIPE_term__ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_111 t in
        _menhir_run_046_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_433 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_sequent (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_214 x xs in
        _menhir_goto_nonempty_list_sequent_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_046_spec_035 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_head_term -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_073 t in
        _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState035 _tok
    
    and _menhir_run_046_spec_042 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_head_term -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_073 t in
        _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState042 _tok
    
    and _menhir_run_042 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState042 _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_047_spec_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState042 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_047_spec_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_047_spec_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_047_spec_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState042
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState042
        | Elpi_lexer_config.Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState042
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_047_spec_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState042 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_047_spec_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_047_spec_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_047_spec_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState042 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_42, _startpos_41) in
            let _v = _menhir_action_081 () in
            _menhir_run_047_spec_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_44 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_46, _startpos_45, _v_44) in
            let _v = _menhir_action_074 c in
            _menhir_run_047_spec_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_48 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_49 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_49, _startpos_48) in
            let _v = _menhir_action_077 () in
            _menhir_run_047_spec_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_51 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_52, _startpos_51) in
            let _v = _menhir_action_078 () in
            _menhir_run_047_spec_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_073 t in
            _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 42
    
    and _menhir_run_047_spec_042 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_head_term -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_111 t in
        _menhir_run_046_spec_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _tok
    
    and _menhir_run_035 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState035 _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_047_spec_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState035 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_047_spec_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_047_spec_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_047_spec_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Elpi_lexer_config.Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_047_spec_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState035 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_047_spec_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_047_spec_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_047_spec_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState035 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_42, _startpos_41) in
            let _v = _menhir_action_081 () in
            _menhir_run_047_spec_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_44 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_46, _startpos_45, _v_44) in
            let _v = _menhir_action_074 c in
            _menhir_run_047_spec_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_48 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_49 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_49, _startpos_48) in
            let _v = _menhir_action_077 () in
            _menhir_run_047_spec_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_51 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_52, _startpos_51) in
            let _v = _menhir_action_078 () in
            _menhir_run_047_spec_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_073 t in
            _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 35
    
    and _menhir_run_047_spec_035 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_head_term -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_111 t in
        _menhir_run_046_spec_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _tok
    
    and _menhir_run_052_spec_220 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAREN, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_221 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState220 _tok
    
    and _menhir_run_221 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LPAREN, ttv_result) _menhir_cell1_term as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_term (_menhir_stack, _, t, _, _) = _menhir_stack in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (c, _endpos__5_) = (_v, _endpos_0) in
            let _v = _menhir_action_069 c t in
            _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__5_ _startpos__1_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 221
    
    and _menhir_run_423 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.COLON ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_COLON (_menhir_stack, MenhirState423, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1 ->
                let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_3, _startpos_2, _v_1) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos_5) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState424 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_8 ->
                let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_10, _startpos_9, _v_8) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState424 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_16 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_16, _startpos_15) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState424 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState424 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState424
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState424
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState424
            | Elpi_lexer_config.Tokens.IO _v_21 ->
                let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_23, _startpos_22, _v_21) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState424 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_25 ->
                let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_27, _startpos_26, _v_25) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_29 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_30 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_30, _startpos_29) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState424 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState424 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_36, _startpos_35) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState424 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_38 ->
                let _startpos_39 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_40 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_40, _startpos_39, _v_38) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_42 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_42 MenhirState424
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_43 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_44 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_44, _startpos_43) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState424 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_46 ->
                let _startpos_47 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_48 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_48, _startpos_47, _v_46) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState424 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_50 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_51 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_51, _startpos_50) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState424 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_53 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_54 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_54, _startpos_53) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState424 _tok
            | _ ->
                _eRR 424)
        | Elpi_lexer_config.Tokens.BIND ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState423
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FLOAT _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.INTEGER _ | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.LBRACKET | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.QUOTED _ | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.STRING _ | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_111 t in
            _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 423
    
    and _menhir_run_052_spec_424 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_cell1_COLON -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_425 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState424 _tok
    
    and _menhir_run_425 : type  ttv_stack. ((((ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_cell1_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_COLON (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_constant (_menhir_stack, _, c, _, _) = _menhir_stack in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _) = _menhir_stack in
            let (t, _endpos__5_) = (_v, _endpos_0) in
            let _v = _menhir_action_309 c t in
            _menhir_goto_sequent _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__5_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 425
    
    and _menhir_goto_sequent : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState439 ->
            _menhir_run_440 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState432 ->
            _menhir_run_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState431 ->
            _menhir_run_432 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState427 ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState421 ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_195 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_195 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState195 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_195 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState195 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState195 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState195 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState195
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState195
        | Elpi_lexer_config.Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState195
        | Elpi_lexer_config.Tokens.IO _v_20 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos_21, _v_20) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState195 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_195 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState195 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState195 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState195 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_39, _startpos_38, _v_37) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_195 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_41 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState195
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_43, _startpos_42) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState195 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_45 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_47, _startpos_46, _v_45) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState195 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_50, _startpos_49) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState195 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState195 _tok
        | Elpi_lexer_config.Tokens.RPAREN ->
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_200 s in
            _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 195
    
    and _menhir_run_052_spec_195 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAREN, ttv_result) _menhir_cell1_FAMILY_TILDE -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState195 _tok
    
    and _menhir_goto_mixfix_SYMB : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState353 ->
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState452 ->
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState422 ->
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState292 ->
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState273 ->
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState280 ->
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState270 ->
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState007 ->
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_354 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_FIXITY -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.INTEGER _v_0 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_FIXITY (_menhir_stack, _menhir_s, f, _startpos_f_) = _menhir_stack in
            let (_endpos_c_, _startpos_c_, c, i) = (_endpos, _startpos, _v, _v_0) in
            let _v = _menhir_action_108 _endpos_c_ _startpos_c_ c f i in
            _menhir_goto_fixity _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_f_ _v _menhir_s _tok
        | _ ->
            _eRR 354
    
    and _menhir_goto_fixity : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__2_, _startpos_f_, f) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_104 _endpos__2_ _startpos_f_ f in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 409
    
    and _menhir_run_428 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_sequent (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_160 x xs in
        _menhir_goto_list_sequent_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_goto_list_sequent_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState421 ->
            _menhir_run_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState427 ->
            _menhir_run_428 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_430 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_list_sequent_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_BIND (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_0 ->
                let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos_2, _v_0) in
                let _v = _menhir_action_067 x in
                _menhir_run_429_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_5 in
                let _v = _menhir_action_083 () in
                _menhir_run_047_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
                let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_9, _startpos_8, _v_7) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_429_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_12 in
                let _v = _menhir_action_082 () in
                _menhir_run_047_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_15 in
                let _v = _menhir_action_087 () in
                _menhir_run_047_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_18 in
                let _v = _menhir_action_076 () in
                _menhir_run_047_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_422 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState431
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState431
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState431
            | Elpi_lexer_config.Tokens.IO _v_20 ->
                let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, c) = (_endpos_22, _v_20) in
                let _v = _menhir_action_080 c in
                _menhir_run_047_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_24 ->
                let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos_26, _v_24) in
                let _v = _menhir_action_065 x in
                _menhir_run_429_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_29 in
                let _v = _menhir_action_079 () in
                _menhir_run_047_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_32 in
                let _v = _menhir_action_075 () in
                _menhir_run_047_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_35 in
                let _v = _menhir_action_084 () in
                _menhir_run_047_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_37 ->
                let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos_39, _v_37) in
                let _v = _menhir_action_066 x in
                _menhir_run_429_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_42 in
                let _v = _menhir_action_081 () in
                _menhir_run_047_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_44 ->
                let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, c) = (_endpos_46, _v_44) in
                let _v = _menhir_action_074 c in
                _menhir_run_047_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _endpos_49 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_49 in
                let _v = _menhir_action_077 () in
                _menhir_run_047_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_52 in
                let _v = _menhir_action_078 () in
                _menhir_run_047_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | _ ->
                _eRR 431)
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE ->
            let _v = _menhir_action_284 () in
            _menhir_goto_option_preceded_BIND_nonempty_list_sequent___ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_047_spec_431 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_BIND -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_111 t in
        _menhir_run_046_spec_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_052_spec_455 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_FAMILY_TILDE -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_456 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState455 _tok
    
    and _menhir_run_456 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_FAMILY_TILDE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, s, _startpos_s_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_061 r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 456
    
    and _menhir_run_052_spec_452 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_LPAREN -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_453 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState452 _tok
    
    and _menhir_run_453 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
                let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_endpos__3_, t) = (_endpos_0, _v) in
                let _v = _menhir_action_030 t in
                _menhir_goto_clause_hd_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
            | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FLOAT _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.INTEGER _ | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LBRACKET | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.QUOTED _ | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.STRING _ ->
                let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_endpos__3_, t) = (_endpos_0, _v) in
                let _v = _menhir_action_112 t in
                _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
            | _ ->
                _eRR 454)
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 453
    
    and _menhir_goto_clause_hd_closed_term : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_064 t in
        _menhir_goto_clause_hd_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_run_052_spec_007 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LPAREN -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState007 _tok
    
    and _menhir_run_338 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LOCALKIND (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_083 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState338 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_082 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState338 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_087 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState338 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_076 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState338 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState338
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_4, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState338 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_5) in
            let _v = _menhir_action_079 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState338 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_075 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState338 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_084 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState338 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_081 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState338 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_9, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState338 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
            let _v = _menhir_action_077 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState338 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_078 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState338 _tok
        | _ ->
            _eRR 338
    
    and _menhir_run_340 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LOCAL (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState340 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_082 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState340 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_087 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState340 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState340 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState340
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState340 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState340 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_075 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState340 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState340 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState340 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState340 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState340 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState340 _tok
        | _ ->
            _eRR 340
    
    and _menhir_run_346 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_KIND (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_083 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState346 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_082 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState346 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_087 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState346 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_076 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState346 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState346
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_4, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState346 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_5) in
            let _v = _menhir_action_079 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState346 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_075 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState346 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_084 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState346 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_081 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState346 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_9, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState346 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
            let _v = _menhir_action_077 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState346 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_078 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState346 _tok
        | _ ->
            _eRR 346
    
    and _menhir_run_353 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_FIXITY (_menhir_stack, _menhir_s, _v, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_199 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.SLASH ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_196 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_083 () in
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_195 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_082 () in
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.OR ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
            let _v = _menhir_action_189 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_12) in
            let _v = _menhir_action_087 () in
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_14) in
            let _v = _menhir_action_076 () in
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.MOD ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_16) in
            let _v = _menhir_action_191 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_18) in
            let _v = _menhir_action_187 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_20) in
            let _v = _menhir_action_185 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_22) in
            let _v = _menhir_action_186 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.MINUS ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_24) in
            let _v = _menhir_action_184 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Elpi_lexer_config.Tokens.IS ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_26) in
            let _v = _menhir_action_190 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IO _v_28 ->
            let _startpos_29 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_29, _v_28) in
            let _v = _menhir_action_080 c in
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_31) in
            let _v = _menhir_action_079 () in
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_33 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_33) in
            let _v = _menhir_action_075 () in
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_35) in
            let _v = _menhir_action_084 () in
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_37 ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_38, _v_37) in
            let _v = _menhir_action_171 s in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_41, _v_40) in
            let _v = _menhir_action_200 s in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_43 ->
            let _startpos_44 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_44, _v_43) in
            let _v = _menhir_action_181 s in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_46 ->
            let _startpos_47 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_47, _v_46) in
            let _v = _menhir_action_179 s in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_49 ->
            let _startpos_50 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_50, _v_49) in
            let _v = _menhir_action_201 s in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_52 ->
            let _startpos_53 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_53, _v_52) in
            let _v = _menhir_action_170 s in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_55 ->
            let _startpos_56 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_56, _v_55) in
            let _v = _menhir_action_178 s in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_58 ->
            let _startpos_59 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_59, _v_58) in
            let _v = _menhir_action_172 s in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_61 ->
            let _startpos_62 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_62, _v_61) in
            let _v = _menhir_action_174 s in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_64 ->
            let _startpos_65 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_65, _v_64) in
            let _v = _menhir_action_175 s in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_67 ->
            let _startpos_68 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_68, _v_67) in
            let _v = _menhir_action_173 s in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_70 ->
            let _startpos_71 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_71, _v_70) in
            let _v = _menhir_action_176 s in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_73 ->
            let _startpos_74 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_74, _v_73) in
            let _v = _menhir_action_180 s in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_76 ->
            let _startpos_77 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_77, _v_76) in
            let _v = _menhir_action_177 s in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _startpos_79 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_79) in
            let _v = _menhir_action_188 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.EQ ->
            let _startpos_81 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_81) in
            let _v = _menhir_action_183 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.DIV ->
            let _startpos_83 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_83) in
            let _v = _menhir_action_192 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.DARROW ->
            let _startpos_85 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_85) in
            let _v = _menhir_action_194 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_87 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_87) in
            let _v = _menhir_action_081 () in
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_89 ->
            let _startpos_90 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_90, _v_89) in
            let _v = _menhir_action_074 c in
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.CONS ->
            let _startpos_92 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_92) in
            let _v = _menhir_action_182 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _startpos_94 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_94) in
            let _v = _menhir_action_197 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONJ ->
            let _startpos_96 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_96) in
            let _v = _menhir_action_198 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_98 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_98) in
            let _v = _menhir_action_077 () in
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.ARROW ->
            let _startpos_100 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_100) in
            let _v = _menhir_action_193 () in
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_102 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_102) in
            let _v = _menhir_action_078 () in
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | _ ->
            _eRR 353
    
    and _menhir_run_356 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_FIXITY -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.INTEGER _v_0 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_FIXITY (_menhir_stack, _menhir_s, f, _startpos_f_) = _menhir_stack in
            let (_endpos_c_, _startpos_c_, c, i) = (_endpos, _startpos, _v, _v_0) in
            let _v = _menhir_action_107 _endpos_c_ _startpos_c_ c f i in
            _menhir_goto_fixity _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_f_ _v _menhir_s _tok
        | _ ->
            _eRR 356
    
    and _menhir_run_417 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_attributes (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.TYPE ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_TYPE (_menhir_stack, MenhirState417, _startpos_0, _endpos_1) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
                let _v = _menhir_action_083 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState418 _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos_5) in
                let _v = _menhir_action_082 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState418 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
                let _v = _menhir_action_087 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState418 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
                let _v = _menhir_action_076 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState418 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState418
            | Elpi_lexer_config.Tokens.IO _v_14 ->
                let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_16 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_16, _startpos_15, _v_14) in
                let _v = _menhir_action_080 c in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState418 _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
                let _v = _menhir_action_079 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState418 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_22, _startpos_21) in
                let _v = _menhir_action_075 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState418 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
                let _v = _menhir_action_084 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState418 _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_27 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_28 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_28, _startpos_27) in
                let _v = _menhir_action_081 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState418 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_30 ->
                let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_32, _startpos_31, _v_30) in
                let _v = _menhir_action_074 c in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState418 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
                let _v = _menhir_action_077 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState418 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
                let _v = _menhir_action_078 () in
                _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState418 _tok
            | _ ->
                _eRR 418)
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_40 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_41 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_41, _startpos_40) in
            let _v = _menhir_action_083 () in
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState417 _tok
        | Elpi_lexer_config.Tokens.RULE ->
            let _startpos_43 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_44 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RULE (_menhir_stack, MenhirState417, _startpos_43) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_45 ->
                let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos_47, _v_45) in
                let _v = _menhir_action_067 x in
                _menhir_run_429_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_50 in
                let _v = _menhir_action_083 () in
                _menhir_run_047_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_52 ->
                let _startpos_53 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_54 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_54, _startpos_53, _v_52) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_429_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _endpos_57 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_57 in
                let _v = _menhir_action_082 () in
                _menhir_run_047_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _endpos_60 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_60 in
                let _v = _menhir_action_087 () in
                _menhir_run_047_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _endpos_63 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_63 in
                let _v = _menhir_action_076 () in
                _menhir_run_047_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_422 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState421
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState421
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState421
            | Elpi_lexer_config.Tokens.IO _v_65 ->
                let _endpos_67 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, c) = (_endpos_67, _v_65) in
                let _v = _menhir_action_080 c in
                _menhir_run_047_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_69 ->
                let _endpos_71 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos_71, _v_69) in
                let _v = _menhir_action_065 x in
                _menhir_run_429_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _endpos_74 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_74 in
                let _v = _menhir_action_079 () in
                _menhir_run_047_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _endpos_77 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_77 in
                let _v = _menhir_action_075 () in
                _menhir_run_047_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _endpos_80 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_80 in
                let _v = _menhir_action_084 () in
                _menhir_run_047_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_82 ->
                let _endpos_84 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos_84, _v_82) in
                let _v = _menhir_action_066 x in
                _menhir_run_429_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _endpos_87 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_87 in
                let _v = _menhir_action_081 () in
                _menhir_run_047_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_89 ->
                let _endpos_91 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, c) = (_endpos_91, _v_89) in
                let _v = _menhir_action_074 c in
                _menhir_run_047_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _endpos_94 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_94 in
                let _v = _menhir_action_077 () in
                _menhir_run_047_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _endpos_97 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_97 in
                let _v = _menhir_action_078 () in
                _menhir_run_047_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.BIND | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE ->
                let _endpos = _endpos_44 in
                let _v = _menhir_action_159 () in
                _menhir_run_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v MenhirState421 _tok
            | _ ->
                _eRR 421)
        | Elpi_lexer_config.Tokens.PRED ->
            let _startpos_100 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_PRED (_menhir_stack, MenhirState417, _startpos_100) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_101 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_102 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_102, _startpos_101) in
                let _v = _menhir_action_083 () in
                _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState442 _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_104 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_105 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_105, _startpos_104) in
                let _v = _menhir_action_082 () in
                _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState442 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_107 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_108 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_108, _startpos_107) in
                let _v = _menhir_action_087 () in
                _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState442 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_110 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_111 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_111, _startpos_110) in
                let _v = _menhir_action_076 () in
                _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState442 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
            | Elpi_lexer_config.Tokens.IO _v_113 ->
                let _startpos_114 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_115 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_115, _startpos_114, _v_113) in
                let _v = _menhir_action_080 c in
                _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState442 _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_117 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_118 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_118, _startpos_117) in
                let _v = _menhir_action_079 () in
                _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState442 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_120 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_121 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_121, _startpos_120) in
                let _v = _menhir_action_075 () in
                _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState442 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_123 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_124 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_124, _startpos_123) in
                let _v = _menhir_action_084 () in
                _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState442 _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_126 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_127 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_127, _startpos_126) in
                let _v = _menhir_action_081 () in
                _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState442 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_129 ->
                let _startpos_130 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_131 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_131, _startpos_130, _v_129) in
                let _v = _menhir_action_074 c in
                _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState442 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_133 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_134 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_134, _startpos_133) in
                let _v = _menhir_action_077 () in
                _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState442 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_136 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_137 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_137, _startpos_136) in
                let _v = _menhir_action_078 () in
                _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState442 _tok
            | _ ->
                _eRR 442)
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_139 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_140 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_140, _startpos_139) in
            let _v = _menhir_action_082 () in
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState417 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_142 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_143 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_143, _startpos_142) in
            let _v = _menhir_action_087 () in
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState417 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_145 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_146 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_146, _startpos_145) in
            let _v = _menhir_action_076 () in
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState417 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _startpos_148 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, MenhirState417, _startpos_148) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.VDASH ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_199 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.STRING _v_152 ->
                let _startpos_153 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_154 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_154, _startpos_153, _v_152) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_452 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SLASH ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_196 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_159 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_160 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_160, _startpos_159) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState452 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_162 ->
                let _startpos_163 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_164 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_164, _startpos_163, _v_162) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_452 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.QDASH ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_195 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_169 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_170 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_170, _startpos_169) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState452 _tok
            | Elpi_lexer_config.Tokens.OR ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_189 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_175 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_176 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_176, _startpos_175) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState452 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_178 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_179 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_179, _startpos_178) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState452 _tok
            | Elpi_lexer_config.Tokens.MOD ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_191 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUSs ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_187 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUSr ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_185 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUSi ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_186 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUS ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_184 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState452
            | Elpi_lexer_config.Tokens.IS ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_190 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.IO _v_199 ->
                let _startpos_200 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_201 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_201, _startpos_200, _v_199) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState452 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_203 ->
                let _startpos_204 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_205 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_205, _startpos_204, _v_203) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_452 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_207 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_208 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_208, _startpos_207) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState452 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_210 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_211 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_211, _startpos_210) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState452 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_213 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_214 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_214, _startpos_213) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState452 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_216 ->
                let _startpos_217 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_218 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_218, _startpos_217, _v_216) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_452 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_220 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_220 in
                let _v = _menhir_action_171 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_224 ->
                _menhir_run_195 _menhir_stack _menhir_lexbuf _menhir_lexer _v_224 MenhirState452
            | Elpi_lexer_config.Tokens.FAMILY_TICK _v_225 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_225 in
                let _v = _menhir_action_181 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_229 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_229 in
                let _v = _menhir_action_179 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_233 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_233 in
                let _v = _menhir_action_201 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_237 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_237 in
                let _v = _menhir_action_170 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_OR _v_241 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_241 in
                let _v = _menhir_action_178 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_245 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_245 in
                let _v = _menhir_action_172 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_LT _v_249 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_249 in
                let _v = _menhir_action_174 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_GT _v_253 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_253 in
                let _v = _menhir_action_175 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_EXP _v_257 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_257 in
                let _v = _menhir_action_173 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_EQ _v_261 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_261 in
                let _v = _menhir_action_176 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_265 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_265 in
                let _v = _menhir_action_180 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_AND _v_269 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_269 in
                let _v = _menhir_action_177 s in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.EQ2 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_188 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.EQ ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_183 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.DIV ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_192 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.DARROW ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_194 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_285 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_286 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_286, _startpos_285) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState452 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_288 ->
                let _startpos_289 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_290 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_290, _startpos_289, _v_288) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState452 _tok
            | Elpi_lexer_config.Tokens.CONS ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_182 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CONJ2 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_197 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CONJ ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_198 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_301 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_302 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_302, _startpos_301) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState452 _tok
            | Elpi_lexer_config.Tokens.AS ->
                _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer
            | Elpi_lexer_config.Tokens.ARROW ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_193 () in
                _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_307 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_308 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_308, _startpos_307) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState452 _tok
            | _ ->
                _eRR 452)
        | Elpi_lexer_config.Tokens.IO _v_310 ->
            let _startpos_311 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_312 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_312, _startpos_311, _v_310) in
            let _v = _menhir_action_080 c in
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState417 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_314 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_315 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_315, _startpos_314) in
            let _v = _menhir_action_079 () in
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState417 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_317 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_318 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_318, _startpos_317) in
            let _v = _menhir_action_075 () in
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState417 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_320 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_321 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_321, _startpos_320) in
            let _v = _menhir_action_084 () in
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState417 _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_323 ->
            let _startpos_324 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_325 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, MenhirState417, _v_323, _startpos_324, _endpos_325) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_326 ->
                let _startpos_327 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_328 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_328, _startpos_327, _v_326) in
                let _v = _menhir_action_067 x in
                _menhir_run_052_spec_455 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_330 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_331 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_331, _startpos_330) in
                let _v = _menhir_action_083 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_333 ->
                let _startpos_334 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_335 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_335, _startpos_334, _v_333) in
                let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
                _menhir_run_052_spec_455 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_337 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_338 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_338, _startpos_337) in
                let _v = _menhir_action_082 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_340 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_341 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_341, _startpos_340) in
                let _v = _menhir_action_087 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_343 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_344 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_344, _startpos_343) in
                let _v = _menhir_action_076 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState455
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState455
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState455
            | Elpi_lexer_config.Tokens.IO _v_346 ->
                let _startpos_347 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_348 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_348, _startpos_347, _v_346) in
                let _v = _menhir_action_080 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_350 ->
                let _startpos_351 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_352 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_352, _startpos_351, _v_350) in
                let _v = _menhir_action_065 x in
                _menhir_run_052_spec_455 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_354 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_355 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_355, _startpos_354) in
                let _v = _menhir_action_079 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_357 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_358 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_358, _startpos_357) in
                let _v = _menhir_action_075 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_360 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_361 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_361, _startpos_360) in
                let _v = _menhir_action_084 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_363 ->
                let _startpos_364 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_365 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_365, _startpos_364, _v_363) in
                let _v = _menhir_action_066 x in
                _menhir_run_052_spec_455 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_367 ->
                _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v_367 MenhirState455
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_368 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_369 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_369, _startpos_368) in
                let _v = _menhir_action_081 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_371 ->
                let _startpos_372 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_373 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_373, _startpos_372, _v_371) in
                let _v = _menhir_action_074 c in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_375 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_376 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_376, _startpos_375) in
                let _v = _menhir_action_077 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_378 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_379 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_379, _startpos_378) in
                let _v = _menhir_action_078 () in
                _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | _ ->
                _eRR 455)
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_381 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_382 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_382, _startpos_381) in
            let _v = _menhir_action_081 () in
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState417 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_384 ->
            let _startpos_385 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_386 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_386, _startpos_385, _v_384) in
            let _v = _menhir_action_074 c in
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState417 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_388 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_389 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_389, _startpos_388) in
            let _v = _menhir_action_077 () in
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState417 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_391 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_392 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_392, _startpos_391) in
            let _v = _menhir_action_078 () in
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState417 _tok
        | _ ->
            _eRR 417
    
    and _menhir_run_460 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_029 t in
            _menhir_goto_clause_hd_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FLOAT _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.INTEGER _ | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LBRACKET | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.QUOTED _ | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.STRING _ ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_111 t in
            _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 460
    
    and _menhir_run_047_spec_421 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_111 t in
        _menhir_run_046_spec_421 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_443 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_PRED as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.IO_COLON _v_0 ->
            _menhir_run_444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState443
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _v = _menhir_action_167 () in
            _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v
        | _ ->
            _eRR 443
    
    and _menhir_run_359 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_EXPORTDEF (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_083 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState359 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_082 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState359 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_087 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState359 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_076 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState359 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState359
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_4, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState359 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_5) in
            let _v = _menhir_action_079 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState359 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_075 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState359 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_084 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState359 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_081 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState359 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_9, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState359 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
            let _v = _menhir_action_077 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState359 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_078 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState359 _tok
        | _ ->
            _eRR 359
    
    and _menhir_run_363 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CONSTRAINT (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_083 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState363 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_082 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState363 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_087 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState363 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_076 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState363 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_4, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState363 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_5) in
            let _v = _menhir_action_079 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState363 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_075 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState363 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_084 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState363 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_081 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState363 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_9, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState363 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
            let _v = _menhir_action_077 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState363 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_078 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState363 _tok
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _v = _menhir_action_157 () in
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR 363
    
    and _menhir_run_366 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_1, _startpos_0) in
            let _v = _menhir_action_083 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState366 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos_3) in
            let _v = _menhir_action_082 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState366 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_087 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState366 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_10, _startpos_9) in
            let _v = _menhir_action_076 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState366 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
        | Elpi_lexer_config.Tokens.IO _v_12 ->
            let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_14, _startpos_13, _v_12) in
            let _v = _menhir_action_080 c in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState366 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState366 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
            let _v = _menhir_action_075 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState366 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_084 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState366 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos_25) in
            let _v = _menhir_action_081 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState366 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_28 ->
            let _startpos_29 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_30 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_30, _startpos_29, _v_28) in
            let _v = _menhir_action_074 c in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState366 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_077 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState366 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_36, _startpos_35) in
            let _v = _menhir_action_078 () in
            _menhir_run_366 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState366 _tok
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _v = _menhir_action_157 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR 366
    
    and _menhir_run_367 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_constant (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_158 x xs in
        _menhir_goto_list_constant_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_goto_list_constant_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState366 ->
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState363 ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_364 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_CONSTRAINT -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_CONSTRAINT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_endpos__3_, cl) = (_endpos, _v) in
        let _v = _menhir_action_095 _endpos__3_ _startpos__1_ cl in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_368 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_COLON (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_371 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Elpi_lexer_config.Tokens.EXTERNAL ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _v = _menhir_action_015 () in
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v MenhirState368 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_382 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | _ ->
            _eRR 368
    
    and _menhir_run_369 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s) = (_endpos_1, _v) in
            let _v = _menhir_action_012 s in
            _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 369
    
    and _menhir_goto_attribute : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_387 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.COLON ->
            let _menhir_stack = MenhirCell1_attribute (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_COLON (_menhir_stack, _startpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState388
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_371 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState388
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState388
            | Elpi_lexer_config.Tokens.EXTERNAL ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_1 in
                let _v = _menhir_action_015 () in
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v MenhirState388 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_382 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState388
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState388
            | _ ->
                _eRR 388)
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FAMILY_TILDE _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PRED | Elpi_lexer_config.Tokens.RULE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.TYPE ->
            let (_endpos_x_, x) = (_endpos, _v) in
            let _v = _menhir_action_298 x in
            _menhir_goto_separated_nonempty_list_COLON_attribute_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR 387
    
    and _menhir_run_371 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_INDEX (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAREN (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let i = _v in
                let _v = _menhir_action_123 i in
                _menhir_run_377 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState372 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_122 () in
                _menhir_run_377 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState372 _tok
            | _ ->
                _eRR 372)
        | _ ->
            _eRR 371
    
    and _menhir_run_377 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.INTEGER _v_0 ->
            let _menhir_stack = MenhirCell1_indexing (_menhir_stack, _menhir_s, _v) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let i = _v_0 in
            let _v = _menhir_action_123 i in
            _menhir_run_377 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState377 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_indexing (_menhir_stack, _menhir_s, _v) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_122 () in
            _menhir_run_377 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState377 _tok
        | Elpi_lexer_config.Tokens.RPAREN ->
            let x = _v in
            let _v = _menhir_action_211 x in
            _menhir_goto_nonempty_list_indexing_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 377
    
    and _menhir_goto_nonempty_list_indexing_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState377 ->
            _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState372 ->
            _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_378 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_indexing -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_indexing (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_212 x xs in
        _menhir_goto_nonempty_list_indexing_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_375 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_INDEX _menhir_cell0_LPAREN -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LPAREN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_INDEX (_menhir_stack, _menhir_s, _, _) = _menhir_stack in
        let (l, _endpos__4_) = (_v, _endpos) in
        let _v = _menhir_action_016 l in
        _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _v _menhir_s _tok
    
    and _menhir_run_379 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s) = (_endpos_1, _v) in
            let _v = _menhir_action_011 s in
            _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 379
    
    and _menhir_run_382 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s) = (_endpos_1, _v) in
            let _v = _menhir_action_014 s in
            _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 382
    
    and _menhir_run_384 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s) = (_endpos_1, _v) in
            let _v = _menhir_action_013 s in
            _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 384
    
    and _menhir_goto_separated_nonempty_list_COLON_attribute_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState388 ->
            _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState368 ->
            _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_389 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_attribute _menhir_cell0_COLON -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_COLON (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_attribute (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_299 x xs in
        _menhir_goto_separated_nonempty_list_COLON_attribute_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_386 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_COLON -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_COLON (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_endpos_l_, l) = (_endpos, _v) in
        let _v = _menhir_action_019 l in
        _menhir_run_417 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_l_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_390 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CLOSED (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_083 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState390 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_082 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState390 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_087 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState390 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_076 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState390 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState390
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_4, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState390 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_5) in
            let _v = _menhir_action_079 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState390 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_075 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState390 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_084 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState390 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_081 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState390 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_9, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState390 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
            let _v = _menhir_action_077 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState390 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_078 () in
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState390 _tok
        | _ ->
            _eRR 390
    
    and _menhir_goto_binder_body : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState423 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState050 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState458 ->
            _menhir_run_045_spec_458 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState036 ->
            _menhir_run_045_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState043 ->
            _menhir_run_045_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_051 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_constant -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_constant (_menhir_stack, _menhir_s, t, _startpos_t_, _) = _menhir_stack in
        let (_endpos_b_, b) = (_endpos, _v) in
        let _v = _menhir_action_024 b t in
        let (_endpos, _startpos) = (_endpos_b_, _startpos_t_) in
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_314 t in
        _menhir_goto_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_run_045_spec_458 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term, _menhir_box_program) _menhir_cell1_nonempty_list_closed_term_ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_x_, x) = (_endpos, _v) in
        let _v = _menhir_action_283 x in
        _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
    
    and _menhir_run_045_spec_036 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term, ttv_result) _menhir_cell1_nonempty_list_closed_term_ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_x_, x) = (_endpos, _v) in
        let _v = _menhir_action_283 x in
        _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
    
    and _menhir_run_045_spec_043 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term, ttv_result) _menhir_cell1_nonempty_list_closed_term_ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_x_, x) = (_endpos, _v) in
        let _v = _menhir_action_283 x in
        _menhir_run_044 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
    
    let rec _menhir_run_000 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_goal =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_052_spec_000 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_068 _endpos_x_ _startpos_x_ x in
            _menhir_run_052_spec_000 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_082 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_087 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState000
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState000
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState000
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_080 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_065 x in
            _menhir_run_052_spec_000 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_075 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_052_spec_000 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState000
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_074 c in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | _ ->
            _eRR 0
    
    let rec _menhir_goto_infix_SYMB : type  ttv_stack. ttv_stack -> _ -> _menhir_box_infix_SYMB =
      fun _menhir_stack _v ->
        MenhirBox_infix_SYMB _v
    
    let rec _menhir_run_229 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_infix_SYMB =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _v = _menhir_action_153 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.SLASH ->
            let _v = _menhir_action_150 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.QDASH ->
            let _v = _menhir_action_149 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.OR ->
            let _v = _menhir_action_143 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.MOD ->
            let _v = _menhir_action_145 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _v = _menhir_action_141 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _v = _menhir_action_139 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _v = _menhir_action_140 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.MINUS ->
            let _v = _menhir_action_138 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.IS ->
            let _v = _menhir_action_144 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            let s = _v in
            let _v = _menhir_action_125 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            let s = _v in
            let _v = _menhir_action_135 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            let s = _v in
            let _v = _menhir_action_133 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            let s = _v in
            let _v = _menhir_action_124 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            let s = _v in
            let _v = _menhir_action_132 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            let s = _v in
            let _v = _menhir_action_126 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            let s = _v in
            let _v = _menhir_action_128 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            let s = _v in
            let _v = _menhir_action_129 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            let s = _v in
            let _v = _menhir_action_127 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            let s = _v in
            let _v = _menhir_action_130 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            let s = _v in
            let _v = _menhir_action_134 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            let s = _v in
            let _v = _menhir_action_131 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _v = _menhir_action_142 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.EQ ->
            let _v = _menhir_action_137 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.DIV ->
            let _v = _menhir_action_146 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.DARROW ->
            let _v = _menhir_action_148 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.CONS ->
            let _v = _menhir_action_136 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _v = _menhir_action_151 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.CONJ ->
            let _v = _menhir_action_152 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.ARROW ->
            let _v = _menhir_action_147 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | _ ->
            _eRR 229
    
    let rec _menhir_run_261 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_postfix_SYMB =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            let s = _v in
            let _v = _menhir_action_292 s in
            MenhirBox_postfix_SYMB _v
        | _ ->
            _eRR 261
    
    let rec _menhir_run_264 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_prefix_SYMB =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            let s = _v in
            let _v = _menhir_action_295 s in
            MenhirBox_prefix_SYMB _v
        | _ ->
            _eRR 264
    
    let rec _menhir_run_267 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.USE_SIG ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_010 () in
            _menhir_run_525 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState267 _tok
        | Elpi_lexer_config.Tokens.USEONLY ->
            _menhir_run_269 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Elpi_lexer_config.Tokens.TYPEABBREV ->
            _menhir_run_291 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Elpi_lexer_config.Tokens.SIG ->
            _menhir_run_301 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Elpi_lexer_config.Tokens.SHORTEN ->
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Elpi_lexer_config.Tokens.RCURLY ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_100 _endpos__1_ _startpos__1_ in
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v MenhirState267 _tok
        | Elpi_lexer_config.Tokens.NAMESPACE ->
            _menhir_run_321 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Elpi_lexer_config.Tokens.MODULE ->
            _menhir_run_324 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Elpi_lexer_config.Tokens.MODE ->
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Elpi_lexer_config.Tokens.MACRO ->
            _menhir_run_334 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Elpi_lexer_config.Tokens.LOCALKIND ->
            _menhir_run_338 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Elpi_lexer_config.Tokens.LOCAL ->
            _menhir_run_340 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_099 _endpos__1_ _startpos__1_ in
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v MenhirState267 _tok
        | Elpi_lexer_config.Tokens.KIND ->
            _menhir_run_346 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Elpi_lexer_config.Tokens.IMPORT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_008 () in
            _menhir_run_525 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState267 _tok
        | Elpi_lexer_config.Tokens.FIXITY _v ->
            _menhir_run_353 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState267
        | Elpi_lexer_config.Tokens.EXTERNAL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_018 () in
            _menhir_run_417 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState267 _tok
        | Elpi_lexer_config.Tokens.EXPORTDEF ->
            _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Elpi_lexer_config.Tokens.EOF ->
            let _v = _menhir_action_296 () in
            _menhir_run_398_spec_267 _menhir_stack _v
        | Elpi_lexer_config.Tokens.CONSTRAINT ->
            _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Elpi_lexer_config.Tokens.COLON ->
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Elpi_lexer_config.Tokens.CLOSED ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Elpi_lexer_config.Tokens.ACCUM_SIG ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_009 () in
            _menhir_run_525 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState267 _tok
        | Elpi_lexer_config.Tokens.ACCUMULATE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_007 () in
            _menhir_run_525 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState267 _tok
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FAMILY_TILDE _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PRED | Elpi_lexer_config.Tokens.RULE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.TYPE ->
            let _v = _menhir_action_017 () in
            _menhir_run_417 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _endpos _v MenhirState267 _tok
        | _ ->
            _eRR 267
    
  end
  
  let program =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_program v = _menhir_run_267 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let prefix_SYMB =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_prefix_SYMB v = _menhir_run_264 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let postfix_SYMB =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_postfix_SYMB v = _menhir_run_261 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let infix_SYMB =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_infix_SYMB v = _menhir_run_229 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let goal =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_goal v = _menhir_run_000 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
end
